@@ -1,7 +1,7 @@
 /* asn1.h
  * Definitions for ASN.1 BER dissection
  *
- * $Id: asn1.h,v 1.7 2002/03/12 10:37:01 guy Exp $
+ * $Id: asn1.h,v 1.9 2002/08/02 23:35:46 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -91,9 +91,9 @@
  * typedef "subid_t".
  */
 #if defined(HAVE_UCD_SNMP)
-typedef u_long	subid_t;	/* UCD SNMP */
+typedef gulong	subid_t;	/* UCD SNMP */
 #else
-typedef u_int	subid_t;	/* CMU SNMP, libsmi, or nothing */
+typedef guint	subid_t;	/* CMU SNMP, libsmi, or nothing */
 #endif
 
 #define ASN1_ERR_NOERROR		0	/* no error */
@@ -122,7 +122,7 @@ int asn1_header_decode(ASN1_SCK *asn1, guint *cls, guint *con, guint *tag,
 int asn1_eoc (ASN1_SCK *asn1, int eoc);
 int asn1_eoc_decode (ASN1_SCK *asn1, int eoc);
 int asn1_null_decode (ASN1_SCK *asn1, int enc_len);
-int asn1_bool_decode (ASN1_SCK *asn1, int enc_len, gboolean *bool);
+int asn1_bool_decode (ASN1_SCK *asn1, int enc_len, gboolean *boolean);
 int asn1_int32_value_decode (ASN1_SCK *asn1, int enc_len, gint32 *integer);
 int asn1_int32_decode (ASN1_SCK *asn1, gint32 *integer, guint *nbytes);
 int asn1_uint32_value_decode (ASN1_SCK *asn1, int enc_len, guint *integer);
