@@ -1,7 +1,7 @@
 /* capture.c
  * Routines for packet capture windows
  *
- * $Id: capture.c,v 1.174 2002/05/04 09:11:28 guy Exp $
+ * $Id: capture.c,v 1.188 2002/08/13 18:12:11 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -28,10 +28,6 @@
 
 #ifdef HAVE_LIBPCAP
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #ifdef HAVE_SYS_STAT_H
 # include <sys/stat.h>
 #endif
@@ -113,11 +109,11 @@
  * XXX - the various BSDs appear to define BSD in <sys/param.h>; we don't
  * want to include it if it's not present on this platform, however.
  */
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__bsdi__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__bsdi__) || defined(__APPLE__)
 #ifndef BSD
 #define BSD
 #endif /* BSD */
-#endif /* defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__bsdi__) */
+#endif /* defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__bsdi__) || defined(__APPLE__) */
 
 /*
  * We don't want to do a "select()" on the pcap_t's file descriptor on
@@ -151,8 +147,10 @@
 
 #include "wiretap/libpcap.h"
 #include "wiretap/wtap.h"
+#include "wiretap/wtap-capture.h"
 
 #include "packet-atalk.h"
+#include "packet-atm.h"
 #include "packet-clip.h"
 #include "packet-eth.h"
 #include "packet-fddi.h"
@@ -201,9 +199,10 @@ static char *signame(int);
 #endif
 static void capture_delete_cb(GtkWidget *, GdkEvent *, gpointer);
 static void capture_stop_cb(GtkWidget *, gpointer);
-static void capture_pcap_cb(u_char *, const struct pcap_pkthdr *,
-  const u_char *);
+static void capture_pcap_cb(guchar *, const struct pcap_pkthdr *,
+  const guchar *);
 static void get_capture_file_io_error(char *, int, const char *, int, gboolean);
+static void popup_errmsg(const char *);
 static void send_errmsg_to_parent(const char *);
 static float pct(gint, gint);
 static void stop_capture(int signo);
@@ -216,16 +215,26 @@ typedef struct _loop_data {
   gint           sync_packets;
   gboolean       pcap_err;     /* TRUE if error from pcap */
   gboolean       from_pipe;    /* TRUE if we are capturing data from a pipe */
-  gboolean       modified;     /* TRUE if data in the pipe uses modified pcap headers */
-  gboolean       byte_swapped; /* TRUE if data in the pipe is byte swapped */
   packet_counts  counts;
   wtap_dumper   *pdh;
+#ifndef _WIN32
+  gboolean       modified;     /* TRUE if data in the pipe uses modified pcap headers */
+  gboolean       byte_swapped; /* TRUE if data in the pipe is byte swapped */
+  unsigned int   bytes_to_read, bytes_read; /* Used by pipe_dispatch */
+  enum {
+         STATE_EXPECT_REC_HDR, STATE_READ_REC_HDR,
+         STATE_EXPECT_DATA,     STATE_READ_DATA
+       } pipe_state;
+
+  enum { PIPOK, PIPEOF, PIPERR, PIPNEXIST } pipe_err;
+#endif
 } loop_data;
 
 #ifndef _WIN32
 static void adjust_header(loop_data *, struct pcap_hdr *, struct pcaprec_hdr *);
-static int pipe_open_live(char *, struct pcap_hdr *, loop_data *);
-static int pipe_dispatch(int, loop_data *, struct pcap_hdr *);
+static int pipe_open_live(char *, struct pcap_hdr *, loop_data *, char *, int);
+static int pipe_dispatch(int, loop_data *, struct pcap_hdr *, \
+		struct pcaprec_modified_hdr *, guchar *, char *, int);
 #endif
 
 /* Win32 needs the O_BINARY flag for open() */
@@ -284,7 +293,7 @@ do_capture(char *capfile_name)
 {
   char tmpname[128+1];
   gboolean is_tempfile;
-  u_char c;
+  guchar c;
   int i;
   guint byte_count;
   char *msg;
@@ -320,7 +329,7 @@ do_capture(char *capfile_name)
         ringbuf_error_cleanup();
       }
       simple_dialog(ESD_TYPE_CRIT, NULL,
-	file_open_error_message(errno, TRUE), capfile_name);
+	file_open_error_message(errno, TRUE, WTAP_FILE_PCAP), capfile_name);
     }
     return;
   }
@@ -563,12 +572,9 @@ do_capture(char *capfile_name)
 				       NULL);
 #endif
       } else {
-	/* We weren't able to open the capture file; complain, and
-	   close the sync pipe. */
-	simple_dialog(ESD_TYPE_CRIT, NULL,
-			file_open_error_message(err, FALSE), cfile.save_file);
+	/* We weren't able to open the capture file; user has been
+	   alerted. Close the sync pipe. */
 
-	/* Close the sync pipe. */
 	close(sync_pipe[READ]);
 
 	/* Don't unlink the save file - leave it around, for debugging
@@ -600,7 +606,7 @@ do_capture(char *capfile_name)
 		  "Capture child process failed: EOF reading its error message.");
 	    wait_for_child(FALSE);
 	  } else
-	    simple_dialog(ESD_TYPE_WARN, NULL, msg);
+	    simple_dialog(ESD_TYPE_CRIT, NULL, msg);
 	  g_free(msg);
 	}
 
@@ -822,7 +828,7 @@ cap_file_input_cb(gpointer data, gint source _U_,
         msglen -= chars_to_copy;
       }
       *r = '\0';
-      simple_dialog(ESD_TYPE_WARN, NULL, msg);
+      simple_dialog(ESD_TYPE_CRIT, NULL, msg);
       g_free(msg);
       break;
     default :
@@ -1011,21 +1017,8 @@ signame(int sig)
 
 /*
  * Timeout, in milliseconds, for reads from the stream of captured packets.
- *
- * XXX - Michael Tuexen says MacOS X's BPF appears to be broken, in that
- * if you use a timeout of 250 in "pcap_open_live()", you don't see
- * packets until a large number of packets arrive; the timeout doesn't
- * cause a smaller number of packets to be delivered.  Perhaps a timeout
- * that's less than 1 second acts like no timeout at all, so that you
- * don't see packets until the BPF buffer fills up?
- *
- * The workaround is to use a timeout of 1000 seconds on MacOS X.
  */
-#ifdef __APPLE__
-#define	CAP_READ_TIMEOUT	1000
-#else
 #define	CAP_READ_TIMEOUT	250
-#endif
 
 #ifndef _WIN32
 /* Take carre of byte order in the libpcap headers read from pipes.
@@ -1065,23 +1058,85 @@ adjust_header(loop_data *ld, struct pcap_hdr *hdr, struct pcaprec_hdr *rechdr)
  * N.B. : we can't read the libpcap formats used in RedHat 6.1 or SuSE 6.3
  * because we can't seek on pipes (see wiretap/libpcap.c for details) */
 static int
-pipe_open_live(char *pipename, struct pcap_hdr *hdr, loop_data *ld)
+pipe_open_live(char *pipename, struct pcap_hdr *hdr, loop_data *ld,
+                 char *errmsg, int errmsgl)
 {
   struct stat pipe_stat;
   int         fd;
   guint32     magic;
-  int         bytes_read, b;
+  int         b, sel_ret;
+  unsigned int bytes_read;
+  fd_set      rfds;
+  struct timeval timeout;
 
-  if (strcmp(pipename, "-") == 0) fd = 0; /* read from stdin */
-  else if (stat(pipename, &pipe_stat) == 0 && S_ISFIFO(pipe_stat.st_mode)) {
-    if ((fd = open(pipename, O_RDONLY)) == -1) return -1;
-  } else return -1;
+  /*
+   * XXX Ethereal blocks until we return
+   */
+  if (strcmp(pipename, "-") == 0)
+    fd = 0; /* read from stdin */
+  else {
+    if (stat(pipename, &pipe_stat) < 0) {
+      if (errno == ENOENT || errno == ENOTDIR)
+        ld->pipe_err = PIPNEXIST;
+      else {
+        snprintf(errmsg, errmsgl,
+          "The capture session could not be initiated "
+          "due to error on pipe: %s", strerror(errno));
+        ld->pipe_err = PIPERR;
+      }
+      return -1;
+    }
+    if (! S_ISFIFO(pipe_stat.st_mode)) {
+      if (S_ISCHR(pipe_stat.st_mode)) {
+        /*
+         * Assume the user specified an interface on a system where
+         * interfaces are in /dev.  Pretend we haven't seen it.
+         */
+         ld->pipe_err = PIPNEXIST;
+      } else {
+        snprintf(errmsg, errmsgl,
+            "The capture session could not be initiated because\n"
+            "\"%s\" is neither an interface nor a pipe", pipename);
+        ld->pipe_err = PIPERR;
+      }
+      return -1;
+    }
+    fd = open(pipename, O_RDONLY | O_NONBLOCK);
+    if (fd == -1) {
+      snprintf(errmsg, errmsgl,
+          "The capture session could not be initiated "
+          "due to error on pipe open: %s", strerror(errno));
+      ld->pipe_err = PIPERR;
+      return -1;
+    }
+  }
 
   ld->from_pipe = TRUE;
+
   /* read the pcap header */
-  if (read(fd, &magic, sizeof magic) != sizeof magic) {
-    close(fd);
-    return -1;
+  FD_ZERO(&rfds);
+  bytes_read = 0;
+  while (bytes_read < sizeof magic) {
+    FD_SET(fd, &rfds);
+    timeout.tv_sec = 0;
+    timeout.tv_usec = CAP_READ_TIMEOUT*1000;
+    sel_ret = select(fd+1, &rfds, NULL, NULL, &timeout);
+    if (sel_ret < 0) {
+      snprintf(errmsg, errmsgl,
+        "Unexpected error from select: %s", strerror(errno));
+      goto error;
+    } else if (sel_ret > 0) {
+      b = read(fd, &magic+bytes_read, sizeof magic-bytes_read);
+      if (b <= 0) {
+        if (b == 0)
+          snprintf(errmsg, errmsgl, "End of file on pipe during open");
+        else
+          snprintf(errmsg, errmsgl, "Error on pipe during open: %s",
+            strerror(errno));
+        goto error;
+      }
+      bytes_read += b;
+    }
   }
 
   switch (magic) {
@@ -1113,25 +1168,36 @@ pipe_open_live(char *pipename, struct pcap_hdr *hdr, loop_data *ld)
     break;
   default:
     /* Not a "libpcap" type we know about. */
-    close(fd);
-    return -1;
+    snprintf(errmsg, errmsgl, "Unrecognized libpcap format");
+    goto error;
   }
 
   /* Read the rest of the header */
-  bytes_read = read(fd, hdr, sizeof(struct pcap_hdr));
-  if (bytes_read <= 0) {
-    close(fd);
-    return -1;
-  }
-  while ((unsigned) bytes_read < sizeof(struct pcap_hdr))
-  {
-    b = read(fd, ((char *)&hdr)+bytes_read, sizeof(struct pcap_hdr) - bytes_read);
-    if (b <= 0) {
-      close(fd);
-      return -1;
+  bytes_read = 0;
+  while (bytes_read < sizeof(struct pcap_hdr)) {
+    FD_SET(fd, &rfds);
+    timeout.tv_sec = 0;
+    timeout.tv_usec = CAP_READ_TIMEOUT*1000;
+    sel_ret = select(fd+1, &rfds, NULL, NULL, &timeout);
+    if (sel_ret < 0) {
+      snprintf(errmsg, errmsgl,
+        "Unexpected error from select: %s", strerror(errno));
+      goto error;
+    } else if (sel_ret > 0) {
+      b = read(fd, ((char *)hdr)+bytes_read,
+            sizeof(struct pcap_hdr) - bytes_read);
+      if (b <= 0) {
+        if (b == 0)
+          snprintf(errmsg, errmsgl, "End of file on pipe during open");
+        else
+          snprintf(errmsg, errmsgl, "Error on pipe during open: %s",
+            strerror(errno));
+        goto error;
+      }
+      bytes_read += b;
     }
-    bytes_read += b;
   }
+
   if (ld->byte_swapped) {
     /* Byte-swap the header fields about which we care. */
     hdr->version_major = BSWAP16(hdr->version_major);
@@ -1139,118 +1205,128 @@ pipe_open_live(char *pipename, struct pcap_hdr *hdr, loop_data *ld)
     hdr->snaplen = BSWAP32(hdr->snaplen);
     hdr->network = BSWAP32(hdr->network);
   }
+
   if (hdr->version_major < 2) {
-    close(fd);
-    return -1;
+    snprintf(errmsg, errmsgl, "Unable to read old libpcap format");
+    goto error;
   }
 
+  ld->pipe_state = STATE_EXPECT_REC_HDR;
+  ld->pipe_err = PIPOK;
   return fd;
+
+error:
+  ld->pipe_err = PIPERR;
+  close(fd);
+  return -1;
+
 }
 
 /* We read one record from the pipe, take care of byte order in the record
  * header, write the record in the capture file, and update capture statistics. */
+
 static int
-pipe_dispatch(int fd, loop_data *ld, struct pcap_hdr *hdr)
+pipe_dispatch(int fd, loop_data *ld, struct pcap_hdr *hdr,
+		struct pcaprec_modified_hdr *rechdr, guchar *data,
+		char *errmsg, int errmsgl)
 {
-  struct wtap_pkthdr whdr;
-  struct pcaprec_modified_hdr rechdr;
-  int bytes_to_read, bytes_read, b;
-  u_char pd[WTAP_MAX_PACKET_SIZE];
-  int err;
+  struct pcap_pkthdr phdr;
+  int b;
+  enum { PD_REC_HDR_READ, PD_DATA_READ, PD_PIPE_EOF, PD_PIPE_ERR,
+          PD_ERR } result;
 
-  /* read the record header */
-  bytes_to_read = ld->modified ? sizeof rechdr : sizeof rechdr.hdr;
-  bytes_read = read(fd, &rechdr, bytes_to_read);
-  if (bytes_read <= 0) {
-    close(fd);
-    ld->go = FALSE;
-    return 0;
-  }
-  while (bytes_read < bytes_to_read)
-  {
-    b = read(fd, ((char *)&rechdr)+bytes_read, bytes_to_read - bytes_read);
+  switch (ld->pipe_state) {
+
+  case STATE_EXPECT_REC_HDR:
+    ld->bytes_to_read = ld->modified ?
+      sizeof(struct pcaprec_modified_hdr) : sizeof(struct pcaprec_hdr);
+    ld->bytes_read = 0;
+    ld->pipe_state = STATE_READ_REC_HDR;
+    /* Fall through */
+
+  case STATE_READ_REC_HDR:
+    b = read(fd, ((char *)rechdr)+ld->bytes_read,
+      ld->bytes_to_read - ld->bytes_read);
     if (b <= 0) {
-      close(fd);
-      ld->go = FALSE;
-      return 0;
+      if (b == 0)
+        result = PD_PIPE_EOF;
+      else
+        result = PD_PIPE_ERR;
+      break;
     }
-    bytes_read += b;
-  }
-  /* take care of byte order */
-  adjust_header(ld, hdr, &rechdr.hdr);
-  if (rechdr.hdr.incl_len > WTAP_MAX_PACKET_SIZE) {
-    close(fd);
-    ld->go = FALSE;
-    return 0;
-  }
-  /* read the packet data */
-  bytes_read = read(fd, pd, rechdr.hdr.incl_len);
-  if (bytes_read <= 0) {
-    close(fd);
-    ld->go = FALSE;
-    return 0;
-  }
-  while ((unsigned) bytes_read < rechdr.hdr.incl_len)
-  {
-    b = read(fd, pd+bytes_read, rechdr.hdr.incl_len - bytes_read);
+    if ((ld->bytes_read += b) < ld->bytes_to_read)
+        return 0;
+    result = PD_REC_HDR_READ;
+    break;
+
+  case STATE_EXPECT_DATA:
+    ld->bytes_read = 0;
+    ld->pipe_state = STATE_READ_DATA;
+    /* Fall through */
+
+  case STATE_READ_DATA:
+    b = read(fd, data+ld->bytes_read, rechdr->hdr.incl_len - ld->bytes_read);
     if (b <= 0) {
-      close(fd);
-      ld->go = FALSE;
-      return 0;
+      if (b == 0)
+        result = PD_PIPE_EOF;
+      else
+        result = PD_PIPE_ERR;
+      break;
     }
-    bytes_read += b;
-  }
-  /* dump the packet data to the capture file */
-  whdr.ts.tv_sec = rechdr.hdr.ts_sec;
-  whdr.ts.tv_usec = rechdr.hdr.ts_usec;
-  whdr.caplen = rechdr.hdr.incl_len;
-  whdr.len = rechdr.hdr.orig_len;
-  whdr.pkt_encap = ld->linktype;
-  wtap_dump(ld->pdh, &whdr, NULL, pd, &err);
+    if ((ld->bytes_read += b) < rechdr->hdr.incl_len)
+      return 0;
+    result = PD_DATA_READ;
+    break;
 
-  /* update capture statistics */
-  switch (ld->linktype) {
-    case WTAP_ENCAP_ETHERNET:
-      capture_eth(pd, 0, whdr.caplen, &ld->counts);
+  default:
+    snprintf(errmsg, errmsgl, "pipe_dispatch: invalid state");
+    result = PD_ERR;
+
+  } /* switch (ld->pipe_state) */
+
+  /*
+   * We've now read as much data as we were expecting, so process it.
+   */
+  switch (result) {
+
+  case PD_REC_HDR_READ:
+    /* We've read the header. Take care of byte order. */
+    adjust_header(ld, hdr, &rechdr->hdr);
+    if (rechdr->hdr.incl_len > WTAP_MAX_PACKET_SIZE) {
+      snprintf(errmsg, errmsgl, "Frame %u too long (%d bytes)",
+        ld->counts.total+1, rechdr->hdr.incl_len);
       break;
-    case WTAP_ENCAP_FDDI:
-    case WTAP_ENCAP_FDDI_BITSWAPPED:
-      capture_fddi(pd, whdr.caplen, &ld->counts);
-      break;
-    case WTAP_ENCAP_PRISM_HEADER:
-      capture_prism(pd, 0, whdr.caplen, &ld->counts);
-      break;
-    case WTAP_ENCAP_TOKEN_RING:
-      capture_tr(pd, 0, whdr.caplen, &ld->counts);
-      break;
-    case WTAP_ENCAP_NULL:
-      capture_null(pd, whdr.caplen, &ld->counts);
-      break;
-    case WTAP_ENCAP_PPP:
-      capture_ppp_hdlc(pd, 0, whdr.caplen, &ld->counts);
-      break;
-    case WTAP_ENCAP_RAW_IP:
-      capture_raw(pd, whdr.caplen, &ld->counts);
-      break;
-    case WTAP_ENCAP_LINUX_ATM_CLIP:
-      capture_clip(pd, whdr.caplen, &ld->counts);
-      break;
-    case WTAP_ENCAP_IEEE_802_11:
-    case WTAP_ENCAP_IEEE_802_11_WITH_RADIO:
-      capture_ieee80211(pd, 0, whdr.caplen, &ld->counts);
-      break;
-    case WTAP_ENCAP_CHDLC:
-      capture_chdlc(pd, 0, whdr.caplen, &ld->counts);
-      break;
-    case WTAP_ENCAP_LOCALTALK:
-      capture_llap(&ld->counts);
-      break;
-    /* XXX - FreeBSD may append 4-byte ATM pseudo-header to DLT_ATM_RFC1483,
-       with LLC header following; we should implement it at some
-       point. */
+    }
+    ld->pipe_state = STATE_EXPECT_DATA;
+    return 0;
+
+  case PD_DATA_READ:
+    /* Fill in a "struct pcap_pkthdr", and process the packet. */
+    phdr.ts.tv_sec = rechdr->hdr.ts_sec;
+    phdr.ts.tv_usec = rechdr->hdr.ts_usec;
+    phdr.caplen = rechdr->hdr.incl_len;
+    phdr.len = rechdr->hdr.orig_len;
+  
+    capture_pcap_cb((guchar *)ld, &phdr, data);
+  
+    ld->pipe_state = STATE_EXPECT_REC_HDR;
+    return 1;
+
+  case PD_PIPE_EOF:
+    ld->pipe_err = PIPEOF;
+    return -1;
+
+  case PD_PIPE_ERR:
+    snprintf(errmsg, errmsgl, "Error reading from pipe: %s",
+      strerror(errno));
+    /* Fall through */
+  case PD_ERR:
+    break;
   }
 
-  return 1;
+  ld->pipe_err = PIPERR;
+  /* Return here rather than inside the switch to prevent GCC warning */
+  return -1;
 }
 #endif
 
@@ -1282,23 +1358,8 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
   static const char capstart_msg = SP_CAPSTART;
   char        errmsg[4096+1];
   gboolean    dump_ok;
-#ifndef _WIN32
-  static const char ppamsg[] = "can't find PPA for ";
-  char       *libpcap_warn;
-#endif
   fd_set      set1;
   struct timeval timeout;
-#ifdef MUST_DO_SELECT
-  int         pcap_fd = 0;
-#endif
-#ifdef _WIN32 
-  WORD wVersionRequested; 
-  WSADATA wsaData; 
-#endif
-#ifndef _WIN32
-  int         pipe_fd = -1;
-  struct pcap_hdr hdr;
-#endif
   struct {
       const gchar *title;
       gint *value_ptr;
@@ -1319,6 +1380,26 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
 
 #define N_COUNTS (sizeof counts / sizeof counts[0])
 
+#ifdef _WIN32 
+  WORD wVersionRequested; 
+  WSADATA wsaData; 
+#else
+  static const char ppamsg[] = "can't find PPA for ";
+  char       *libpcap_warn;
+  int         sel_ret;
+  int         pipe_fd = -1;
+  struct pcap_hdr hdr;
+  struct pcaprec_modified_hdr rechdr;
+  guchar pcap_data[WTAP_MAX_PACKET_SIZE];
+#endif
+#ifdef MUST_DO_SELECT
+  int         pcap_fd = 0;
+#endif
+
+/* Size of buffer to hold decimal representation of
+   signed/unsigned 64-bit int */
+#define DECISIZE 20
+
   /* Initialize Windows Socket if we are in a WIN32 OS 
      This needs to be done before querying the interface for network/netmask */
 #ifdef _WIN32 
@@ -1389,55 +1470,61 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
 	"Please check that you have the proper interface specified.\n"
 	"\n"
 	"Note that the driver Ethereal uses for packet capture on Windows\n"
-	"doesn't support capturing on PPP/WAN interfaces in Windows NT/2000.\n",
+	"doesn't support capturing on PPP/WAN interfaces in Windows NT/2000/XP/.NET Server.\n",
 	open_err_str);
     goto error;
 #else
     /* try to open cfile.iface as a pipe */
-    pipe_fd = pipe_open_live(cfile.iface, &hdr, &ld);
+    pipe_fd = pipe_open_live(cfile.iface, &hdr, &ld, errmsg, sizeof errmsg);
 
     if (pipe_fd == -1) {
-      /* Well, we couldn't start the capture assuming the interface was
-         a device, and we couldn't open the pipe, either.
 
-	 We choose to report the error for the device, rather than the
-	 file, under the assumption that you're typically capturing on
-	 a device.
-
-	 If this is a child process that does the capturing in sync
-	 mode or fork mode, it shouldn't do any UI stuff until we pop up the
-	 capture-progress window, and, since we couldn't start the
-	 capture, we haven't popped it up. */
+      /* If this is a child process that does the capturing in sync
+       * mode or fork mode, it shouldn't do any UI stuff until we pop up the
+       * capture-progress window, and, since we couldn't start the
+       * capture, we haven't popped it up.
+       */
       if (!capture_child) {
 	while (gtk_events_pending()) gtk_main_iteration();
       }
 
-      /* If we got a "can't find PPA for XXX" message, warn the user (who
-         is running Ethereal on HP-UX) that they don't have a version
-	 of libpcap that properly handles HP-UX (libpcap 0.6.x and later
-	 versions, which properly handle HP-UX, say "can't find /dev/dlpi
-	 PPA for XXX" rather than "can't find PPA for XXX"). */
-      if (strncmp(open_err_str, ppamsg, sizeof ppamsg - 1) == 0)
-	libpcap_warn =
-	  "\n\n"
-	  "You are running Ethereal with a version of the libpcap library\n"
-	  "that doesn't handle HP-UX network devices well; this means that\n"
-	  "Ethereal may not be able to capture packets.\n"
-	  "\n"
-	  "To fix this, you should install libpcap 0.6.2, or a later version\n"
-	  "of libpcap, rather than libpcap 0.4 or 0.5.x.  It is available in\n"
-	  "packaged binary form from the Software Porting And Archive Centre\n"
-	  "for HP-UX; the Centre is at http://hpux.connect.org.uk/ - the page\n"
-	  "at the URL lists a number of mirror sites.";
-      else
-	libpcap_warn = "";
-      snprintf(errmsg, sizeof errmsg,
+      if (ld.pipe_err == PIPNEXIST) {
+	/* Pipe doesn't exist, so output message for interface */
+
+	/* If we got a "can't find PPA for XXX" message, warn the user (who
+	   is running Ethereal on HP-UX) that they don't have a version
+	   of libpcap that properly handles HP-UX (libpcap 0.6.x and later
+	   versions, which properly handle HP-UX, say "can't find /dev/dlpi
+	   PPA for XXX" rather than "can't find PPA for XXX"). */
+	if (strncmp(open_err_str, ppamsg, sizeof ppamsg - 1) == 0)
+	  libpcap_warn =
+	    "\n\n"
+	    "You are running Ethereal with a version of the libpcap library\n"
+	    "that doesn't handle HP-UX network devices well; this means that\n"
+	    "Ethereal may not be able to capture packets.\n"
+	    "\n"
+	    "To fix this, you should install libpcap 0.6.2, or a later version\n"
+	    "of libpcap, rather than libpcap 0.4 or 0.5.x.  It is available in\n"
+	    "packaged binary form from the Software Porting And Archive Centre\n"
+	    "for HP-UX; the Centre is at http://hpux.connect.org.uk/ - the page\n"
+	    "at the URL lists a number of mirror sites.";
+	else
+	  libpcap_warn = "";
+	snprintf(errmsg, sizeof errmsg,
 	  "The capture session could not be initiated (%s).\n"
 	  "Please check to make sure you have sufficient permissions, and that\n"
 	  "you have the proper interface or pipe specified.%s", open_err_str,
 	  libpcap_warn);
+      }
+      /*
+       * Else pipe (or file) does exist and pipe_open_live() has
+       * filled in errmsg
+       */
       goto error;
-    }
+    } else
+      /* pipe_open_live() succeeded; don't want
+         error message from pcap_open_live() */
+      open_err_str[0] = '\0';
 #endif
   }
 
@@ -1615,7 +1702,8 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
    * Catch SIGUSR1, so that we exit cleanly if the parent process
    * kills us with it due to the user selecting "Capture->Stop".
    */
-  signal(SIGUSR1, stop_capture);
+  if (capture_child)
+    signal(SIGUSR1, stop_capture);
 #endif
   /* initialize capture stop conditions */ 
   init_capture_stop_conditions();
@@ -1636,16 +1724,25 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
       FD_SET(pipe_fd, &set1);
       timeout.tv_sec = 0;
       timeout.tv_usec = CAP_READ_TIMEOUT*1000;
-      if (select(pipe_fd+1, &set1, NULL, NULL, &timeout) != 0) {
-	/*
-	 * "select()" says we can read from the pipe without blocking; go for
-	 * it. We are not sure we can read a whole record, but at least the
-	 * begninning of one. pipe_dispatch() will block reading the whole
-	 * record.
-	 */
-	inpkts = pipe_dispatch(pipe_fd, &ld, &hdr);
-      } else
+      sel_ret = select(pipe_fd+1, &set1, NULL, NULL, &timeout);
+      if (sel_ret <= 0) {
 	inpkts = 0;
+        if (sel_ret < 0 && errno != EINTR) {
+          snprintf(errmsg, sizeof(errmsg),
+            "Unexpected error from select: %s", strerror(errno));
+          popup_errmsg(errmsg);
+          ld.go = FALSE;
+        }
+      } else {
+	/*
+	 * "select()" says we can read from the pipe without blocking
+	 */
+	inpkts = pipe_dispatch(pipe_fd, &ld, &hdr, &rechdr, pcap_data,
+          errmsg, sizeof errmsg);
+	if (inpkts < 0) {
+	  ld.go = FALSE;
+        }
+      }
     }
     else
 #endif
@@ -1682,80 +1779,99 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
       FD_SET(pcap_fd, &set1);
       timeout.tv_sec = 0;
       timeout.tv_usec = CAP_READ_TIMEOUT*1000;
-      if (select(pcap_fd+1, &set1, NULL, NULL, &timeout) != 0) {
+      sel_ret = select(pcap_fd+1, &set1, NULL, NULL, &timeout);
+      if (sel_ret > 0) {
 	/*
 	 * "select()" says we can read from it without blocking; go for
 	 * it.
 	 */
-	inpkts = pcap_dispatch(pch, 1, capture_pcap_cb, (u_char *) &ld);
+	inpkts = pcap_dispatch(pch, 1, capture_pcap_cb, (guchar *) &ld);
 	if (inpkts < 0) {
 	  ld.pcap_err = TRUE;
 	  ld.go = FALSE;
 	}
-      } else
-	inpkts = 0;
+      } else {
+        inpkts = 0;
+        if (sel_ret < 0 && errno != EINTR) {
+          snprintf(errmsg, sizeof(errmsg),
+            "Unexpected error from select: %s", strerror(errno));
+          popup_errmsg(errmsg);
+          ld.go = FALSE;
+        }
+      }
 #else
-      inpkts = pcap_dispatch(pch, 1, capture_pcap_cb, (u_char *) &ld);
+      inpkts = pcap_dispatch(pch, 1, capture_pcap_cb, (guchar *) &ld);
       if (inpkts < 0) {
         ld.pcap_err = TRUE;
         ld.go = FALSE;
       }
 #endif
     }
-    if (inpkts > 0)
+
+    if (inpkts > 0) {
       ld.sync_packets += inpkts;
-    /* check capture stop conditons */
-    if (cnd_stop_timeout != NULL && cnd_eval(cnd_stop_timeout)) {
-      /* The specified capture time has elapsed; stop the capture. */
-      ld.go = FALSE;
-    } else if (cnd_stop_capturesize != NULL && cnd_eval(cnd_stop_capturesize, 
-                  (guint32)wtap_get_bytes_dumped(ld.pdh))){
-      /* Capture file reached its maximum size. */
-      if (capture_opts.ringbuffer_on) {
-        /* Switch to the next ringbuffer file */
-        if (ringbuf_switch_file(&cfile, &ld.pdh, &ld.err)) {
-          /* File switch succeeded: reset the condition */
-          cnd_reset(cnd_stop_capturesize);
+      /* check capture stop conditons */
+      if (cnd_stop_capturesize != NULL && cnd_eval(cnd_stop_capturesize, 
+                    (guint32)wtap_get_bytes_dumped(ld.pdh))){
+        /* Capture file reached its maximum size. */
+        if (capture_opts.ringbuffer_on) {
+          /* Switch to the next ringbuffer file */
+          if (ringbuf_switch_file(&cfile, &ld.pdh, &ld.err)) {
+            /* File switch succeeded: reset the condition */
+            cnd_reset(cnd_stop_capturesize);
+          } else {
+            /* File switch failed: stop here */
+            ld.go = FALSE;
+            continue;
+          }
         } else {
-          /* File switch failed: stop here */
+          /* no ringbuffer - just stop */
           ld.go = FALSE;
-          continue;
         }
-      } else {
-        /* no ringbuffer - just stop */
-        ld.go = FALSE;
       }
     }
+
     /* Only update once a second so as not to overload slow displays */
     cur_time = time(NULL);
     if (cur_time > upd_time) {
       upd_time = cur_time;
 
-      for (i = 0; i < N_COUNTS; i++) {
-          snprintf(label_str, sizeof(label_str), "%d",
-                   *counts[i].value_ptr);
+      if (ld.sync_packets) {
 
-          gtk_label_set(GTK_LABEL(counts[i].value), label_str);
+        for (i = 0; i < N_COUNTS; i++) {
+            snprintf(label_str, sizeof(label_str), "%d",
+                     *counts[i].value_ptr);
+  
+            gtk_label_set(GTK_LABEL(counts[i].value), label_str);
+  
+            snprintf(label_str, sizeof(label_str), "(%.1f%%)",
+                     pct(*counts[i].value_ptr, ld.counts.total));
+  
+            gtk_label_set(GTK_LABEL(counts[i].percent), label_str);
+        }
 
-          snprintf(label_str, sizeof(label_str), "(%.1f%%)",
-                   pct(*counts[i].value_ptr, ld.counts.total));
+        /* do sync here, too */
+        fflush(wtap_dump_file(ld.pdh));
+
+        if (capture_child) {
+	  /* This is the child process for a sync mode capture, so send
+	     our parent a message saying we've written out "ld.sync_packets"
+	     packets to the capture file. */
+	  char tmp[DECISIZE+1+1];
+	  sprintf(tmp, "%d%c", ld.sync_packets, SP_PACKET_COUNT);
+	  write(1, tmp, strlen(tmp));
+        }
+
+	ld.sync_packets = 0;
 
-          gtk_label_set(GTK_LABEL(counts[i].percent), label_str);
       }
 
-      /* do sync here, too */
-      fflush(wtap_dump_file(ld.pdh));
-      if (capture_child && ld.sync_packets) {
-	/* This is the child process for a sync mode capture, so send
-	   our parent a message saying we've written out "ld.sync_packets"
-	   packets to the capture file. */
-	char tmp[20];
-	sprintf(tmp, "%d%c", ld.sync_packets, SP_PACKET_COUNT);
-	write(1, tmp, strlen(tmp));
-	ld.sync_packets = 0;
+      if (cnd_stop_timeout != NULL && cnd_eval(cnd_stop_timeout)) {
+        /* The specified capture time has elapsed; stop the capture. */
+        ld.go = FALSE;
       }
     }
-  }
+  } /* while (ld.go) */
     
   /* delete stop conditions */
   if (cnd_stop_capturesize != NULL)
@@ -1766,29 +1882,18 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
   if (ld.pcap_err) {
     snprintf(errmsg, sizeof(errmsg), "Error while capturing packets: %s",
       pcap_geterr(pch));
-    if (capture_child) {
-      /* Tell the parent, so that they can pop up the message;
-         we're going to exit, so if we try to pop it up, either
-         it won't pop up or it'll disappear as soon as we exit. */
-      send_errmsg_to_parent(errmsg);
-    } else {
-     /* Just pop up the message ourselves. */
-     simple_dialog(ESD_TYPE_WARN, NULL, "%s", errmsg);
-    }
+    popup_errmsg(errmsg);
+#ifdef _WIN32
   }
+#else
+  } else if (ld.from_pipe && ld.pipe_err == PIPERR)
+      popup_errmsg(errmsg);
+#endif
 
   if (ld.err != 0) {
     get_capture_file_io_error(errmsg, sizeof(errmsg), cfile.save_file, ld.err,
 			      FALSE);
-    if (capture_child) {
-      /* Tell the parent, so that they can pop up the message;
-         we're going to exit, so if we try to pop it up, either
-         it won't pop up or it'll disappear as soon as we exit. */
-      send_errmsg_to_parent(errmsg);
-    } else {
-     /* Just pop up the message ourselves. */
-     simple_dialog(ESD_TYPE_WARN, NULL, "%s", errmsg);
-    }
+    popup_errmsg(errmsg);
 
     /* A write failed, so we've already told the user there's a problem;
        if the close fails, there's no point in telling them about that
@@ -1807,19 +1912,20 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
     if (!dump_ok) {
       get_capture_file_io_error(errmsg, sizeof(errmsg), cfile.save_file, err,
 				TRUE);
-      if (capture_child) {
-        /* Tell the parent, so that they can pop up the message;
-           we're going to exit, so if we try to pop it up, either
-           it won't pop up or it'll disappear as soon as we exit. */
-        send_errmsg_to_parent(errmsg);
-      } else {
-       /* Just pop up the message ourselves. */
-       simple_dialog(ESD_TYPE_WARN, NULL, "%s", errmsg);
-      }
+      popup_errmsg(errmsg);
     }
   }
+
 #ifndef _WIN32
-  if (ld.from_pipe)
+  /*
+   * XXX We exhibit different behaviour between normal mode and sync mode
+   * when the pipe is stdin and not already at EOF.  If we're a child, the
+   * parent's stdin isn't closed, so if the user starts another capture,
+   * pipe_open_live() will very likely not see the expected magic bytes and
+   * will say "Unrecognized libpcap format".  On the other hand, in normal
+   * mode, pipe_open_live() will say "End of file on pipe during open".
+   */
+  if (ld.from_pipe && pipe_fd >= 0)
     close(pipe_fd);
   else
 #endif
@@ -1830,7 +1936,7 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
       *stats_known = TRUE;
       if (capture_child) {
       	/* Let the parent process know. */
-	char tmp[20];
+	char tmp[DECISIZE+1+1];
 	sprintf(tmp, "%d%c", stats->ps_drop, SP_DROPS);
 	write(1, tmp, strlen(tmp));
       }
@@ -1838,15 +1944,7 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
       snprintf(errmsg, sizeof(errmsg),
 		"Can't get packet-drop statistics: %s",
 		pcap_geterr(pch));
-      if (capture_child) {
-        /* Tell the parent, so that they can pop up the message;
-           we're going to exit, so if we try to pop it up, either
-           it won't pop up or it'll disappear as soon as we exit. */
-        send_errmsg_to_parent(errmsg);
-      } else {
-       /* Just pop up the message ourselves. */
-       simple_dialog(ESD_TYPE_WARN, NULL, "%s", errmsg);
-      }
+      popup_errmsg(errmsg);
     }
     pcap_close(pch);
   }
@@ -1876,17 +1974,18 @@ error:
     g_free(cfile.save_file);
   }
   cfile.save_file = NULL;
-  if (capture_child) {
-    /* This is the child process for a sync mode capture.
-       Send the error message to our parent, so they can display a
-       dialog box containing it. */
-    send_errmsg_to_parent(errmsg);
-  } else {
-    /* Display the dialog box ourselves; there's no parent. */
-    simple_dialog(ESD_TYPE_CRIT, NULL, "%s", errmsg);
+  popup_errmsg(errmsg);
+
+#ifndef WIN32
+  if (ld.from_pipe) {
+    if (pipe_fd >= 0)
+      close(pipe_fd);
+  } else
+#endif
+  {
+    if (pch != NULL)
+      pcap_close(pch);
   }
-  if (pch != NULL && !ld.from_pipe)
-    pcap_close(pch);
 
   return FALSE;
 }
@@ -1949,11 +2048,25 @@ get_capture_file_io_error(char *errmsg, int errmsglen, const char *fname,
   }
 }
 
+static void
+popup_errmsg(const char *errmsg)
+{
+  if (capture_child) {
+    /* This is the child process for a sync mode capture.
+       Send the error message to our parent, so they can display a
+       dialog box containing it. */
+    send_errmsg_to_parent(errmsg);
+  } else {
+    /* Display the dialog box ourselves; there's no parent. */
+    simple_dialog(ESD_TYPE_CRIT, NULL, "%s", errmsg);
+  }
+}
+
 static void
 send_errmsg_to_parent(const char *errmsg)
 {
     int msglen = strlen(errmsg);
-    char lenbuf[10+1+1];
+    char lenbuf[DECISIZE+1+1];
 
     sprintf(lenbuf, "%u%c", msglen, SP_ERROR_MSG);
     write(1, lenbuf, strlen(lenbuf));
@@ -2012,9 +2125,11 @@ kill_capture_child(void)
 }
 
 static void
-capture_pcap_cb(u_char *user, const struct pcap_pkthdr *phdr,
-  const u_char *pd) {
+capture_pcap_cb(guchar *user, const struct pcap_pkthdr *phdr,
+  const guchar *pd)
+{
   struct wtap_pkthdr whdr;
+  union wtap_pseudo_header pseudo_header;
   loop_data *ld = (loop_data *) user;
   int err;
 
@@ -2022,60 +2137,73 @@ capture_pcap_cb(u_char *user, const struct pcap_pkthdr *phdr,
   {
      ld->go = FALSE;
   }
-  if (ld->pdh) {
-     /* "phdr->ts" may not necessarily be a "struct timeval" - it may
-        be a "struct bpf_timeval", with member sizes wired to 32
-	bits - and we may go that way ourselves in the future, so
-	copy the members individually. */
-     whdr.ts.tv_sec = phdr->ts.tv_sec;
-     whdr.ts.tv_usec = phdr->ts.tv_usec;
-     whdr.caplen = phdr->caplen;
-     whdr.len = phdr->len;
-     whdr.pkt_encap = ld->linktype;
 
-     /* If this fails, set "ld->go" to FALSE, to stop the capture, and set
-        "ld->err" to the error. */
-     if (!wtap_dump(ld->pdh, &whdr, NULL, pd, &err)) {
-       ld->go = FALSE;
-       ld->err = err;
-     }
+  /* Convert from libpcap to Wiretap format.
+     If that fails, set "ld->go" to FALSE, to stop the capture, and set
+     "ld->err" to the error. */
+  pd = wtap_process_pcap_packet(ld->linktype, phdr, pd, &pseudo_header,
+				&whdr, &err);
+  if (pd == NULL) {
+    ld->go = FALSE;
+    ld->err = err;
+    return;
+  }
+
+  if (ld->pdh) {
+    /* We're supposed to write the packet to a file; do so.
+       If this fails, set "ld->go" to FALSE, to stop the capture, and set
+       "ld->err" to the error. */
+    if (!wtap_dump(ld->pdh, &whdr, &pseudo_header, pd, &err)) {
+      ld->go = FALSE;
+      ld->err = err;
+    }
   }
 
   switch (ld->linktype) {
     case WTAP_ENCAP_ETHERNET:
-      capture_eth(pd, 0, phdr->len, &ld->counts);
+      capture_eth(pd, 0, whdr.caplen, &ld->counts);
       break;
     case WTAP_ENCAP_FDDI:
     case WTAP_ENCAP_FDDI_BITSWAPPED:
-      capture_fddi(pd, phdr->len, &ld->counts);
+      capture_fddi(pd, whdr.caplen, &ld->counts);
       break;
     case WTAP_ENCAP_PRISM_HEADER:
-      capture_prism(pd, 0, phdr->len, &ld->counts);
+      capture_prism(pd, 0, whdr.caplen, &ld->counts);
       break;
     case WTAP_ENCAP_TOKEN_RING:
-      capture_tr(pd, 0, phdr->len, &ld->counts);
+      capture_tr(pd, 0, whdr.caplen, &ld->counts);
       break;
     case WTAP_ENCAP_NULL:
-      capture_null(pd, phdr->len, &ld->counts);
+      capture_null(pd, whdr.caplen, &ld->counts);
       break;
     case WTAP_ENCAP_PPP:
-      capture_ppp_hdlc(pd, 0, phdr->len, &ld->counts);
+      capture_ppp_hdlc(pd, 0, whdr.caplen, &ld->counts);
       break;
     case WTAP_ENCAP_RAW_IP:
-      capture_raw(pd, phdr->len, &ld->counts);
+      capture_raw(pd, whdr.caplen, &ld->counts);
       break;
     case WTAP_ENCAP_SLL:
-      capture_sll(pd, phdr->len, &ld->counts);
+      capture_sll(pd, whdr.caplen, &ld->counts);
       break;
     case WTAP_ENCAP_LINUX_ATM_CLIP:
-      capture_clip(pd, phdr->len, &ld->counts);
+      capture_clip(pd, whdr.caplen, &ld->counts);
+      break;
+    case WTAP_ENCAP_IEEE_802_11:
+    case WTAP_ENCAP_IEEE_802_11_WITH_RADIO:
+      capture_ieee80211(pd, 0, whdr.caplen, &ld->counts);
+      break;
+    case WTAP_ENCAP_CHDLC:
+      capture_chdlc(pd, 0, whdr.caplen, &ld->counts);
       break;
     case WTAP_ENCAP_LOCALTALK:
       capture_llap(&ld->counts);
       break;
-    /* XXX - FreeBSD may append 4-byte ATM pseudo-header to DLT_ATM_RFC1483,
-       with LLC header following; we should implement it at some
-       point. */
+    case WTAP_ENCAP_ATM_SNIFFER:
+      capture_atm(&pseudo_header, pd, whdr.caplen, &ld->counts);
+      break;
+    /* XXX - some ATM drivers on FreeBSD might prepend a 4-byte ATM
+       pseudo-header to DLT_ATM_RFC1483, with LLC header following;
+       we might have to implement that at some point. */
   }
 }
 
