@@ -1,7 +1,7 @@
 /* Edit capture files.  We can delete records, adjust timestamps, or
  * simply convert from one format to another format.
  *
- * $Id: editcap.c,v 1.22 2002/03/31 20:39:08 guy Exp $
+ * $Id: editcap.c,v 1.25 2002/08/02 23:35:46 jmayer Exp $
  *
  * Originally written by Richard Sharpe.
  * Improved by Guy Harris.
@@ -24,10 +24,6 @@
 #include <sys/time.h>
 #endif
 
-#ifdef HAVE_WINSOCK_H
-#include <winsock.h>
-#endif
-
 #include <string.h>
 #include "wtap.h"
 
@@ -53,8 +49,8 @@ struct time_adjustment {
   int is_negative;
 };
 
-struct select_item selectfrm[100];
-int max_selected = -1;
+static struct select_item selectfrm[100];
+static int max_selected = -1;
 static int count = 1;
 static int keep_em = 0;
 static int out_file_type = WTAP_FILE_PCAP;   /* default to "libpcap"   */
@@ -65,7 +61,7 @@ static struct time_adjustment time_adj = {{0, 0}, 0}; /* no adjustment */
 
 /* Add a selection item, a simple parser for now */
 
-void add_selection(char *sel) 
+static void add_selection(char *sel) 
 {
   char *locn;
   char *next;
@@ -105,7 +101,7 @@ void add_selection(char *sel)
 
 /* Was the record selected? */
 
-int selected(int recno)
+static int selected(int recno)
 {
   int i = 0;
 
@@ -137,8 +133,8 @@ typedef struct {
  */
 
 static void
-edit_callback(u_char *user, const struct wtap_pkthdr *phdr, long offset _U_,
-    union wtap_pseudo_header *pseudo_header, const u_char *buf) 
+edit_callback(guchar *user, const struct wtap_pkthdr *phdr, long offset _U_,
+    union wtap_pseudo_header *pseudo_header, const guchar *buf) 
 {
   callback_arg *argp = (callback_arg *)user;
   int err;
@@ -272,7 +268,7 @@ set_time_adjustment(char *optarg)
   time_adj.tv.tv_usec = val;
 }
 
-void usage()
+static void usage()
 {
   int i;
   const char *string;
