@@ -1,7 +1,7 @@
 /* column-utils.c
  * Routines for column utilities.
  *
- * $Id: column-utils.c,v 1.13 2002/01/31 08:03:39 guy Exp $
+ * $Id: column-utils.c,v 1.17 2002/08/02 21:29:39 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -29,10 +29,6 @@
 #include <string.h>
 #include <time.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #ifdef NEED_SNPRINTF_H
 # include "snprintf.h"
 #endif
@@ -430,11 +426,6 @@ col_set_addr(packet_info *pinfo, int col, address *addr, gboolean is_res,
       ipx_addr_to_str(pntohl(&addr->data[0]), &addr->data[4]), COL_MAX_LEN);
     pinfo->cinfo->col_buf[col][COL_MAX_LEN - 1] = '\0';
     pinfo->cinfo->col_data[col] = pinfo->cinfo->col_buf[col];
-    if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "ipx.src");
-    else
-      strcpy(pinfo->cinfo->col_expr[col], "ipx.dst");
-    strcpy(pinfo->cinfo->col_expr_val[col],pinfo->cinfo->col_buf[col]);
     break;
 
   case AT_SNA:
@@ -464,7 +455,12 @@ col_set_addr(packet_info *pinfo, int col, address *addr, gboolean is_res,
     strncpy(pinfo->cinfo->col_buf[col], atalk_addr_to_str(&ddp_addr),
       COL_MAX_LEN);
     pinfo->cinfo->col_buf[col][COL_MAX_LEN - 1] = '\0';
+    if (is_src)
+      strcpy(pinfo->cinfo->col_expr[col], "ddp.src");
+    else
+      strcpy(pinfo->cinfo->col_expr[col], "ddp.dst");
     pinfo->cinfo->col_data[col] = pinfo->cinfo->col_buf[col];
+    strcpy(pinfo->cinfo->col_expr_val[col],pinfo->cinfo->col_buf[col]);
     break;
 
   case AT_VINES:
@@ -527,6 +523,16 @@ col_set_port(packet_info *pinfo, int col, port_type ptype, guint32 port,
     pinfo->cinfo->col_expr_val[col][COL_MAX_LEN - 1] = '\0';
     break;
 
+  case PT_DDP:
+    if (is_src)
+      strcpy(pinfo->cinfo->col_expr[col], "ddp.src_socket");
+    else
+      strcpy(pinfo->cinfo->col_expr[col], "ddp.dst_socket");
+    snprintf(pinfo->cinfo->col_buf[col], COL_MAX_LEN, "%u", port);
+    snprintf(pinfo->cinfo->col_expr_val[col], COL_MAX_LEN, "%u", port);
+    pinfo->cinfo->col_expr_val[col][COL_MAX_LEN - 1] = '\0';
+    break;
+
   default:
     break;
   }
