@@ -1,5 +1,5 @@
 /*
- * $Id: dfilter.c,v 1.7 2002/01/21 07:37:37 guy Exp $
+ * $Id: dfilter.c,v 1.10 2002/05/09 23:50:30 gram Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -38,17 +38,10 @@
 #include "dfvm.h"
 #include <epan/epan_dissect.h>
 
-
-/* Balanced tree of abbreviations and IDs */
-GTree *dfilter_tokens = NULL;
-
 #define DFILTER_TOKEN_ID_OFFSET	1
 
-/* Comparision function for tree insertion. A wrapper around strcmp() */
-static int g_strcmp(gconstpointer a, gconstpointer b);
-
 /* Global error message space for dfilter_compile errors */
-gchar dfilter_error_msg_buf[1024];
+static gchar dfilter_error_msg_buf[1024];
 gchar *dfilter_error_msg;	/* NULL when no error resulted */
 
 /* In proto.c */
@@ -61,7 +54,7 @@ void    df_scanner_cleanup(void);
 int     df_lex(void);
 
 /* Holds the singular instance of our Lemon parser object */
-void*		ParserObj = NULL;
+static void*	ParserObj = NULL;
 
 void
 dfilter_fail(char *format, ...)
@@ -85,68 +78,6 @@ dfilter_fail(char *format, ...)
 void
 dfilter_init(void)
 {
-	int 			id, num_symbols;
-	char 			*abbrev;
-	header_field_info	*hfinfo, *same_name_hfinfo, *same_name_next_hfinfo;
-
-	num_symbols = proto_registrar_n();
-
-	if (dfilter_tokens) {
-		/* XXX - needed? */
-		g_message("I expected hf_ids to be NULL\n");
-		g_tree_destroy(dfilter_tokens);
-
-		/* Make sure the hfinfo->same_name links are broken */
-		for (id = 0; id < num_symbols; id++) {
-			hfinfo = proto_registrar_get_nth(id);
-			hfinfo->same_name_next = NULL;
-			hfinfo->same_name_prev = NULL;
-		}
-	}
-	dfilter_tokens = g_tree_new(g_strcmp);
-
-	/* Populate the abbrev/ID GTree (header-field symbol table) */
-
-	
-	for (id = 0; id < num_symbols; id++) {
-		if (id == hf_text_only) {
-			continue;
-		}
-		abbrev = proto_registrar_get_abbrev(id);
-		hfinfo = proto_registrar_get_nth(id);
-
-		g_assert(abbrev);		/* Not Null */
-		g_assert(abbrev[0] != 0);	/* Not empty string */
-
-		/* We allow multiple hfinfo's to be registered under the same
-		 * abbreviation. This was done for X.25, as, depending
-		 * on whether it's modulo-8 or modulo-128 operation,
-		 * some bitfield fields may be in different bits of
-		 * a byte, and we want to be able to refer to that field
-		 * with one name regardless of whether the packets
-		 * are modulo-8 or modulo-128 packets. */
-		same_name_hfinfo = g_tree_lookup(dfilter_tokens, abbrev);
-		if (same_name_hfinfo) {
-			/* There's already a field with this name.
-			 * Put it after that field in the list of
-			 * fields with this name, then allow the code
-			 * after this if{} block to replace the old
-			 * hfinfo with the new hfinfo in the GTree. Thus,
-			 * we end up with a linked-list of same-named hfinfo's,
-			 * with the root of the list being the hfinfo in the GTree */
-			same_name_next_hfinfo =
-			    same_name_hfinfo->same_name_next;
-
-			hfinfo->same_name_next = same_name_next_hfinfo;
-			if (same_name_next_hfinfo)
-				same_name_next_hfinfo->same_name_prev = hfinfo;
-
-			same_name_hfinfo->same_name_next = hfinfo;
-			hfinfo->same_name_prev = same_name_hfinfo;
-		}
-		g_tree_insert(dfilter_tokens, abbrev, hfinfo);
-	}
-
 	if (ParserObj) {
 		g_message("I expected ParserObj to be NULL\n");
 		/* Free the Lemon Parser object */
@@ -163,12 +94,6 @@ dfilter_init(void)
 void
 dfilter_cleanup(void)
 {
-	/* Free the abbrev/ID GTree */
-	if (dfilter_tokens) {
-		g_tree_destroy(dfilter_tokens);
-		dfilter_tokens = NULL;
-	}
-
 	/* Free the Lemon Parser object */
 	if (ParserObj) {
 		DfilterFree(ParserObj, g_free);
@@ -178,24 +103,6 @@ dfilter_cleanup(void)
 	sttype_cleanup();
 }
 
-
-
-/* Lookup an abbreviation in our token tree, returing the ID #
- * If the abbreviation doesn't exit, returns -1 */
-header_field_info*
-dfilter_lookup_token(char *abbrev)
-{
-	g_assert(abbrev != NULL);
-	return g_tree_lookup(dfilter_tokens, abbrev);
-}
-
-/* String comparison func for dfilter_token GTree */
-static int
-g_strcmp(gconstpointer a, gconstpointer b)
-{
-	return strcmp((const char*)a, (const char*)b);
-}
-
 static dfilter_t*
 dfilter_new(void)
 {
@@ -377,26 +284,25 @@ FAILURE:
 
 
 gboolean
-dfilter_apply(dfilter_t *df, tvbuff_t *tvb, proto_tree *tree)
+dfilter_apply(dfilter_t *df, proto_tree *tree)
 {
-	return dfvm_apply(df, tvb, tree);
+	return dfvm_apply(df, tree);
 }
 
 gboolean
 dfilter_apply_edt(dfilter_t *df, epan_dissect_t* edt)
 {
-	return dfvm_apply(df, edt->tvb, edt->tree);
+	return dfvm_apply(df, edt->tree);
 }
 
 
 void
-dfilter_foreach_interesting_field(dfilter_t *df, GFunc func,
-        gpointer user_data)
+dfilter_prime_proto_tree(dfilter_t *df, proto_tree *tree)
 {
     int i;
 
     for (i = 0; i < df->num_interesting_fields; i++) {
-        func(GINT_TO_POINTER(df->interesting_fields[i]), user_data);
+        proto_tree_prime_hfid(tree, df->interesting_fields[i]);
     }
 }
                 
