@@ -1,7 +1,7 @@
 /* filesystem.c
  * Filesystem utility routines
  *
- * $Id: filesystem.c,v 1.17 2002/03/02 20:48:10 guy Exp $
+ * $Id: filesystem.c,v 1.19 2002/08/02 21:29:39 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -37,10 +37,6 @@
 #include <unistd.h>
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
@@ -195,6 +191,20 @@ test_for_directory(const char *path)
 		return 0;
 }
 
+int
+test_for_fifo(const char *path)
+{
+	struct stat statb;
+
+	if (stat(path, &statb) < 0)
+		return errno;
+
+	if (S_ISFIFO(statb.st_mode))
+		return ESPIPE;
+	else
+		return 0;
+}
+
 /*
  * Get the directory in which Ethereal's global configuration and data
  * files are stored.
