@@ -1,7 +1,7 @@
 /* ftypes.h
  * Definitions for field types
  *
- * $Id: ftypes.h,v 1.10 2002/05/09 23:50:32 gram Exp $
+ * $Id: ftypes.h,v 1.12 2002/08/02 21:29:45 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -113,10 +113,6 @@ ftype_can_le(enum ftenum ftype);
 
 #include <epan/ipv4.h>
 
-#ifdef HAVE_WINSOCK_H
-#include <winsock.h>
-#endif
-
 #include <epan/tvbuff.h>
 #include <epan/nstime.h>
 #include <epan/dfilter/drange.h>
