@@ -1,7 +1,7 @@
 /* packet.h
  * Definitions for packet disassembly structures and routines
  *
- * $Id: packet.h,v 1.56 2002/05/09 23:50:28 gram Exp $
+ * $Id: packet.h,v 1.58 2002/08/02 21:29:39 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -266,22 +266,23 @@ final_registration_all_protocols(void);
  * Add a new data source to the list of data sources for a frame, given
  * the tvbuff for the data source and its name.
  */
-extern void add_new_data_source(frame_data *fd, tvbuff_t *tvb, char *name);
+extern void add_new_data_source(packet_info *pinfo, tvbuff_t *tvb,
+    char *name);
 
 /*
  * Free up a frame's list of data sources.
  */
-extern void free_data_sources(frame_data *fd);
+extern void free_data_sources(packet_info *pinfo);
 
 /*
  * Dissectors should never modify the packet data.
  */
 extern void dissect_packet(epan_dissect_t *edt,
-    union wtap_pseudo_header *pseudo_header, const u_char *pd,
+    union wtap_pseudo_header *pseudo_header, const guchar *pd,
     frame_data *fd, column_info *cinfo);
 
 /* These functions are in packet-ethertype.c */
-extern void capture_ethertype(guint16 etype, const u_char *pd, int offset,
+extern void capture_ethertype(guint16 etype, const guchar *pd, int offset,
 		int len, packet_counts *ld);
 extern void ethertype(guint16 etype, tvbuff_t *tvb, int offset_after_ethertype,
 		packet_info *pinfo, proto_tree *tree, proto_tree *fh_tree,
