@@ -1,7 +1,7 @@
 /* plugins.c
  * plugin routines
  *
- * $Id: plugins.c,v 1.54 2002/05/14 10:39:29 guy Exp $
+ * $Id: plugins.c,v 1.58 2002/08/14 19:18:15 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -26,6 +26,10 @@
 # include "config.h"
 #endif
 
+#ifdef NEED_SNPRINTF_H
+# include "snprintf.h"
+#endif
+
 #include "plugins.h"
 
 #ifdef HAVE_PLUGINS
@@ -48,10 +52,6 @@
 #include <sys/stat.h>
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -455,6 +455,15 @@ init_plugins(const char *plugin_dir)
 	patable.p_decode_boolean_bitfield	= decode_boolean_bitfield;
 	patable.p_decode_numeric_bitfield	= decode_numeric_bitfield;
 	patable.p_decode_enumerated_bitfield	= decode_enumerated_bitfield;
+	patable.p_register_dissector_table	= register_dissector_table;
+	patable.p_except_throw			= except_throw;
+	patable.p_dissector_try_port		= dissector_try_port;
+
+	patable.p_conversation_add_proto_data	= conversation_add_proto_data;
+	patable.p_conversation_get_proto_data	= conversation_get_proto_data;
+	patable.p_conversation_delete_proto_data = conversation_delete_proto_data;
+	patable.p_p_add_proto_data		= p_add_proto_data;
+	patable.p_p_get_proto_data		= p_get_proto_data;
 #endif
 
 #ifdef WIN32
