@@ -1,7 +1,7 @@
 /* proto.c
  * Routines for protocol tree
  *
- * $Id: proto.c,v 1.69 2002/05/14 10:15:10 guy Exp $
+ * $Id: proto.c,v 1.72 2002/08/18 19:08:30 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -26,10 +26,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <glib.h>
@@ -2175,7 +2171,7 @@ proto_register_field_init(header_field_info *hfinfo, int parent)
 	default:
 		break;
 	}
-	/* if this is a bitfield, compure bitshift */
+	/* if this is a bitfield, compute bitshift */
 	if (hfinfo->bitmask) {
 		while ((hfinfo->bitmask & (1 << hfinfo->bitshift)) == 0)
 			hfinfo->bitshift++;
@@ -3048,8 +3044,8 @@ proto_registrar_dump_fields(void)
 			g_assert(parent_hfinfo);
 
 			enum_name = ftype_name(hfinfo->type);
-			printf("F\t%s\t%s\t%s\t%s\n", hfinfo->name, hfinfo->abbrev,
-				enum_name,parent_hfinfo->abbrev);
+			printf("F\t%s\t%s\t%s\t%s\t%s\n", hfinfo->name, hfinfo->abbrev,
+				enum_name,parent_hfinfo->abbrev, hfinfo->blurb);
 		}
 	}
 }
