@@ -1,7 +1,7 @@
 /* proto.h
  * Definitions for protocol display
  *
- * $Id: proto.h,v 1.32 2002/05/14 10:15:10 guy Exp $
+ * $Id: proto.h,v 1.34 2002/08/02 21:29:39 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -31,10 +31,6 @@
 # include <varargs.h>
 #endif
 
-#ifdef HAVE_WINSOCK_H
-# include <winsock.h>
-#endif
-
 #include <glib.h>
 
 #include "ipv4.h"
