@@ -1,12 +1,11 @@
 /* strutil.h
  * String utility definitions
  *
- * $Id: strutil.h,v 1.6 2000/12/22 12:05:36 gram Exp $
+ * $Id: strutil.h,v 1.8 2002/08/02 21:29:40 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,19 +27,11 @@
 
 /* ... thus, config.h needs to be #included */
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>	/* for u_char */
-#endif
-
-#ifdef HAVE_WINSOCK_H
-# include <winsock.h>	/* for u_char */
-#endif
-
-const u_char *find_line_end(const u_char *data, const u_char *dataend,
-    const u_char **eol);
-int        get_token_len(const u_char *linep, const u_char *lineend,
-    const u_char **next_token);
-gchar*     format_text(const u_char *line, int len);
+const guchar *find_line_end(const guchar *data, const guchar *dataend,
+    const guchar **eol);
+int        get_token_len(const guchar *linep, const guchar *lineend,
+    const guchar **next_token);
+gchar*     format_text(const guchar *line, int len);
 gchar*     bytes_to_str(const guint8 *, int);
 gchar*     bytes_to_str_punct(const guint8 *, int, gchar punct);
 #endif /* __STRUTIL_H__ */
