@@ -1,7 +1,7 @@
 /* file.c
  * File I/O routines
  *
- * $Id: file.c,v 1.272 2002/05/03 21:55:12 guy Exp $
+ * $Id: file.c,v 1.285 2002/08/02 23:35:46 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -60,14 +60,6 @@
 #include "strerror.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <epan/epan.h>
 #include <epan/filesystem.h>
 
@@ -197,7 +189,7 @@ open_cap_file(char *fname, gboolean is_tempfile, capture_file *cf)
 
 fail:
   simple_dialog(ESD_TYPE_CRIT, NULL,
-			file_open_error_message(err, FALSE), fname);
+			file_open_error_message(err, FALSE, 0), fname);
   return (err);
 }
 
@@ -317,12 +309,13 @@ read_cap_file(capture_file *cf, int *err)
   char        errmsg_errno[1024+1];
   gchar       err_str[2048+1];
   long        data_offset;
-  progdlg_t  *progbar;
+  progdlg_t  *progbar = NULL;
   gboolean    stop_flag;
   int         file_pos;
   float       prog_val;
   int         fd;
   struct stat cf_stat;
+  GTimeVal    start_time;
 
   name_ptr = get_basename(cf->filename);
 
@@ -344,8 +337,7 @@ read_cap_file(capture_file *cf, int *err)
   freeze_clist(cf);
 
   stop_flag = FALSE;
-  progbar = create_progress_dlg(load_msg, "Stop", &stop_flag);
-  g_free(load_msg);
+  g_get_current_time(&start_time);
 
   while ((wtap_read(cf->wth, err, &data_offset))) {
     /* Update the progress bar, but do it only N_PROGBAR_UPDATES times;
@@ -371,7 +363,15 @@ read_cap_file(capture_file *cf, int *err)
           if (prog_val > 1.0)
             prog_val = 1.0;
         }
-        update_progress_dlg(progbar, prog_val);
+        if (progbar == NULL) {
+          /* Create the progress bar if necessary */
+          progbar = delayed_create_progress_dlg(load_msg, "Stop",
+            &stop_flag, &start_time, prog_val);
+          if (progbar != NULL)
+            g_free(load_msg);
+        }
+        if (progbar != NULL)
+          update_progress_dlg(progbar, prog_val);
         cf->progbar_nextstep += cf->progbar_quantum;
     }
 
@@ -388,8 +388,11 @@ read_cap_file(capture_file *cf, int *err)
     read_packet(cf, data_offset);
   }
 
-  /* We're done reading the file; destroy the progress bar. */
-  destroy_progress_dlg(progbar);
+  /* We're done reading the file; destroy the progress bar if it was created. */
+  if (progbar == NULL)
+    g_free(load_msg);
+  else
+    destroy_progress_dlg(progbar);
 
   /* We're done reading sequentially through the file. */
   cf->state = FILE_READ_DONE;
@@ -636,7 +639,7 @@ apply_color_filter(gpointer filter_arg, gpointer argp)
 
 static int
 add_packet_to_packet_list(frame_data *fdata, capture_file *cf,
-	union wtap_pseudo_header *pseudo_header, const u_char *buf,
+	union wtap_pseudo_header *pseudo_header, const guchar *buf,
 	gboolean refilter)
 {
   apply_color_filter_args args;
@@ -786,7 +789,7 @@ read_packet(capture_file *cf, long offset)
 {
   const struct wtap_pkthdr *phdr = wtap_phdr(cf->wth);
   union wtap_pseudo_header *pseudo_header = wtap_pseudoheader(cf->wth);
-  const u_char *buf = wtap_buf_ptr(cf->wth);
+  const guchar *buf = wtap_buf_ptr(cf->wth);
   frame_data   *fdata;
   int           passed;
   frame_data   *plist_end;
@@ -798,7 +801,6 @@ read_packet(capture_file *cf, long offset)
   fdata->next = NULL;
   fdata->prev = NULL;
   fdata->pfd  = NULL;
-  fdata->data_src  = NULL;
   fdata->pkt_len  = phdr->len;
   fdata->cap_len  = phdr->caplen;
   fdata->file_off = offset;
@@ -912,15 +914,15 @@ rescan_packets(capture_file *cf, const char *action, gboolean refilter,
 		gboolean redissect)
 {
   frame_data *fdata;
-  progdlg_t *progbar;
-  gboolean stop_flag;
-  guint32 progbar_quantum;
-  guint32 progbar_nextstep;
-  unsigned int count;
-  int err;
+  progdlg_t  *progbar = NULL;
+  gboolean    stop_flag;
+  long        count;
+  int         err;
   frame_data *selected_frame;
-  int selected_row;
-  int row;
+  int         selected_row;
+  int         row;
+  float       prog_val;
+  GTimeVal    start_time;
 
   /* Which frame, if any, is the currently selected frame?
      XXX - should the selected frame or the focus frame be the "current"
@@ -962,15 +964,15 @@ rescan_packets(capture_file *cf, const char *action, gboolean refilter,
   prevusec = 0;
 
   /* Update the progress bar when it gets to this value. */
-  progbar_nextstep = 0;
+  cf->progbar_nextstep = 0;
   /* When we reach the value that triggers a progress bar update,
      bump that value by this amount. */
-  progbar_quantum = cf->count/N_PROGBAR_UPDATES;
+  cf->progbar_quantum = cf->count/N_PROGBAR_UPDATES;
   /* Count of packets at which we've looked. */
   count = 0;
 
   stop_flag = FALSE;
-  progbar = create_progress_dlg(action, "Stop", &stop_flag);
+  g_get_current_time(&start_time);
 
   for (fdata = cf->plist; fdata != NULL; fdata = fdata->next) {
     /* Update the progress bar, but do it only N_PROGBAR_UPDATES times;
@@ -978,15 +980,22 @@ rescan_packets(capture_file *cf, const char *action, gboolean refilter,
        to repaint what's pending, and doing so may involve an "ioctl()"
        to see if there's any pending input from an X server, and doing
        that for every packet can be costly, especially on a big file. */
-    if (count >= progbar_nextstep) {
+    if (count >= cf->progbar_nextstep) {
       /* let's not divide by zero. I should never be started
        * with count == 0, so let's assert that
        */
       g_assert(cf->count > 0);
+      prog_val = (gfloat) count / cf->count;
 
-      update_progress_dlg(progbar, (gfloat) count / cf->count);
+      if (progbar == NULL)
+        /* Create the progress bar if necessary */
+        progbar = delayed_create_progress_dlg(action, "Stop", &stop_flag,
+          &start_time, prog_val);
 
-      progbar_nextstep += progbar_quantum;
+      if (progbar != NULL)
+        update_progress_dlg(progbar, prog_val);
+
+      cf->progbar_nextstep += cf->progbar_quantum;
     }
 
     if (stop_flag) {
@@ -1017,7 +1026,6 @@ rescan_packets(capture_file *cf, const char *action, gboolean refilter,
 	g_slist_free(fdata->pfd);
         fdata->pfd = NULL;
       }
-      free_data_sources(fdata);	/* release data source list */
     }
 
     /* XXX - do something with "err" */
@@ -1046,12 +1054,13 @@ rescan_packets(capture_file *cf, const char *action, gboolean refilter,
 	g_slist_free(fdata->pfd);
         fdata->pfd = NULL;
       }
-      free_data_sources(fdata);	/* release data source list */
     }
   }
 
-  /* We're done filtering the packets; destroy the progress bar. */
-  destroy_progress_dlg(progbar);
+  /* We're done filtering the packets; destroy the progress bar if it
+     was created. */
+  if (progbar != NULL)
+    destroy_progress_dlg(progbar);
 
   /* Unfreeze the packet list. */
   gtk_clist_thaw(GTK_CLIST(packet_list));
@@ -1074,11 +1083,9 @@ print_packets(capture_file *cf, print_args_t *print_args)
 {
   int         i;
   frame_data *fdata;
-  progdlg_t  *progbar;
+  progdlg_t  *progbar = NULL;
   gboolean    stop_flag;
-  guint32     progbar_quantum;
-  guint32     progbar_nextstep;
-  guint32     count;
+  long        count;
   int         err;
   gint       *col_widths = NULL;
   gint        data_width;
@@ -1089,6 +1096,8 @@ print_packets(capture_file *cf, print_args_t *print_args)
   int         column_len;
   int         line_len;
   epan_dissect_t *edt = NULL;
+  float       prog_val;
+  GTimeVal    start_time;
 
   cf->print_fh = open_print_dest(print_args->to_file, print_args->dest);
   if (cf->print_fh == NULL)
@@ -1125,7 +1134,7 @@ print_packets(capture_file *cf, print_args_t *print_args)
 
       /* Make sure there's room in the line buffer for the column; if not,
          double its length. */
-      line_len += column_len + 1;	/* "+1" for space or \n */
+      line_len += column_len + 1;	/* "+1" for space */
       if (line_len > line_buf_len) {
         line_buf_len *= 2;
         line_buf = g_realloc(line_buf, line_buf_len + 1);
@@ -1137,27 +1146,25 @@ print_packets(capture_file *cf, print_args_t *print_args)
       else
         sprintf(cp, "%-*s", col_widths[i], cf->cinfo.col_title[i]);
       cp += column_len;
-      if (i == cf->cinfo.num_cols - 1)
-        *cp++ = '\n';
-      else
+      if (i != cf->cinfo.num_cols - 1)
         *cp++ = ' ';
     }
     *cp = '\0';
-    print_line(cf->print_fh, print_args->format, line_buf);
+    print_line(cf->print_fh, 0, print_args->format, line_buf);
   }
 
   print_separator = FALSE;
 
   /* Update the progress bar when it gets to this value. */
-  progbar_nextstep = 0;
+  cf->progbar_nextstep = 0;
   /* When we reach the value that triggers a progress bar update,
      bump that value by this amount. */
-  progbar_quantum = cf->count/N_PROGBAR_UPDATES;
+  cf->progbar_quantum = cf->count/N_PROGBAR_UPDATES;
   /* Count of packets at which we've looked. */
   count = 0;
 
   stop_flag = FALSE;
-  progbar = create_progress_dlg("Printing", "Stop", &stop_flag);
+  g_get_current_time(&start_time);
 
   /* Iterate through the list of packets, printing the packets that
      were selected by the current display filter.  */
@@ -1167,15 +1174,22 @@ print_packets(capture_file *cf, print_args_t *print_args)
        to repaint what's pending, and doing so may involve an "ioctl()"
        to see if there's any pending input from an X server, and doing
        that for every packet can be costly, especially on a big file. */
-    if (count >= progbar_nextstep) {
+    if (count >= cf->progbar_nextstep) {
       /* let's not divide by zero. I should never be started
        * with count == 0, so let's assert that
        */
       g_assert(cf->count > 0);
+      prog_val = (gfloat) count / cf->count;
 
-      update_progress_dlg(progbar, (gfloat) count / cf->count);
+      if (progbar == NULL)
+        /* Create the progress bar if necessary */
+        progbar = delayed_create_progress_dlg("Printing", "Stop", &stop_flag,
+          &start_time, prog_val);
 
-      progbar_nextstep += progbar_quantum;
+      if (progbar != NULL)
+        update_progress_dlg(progbar, prog_val);
+
+      cf->progbar_nextstep += cf->progbar_quantum;
     }
 
     if (stop_flag) {
@@ -1213,7 +1227,7 @@ print_packets(capture_file *cf, print_args_t *print_args)
 
           /* Make sure there's room in the line buffer for the column; if not,
              double its length. */
-          line_len += column_len + 1;	/* "+1" for space or \n */
+          line_len += column_len + 1;	/* "+1" for space */
           if (line_len > line_buf_len) {
             line_buf_len *= 2;
             line_buf = g_realloc(line_buf, line_buf_len + 1);
@@ -1225,16 +1239,14 @@ print_packets(capture_file *cf, print_args_t *print_args)
           else
             sprintf(cp, "%-*s", col_widths[i], cf->cinfo.col_data[i]);
           cp += column_len;
-          if (i == cf->cinfo.num_cols - 1)
-            *cp++ = '\n';
-          else
+          if (i != cf->cinfo.num_cols - 1)
             *cp++ = ' ';
         }
         *cp = '\0';
-        print_line(cf->print_fh, print_args->format, line_buf);
+        print_line(cf->print_fh, 0, print_args->format, line_buf);
       } else {
         if (print_separator)
-          print_line(cf->print_fh, print_args->format, "\n");
+          print_line(cf->print_fh, 0, print_args->format, "");
 
         /* Create the logical protocol tree, complete with the display
            representation of the items; we don't need the columns here,
@@ -1243,12 +1255,11 @@ print_packets(capture_file *cf, print_args_t *print_args)
         epan_dissect_run(edt, &cf->pseudo_header, cf->pd, fdata, NULL);
 
         /* Print the information in that tree. */
-        proto_tree_print(print_args, (GNode *)edt->tree,
-			fdata, cf->print_fh);
+        proto_tree_print(print_args, edt, cf->print_fh);
 
 	if (print_args->print_hex) {
 	  /* Print the full packet data as hex. */
-	  print_hex_data(cf->print_fh, print_args->format, fdata);
+	  print_hex_data(cf->print_fh, print_args->format, edt);
 	}
 
         /* Print a blank line if we print anything after this. */
@@ -1258,8 +1269,10 @@ print_packets(capture_file *cf, print_args_t *print_args)
     }
   }
 
-  /* We're done printing the packets; destroy the progress bar. */
-  destroy_progress_dlg(progbar);
+  /* We're done printing the packets; destroy the progress bar if
+     it was created. */
+  if (progbar != NULL)
+    destroy_progress_dlg(progbar);
 
   if (col_widths != NULL)
     g_free(col_widths);
@@ -1282,14 +1295,14 @@ void
 change_time_formats(capture_file *cf)
 {
   frame_data *fdata;
-  progdlg_t *progbar;
-  gboolean stop_flag;
-  guint32 progbar_quantum;
-  guint32 progbar_nextstep;
-  unsigned int count;
-  int row;
-  int i;
-  GtkStyle  *pl_style;
+  progdlg_t  *progbar = NULL;
+  gboolean    stop_flag;
+  long        count;
+  int         row;
+  int         i;
+  GtkStyle   *pl_style;
+  float       prog_val;
+  GTimeVal    start_time;
 
   /* Are there any columns with time stamps in the "command-line-specified"
      format?
@@ -1308,15 +1321,15 @@ change_time_formats(capture_file *cf)
   freeze_clist(cf);
 
   /* Update the progress bar when it gets to this value. */
-  progbar_nextstep = 0;
+  cf->progbar_nextstep = 0;
   /* When we reach the value that triggers a progress bar update,
      bump that value by this amount. */
-  progbar_quantum = cf->count/N_PROGBAR_UPDATES;
+  cf->progbar_quantum = cf->count/N_PROGBAR_UPDATES;
   /* Count of packets at which we've looked. */
   count = 0;
 
   stop_flag = FALSE;
-  progbar = create_progress_dlg("Changing time display", "Stop", &stop_flag);
+  g_get_current_time(&start_time);
 
   /* Iterate through the list of packets, checking whether the packet
      is in a row of the summary list and, if so, whether there are
@@ -1328,15 +1341,23 @@ change_time_formats(capture_file *cf)
        to repaint what's pending, and doing so may involve an "ioctl()"
        to see if there's any pending input from an X server, and doing
        that for every packet can be costly, especially on a big file. */
-    if (count >= progbar_nextstep) {
+    if (count >= cf->progbar_nextstep) {
       /* let's not divide by zero. I should never be started
        * with count == 0, so let's assert that
        */
       g_assert(cf->count > 0);
 
-      update_progress_dlg(progbar, (gfloat) count / cf->count);
+      prog_val = (gfloat) count / cf->count;
 
-      progbar_nextstep += progbar_quantum;
+      if (progbar == NULL)
+        /* Create the progress bar if necessary */
+        progbar = delayed_create_progress_dlg("Changing time display", "Stop",
+          &stop_flag, &start_time, prog_val);
+
+      if (progbar != NULL)
+        update_progress_dlg(progbar, prog_val);
+
+      cf->progbar_nextstep += cf->progbar_quantum;
     }
 
     if (stop_flag) {
@@ -1369,8 +1390,10 @@ change_time_formats(capture_file *cf)
     }
   }
 
-  /* We're done redisplaying the packets; destroy the progress bar. */
-  destroy_progress_dlg(progbar);
+  /* We're done redisplaying the packets; destroy the progress bar if it
+     was created. */
+  if (progbar != NULL)
+    destroy_progress_dlg(progbar);
 
   /* Set the column widths of those columns that show the time in
      "command-line-specified" format. */
@@ -1392,15 +1415,15 @@ find_packet(capture_file *cf, dfilter_t *sfcode)
   frame_data *start_fd;
   frame_data *fdata;
   frame_data *new_fd = NULL;
-  progdlg_t *progbar = NULL;
-  gboolean stop_flag;
-  guint32 progbar_quantum;
-  guint32 progbar_nextstep;
-  unsigned int count;
-  int err;
-  gboolean frame_matched;
-  int row;
+  progdlg_t  *progbar = NULL;
+  gboolean    stop_flag;
+  long        count;
+  int         err;
+  gboolean    frame_matched;
+  int         row;
   epan_dissect_t	*edt;
+  float       prog_val;
+  GTimeVal    start_time;
 
   start_fd = cf->current_frame;
   if (start_fd != NULL)  {
@@ -1410,18 +1433,13 @@ find_packet(capture_file *cf, dfilter_t *sfcode)
     count = 0;
     fdata = start_fd;
 
-    /* Update the progress bar when it gets to this value.  We start at
-       20, not 0, so that we don't get a progress bar until we've
-       checked at least that many frames, so that a very quick search
-       doesn't pop up and immediately destroy a progress bar.
-
-       XXX - should use a timer?  Like 50 ms. */
-    progbar_nextstep = 20;
+    cf->progbar_nextstep = 0;
     /* When we reach the value that triggers a progress bar update,
        bump that value by this amount. */
-    progbar_quantum = cf->count/N_PROGBAR_UPDATES;
+    cf->progbar_quantum = cf->count/N_PROGBAR_UPDATES;
 
     stop_flag = FALSE;
+    g_get_current_time(&start_time);
 
     fdata = start_fd;
     for (;;) {
@@ -1430,21 +1448,23 @@ find_packet(capture_file *cf, dfilter_t *sfcode)
          to repaint what's pending, and doing so may involve an "ioctl()"
          to see if there's any pending input from an X server, and doing
          that for every packet can be costly, especially on a big file. */
-      if (count >= progbar_nextstep) {
+      if (count >= cf->progbar_nextstep) {
         /* let's not divide by zero. I should never be started
          * with count == 0, so let's assert that
          */
         g_assert(cf->count > 0);
 
-        /* Create the progress bar if it doesn't exist; we don't create it
-           immediately, so that we don't have it appear and immediately
-           disappear if the search is quick. */
-        if (progbar == NULL)
-           progbar = create_progress_dlg("Searching", "Cancel", &stop_flag);
-        
-        update_progress_dlg(progbar, (gfloat) count / cf->count);
+        prog_val = (gfloat) count / cf->count;
 
-        progbar_nextstep += progbar_quantum;
+        /* Create the progress bar if necessary */
+        if (progbar == NULL)
+           progbar = delayed_create_progress_dlg("Searching", "Cancel",
+             &stop_flag, &start_time, prog_val);
+        
+        if (progbar != NULL)
+          update_progress_dlg(progbar, prog_val);
+
+        cf->progbar_nextstep += cf->progbar_quantum;
       }
 
       if (stop_flag) {
@@ -1493,8 +1513,8 @@ find_packet(capture_file *cf, dfilter_t *sfcode)
       }
     }
 
-    /* We're done scanning the packets; destroy the progress bar, if
-       we created it. */
+    /* We're done scanning the packets; destroy the progress bar if it
+       was created. */
     if (progbar != NULL)
       destroy_progress_dlg(progbar);
   }
@@ -1597,8 +1617,7 @@ select_packet(capture_file *cf, int row)
   /* Display the GUI protocol tree and hex dump.
      XXX - why do we dump core if we call "proto_tree_draw()"
      before calling "add_byte_views()"? */
-  add_byte_views(cf->current_frame, cf->edt->tree, tree_view,
-      byte_nb_ptr);
+  add_byte_views(cf->edt, tree_view, byte_nb_ptr);
   proto_tree_draw(cf->edt->tree, tree_view);
 
   /* A packet is selected. */
@@ -1713,9 +1732,16 @@ thaw_clist(capture_file *cf)
     gtk_clist_set_column_resizeable(GTK_CLIST(packet_list), i, TRUE);
 }
 
-int
-save_cap_file(char *fname, capture_file *cf, gboolean save_filtered, gboolean save_marked,
-		guint save_format)
+/*
+ * Save a capture to a file, in a particular format, saving either
+ * all packets, all currently-displayed packets, or all marked packets.
+ *
+ * Returns TRUE if it succeeds, FALSE otherwise; if it fails, it pops
+ * up a message box for the failure.
+ */
+gboolean
+save_cap_file(char *fname, capture_file *cf, gboolean save_filtered,
+		gboolean save_marked, guint save_format)
 {
   gchar        *from_filename;
   gchar        *name_ptr, *save_msg, *save_fmt = " Saving: %s...";
@@ -1727,6 +1753,7 @@ save_cap_file(char *fname, capture_file *cf, gboolean save_filtered, gboolean sa
   struct wtap_pkthdr hdr;
   union wtap_pseudo_header pseudo_header;
   guint8        pd[65536];
+  struct stat   infile, outfile;
 
   name_ptr = get_basename(fname);
   msg_len = strlen(name_ptr) + strlen(save_fmt) + 2;
@@ -1735,13 +1762,28 @@ save_cap_file(char *fname, capture_file *cf, gboolean save_filtered, gboolean sa
   statusbar_push_file_msg(save_msg);
   g_free(save_msg);
 
+  /* 
+   * Check that the from file is not the same as to file 
+   * We do it here so we catch all cases ...
+   * Unfortunately, the file requester gives us an absolute file
+   * name and the read file name may be relative (if supplied on
+   * the command line). From Joerg Mayer.
+   */
+   infile.st_ino = 1;   /* These prevent us from getting equality         */
+   outfile.st_ino = 2;  /* If one or other of the files is not accessible */
+   stat(cf->filename, &infile);
+   stat(fname, &outfile);
+   if (infile.st_ino == outfile.st_ino) {
+    simple_dialog(ESD_TYPE_CRIT, NULL, 
+		      "Can't save over current capture file: %s!",
+		      cf->filename);
+    goto fail;
+  }
+
   if (!save_filtered && !save_marked && save_format == cf->cd_t) {
     /* We're not filtering packets, and we're saving it in the format
        it's already in, so we can just move or copy the raw data. */
 
-    /* In this branch, we set "err" only if we get an error, so we
-       must first clear it. */
-    err = 0;
     if (cf->is_tempfile) {
       /* The file being saved is a temporary file from a live
          capture, so it doesn't need to stay around under that name;
@@ -1765,10 +1807,9 @@ save_cap_file(char *fname, capture_file *cf, gboolean save_filtered, gboolean sa
 	     be if we didn't have permission to remove the file from
 	     the temporary directory, and that might be fixable - but
 	     is it worth requiring the user to go off and fix it?) */
-	  err = errno;
 	  simple_dialog(ESD_TYPE_CRIT, NULL,
-				file_rename_error_message(err), fname);
-	  goto done;
+				file_rename_error_message(errno), fname);
+	  goto fail;
 	}
       }
 #else
@@ -1782,20 +1823,10 @@ save_cap_file(char *fname, capture_file *cf, gboolean save_filtered, gboolean sa
       from_filename = cf->filename;
     }
 
-    /* Check that the from file is not the same as to file */
-
     if (do_copy) {
-
-            /* Copy the file, if we haven't moved it. */
-	    if (strncmp(from_filename, fname, sizeof(cf->filename)) == 0) {
-		    simple_dialog(ESD_TYPE_WARN, NULL, 
-				  "Can't save over current capture file: %s!", from_filename);
-		    goto done;
-	    }
-
-	    if (!copy_binary_file(from_filename, fname)) {
-		goto done;
-	    }
+      /* Copy the file, if we haven't moved it. */
+      if (!copy_binary_file(from_filename, fname))
+	goto fail;
     }
   } else {
     /* Either we're filtering packets, or we're saving in a different
@@ -1804,8 +1835,8 @@ save_cap_file(char *fname, capture_file *cf, gboolean save_filtered, gboolean sa
     pdh = wtap_dump_open(fname, save_format, cf->lnk_t, cf->snap, &err);
     if (pdh == NULL) {
       simple_dialog(ESD_TYPE_CRIT, NULL,
-			file_open_error_message(err, TRUE), fname);
-      goto done;
+			file_open_error_message(err, TRUE, save_format), fname);
+      goto fail;
     }
 
     /* XXX - have a way to save only the packets currently selected by
@@ -1834,17 +1865,17 @@ save_cap_file(char *fname, capture_file *cf, gboolean save_filtered, gboolean sa
         hdr.pkt_encap = fdata->lnk_t;
 	if (!wtap_seek_read(cf->wth, fdata->file_off, &pseudo_header,
 		pd, fdata->cap_len, &err)) {
-	    simple_dialog(ESD_TYPE_CRIT, NULL,
+	  simple_dialog(ESD_TYPE_CRIT, NULL,
 				file_read_error_message(err), cf->filename);
-	    wtap_dump_close(pdh, &err);
-	    goto done;
+	  wtap_dump_close(pdh, &err);
+          goto fail;
 	}
 
         if (!wtap_dump(pdh, &hdr, &pseudo_header, pd, &err)) {
-	    simple_dialog(ESD_TYPE_CRIT, NULL,
+	  simple_dialog(ESD_TYPE_CRIT, NULL,
 				file_write_error_message(err), fname);
-	    wtap_dump_close(pdh, &err);
-	    goto done;
+	  wtap_dump_close(pdh, &err);
+          goto fail;
 	}
       }
     }
@@ -1852,55 +1883,57 @@ save_cap_file(char *fname, capture_file *cf, gboolean save_filtered, gboolean sa
     if (!wtap_dump_close(pdh, &err)) {
       simple_dialog(ESD_TYPE_WARN, NULL,
 		file_close_error_message(err), fname);
-      goto done;
+      goto fail;
     }
   }
 
-done:
-
   /* Pop the "Saving:" message off the status bar. */
   statusbar_pop_file_msg();
-  if (err == 0) {
-    if (!save_filtered && !save_marked) {
-      /* We saved the entire capture, not just some packets from it.
-         Open and read the file we saved it to.
+  if (!save_filtered && !save_marked) {
+    /* We saved the entire capture, not just some packets from it.
+       Open and read the file we saved it to.
 
-	 XXX - this is somewhat of a waste; we already have the
-	 packets, all this gets us is updated file type information
-	 (which we could just stuff into "cf"), and having the new
-	 file be the one we have opened and from which we're reading
-	 the data, and it means we have to spend time opening and
-	 reading the file, which could be a significant amount of
-	 time if the file is large. */
-      cf->user_saved = TRUE;
+       XXX - this is somewhat of a waste; we already have the
+       packets, all this gets us is updated file type information
+       (which we could just stuff into "cf"), and having the new
+       file be the one we have opened and from which we're reading
+       the data, and it means we have to spend time opening and
+       reading the file, which could be a significant amount of
+       time if the file is large. */
+    cf->user_saved = TRUE;
 
-      if ((err = open_cap_file(fname, FALSE, cf)) == 0) {
-	/* XXX - report errors if this fails? */
-	switch (read_cap_file(cf, &err)) {
+    if ((err = open_cap_file(fname, FALSE, cf)) == 0) {
+      /* XXX - report errors if this fails?
+         What should we return if it fails or is aborted? */
+      switch (read_cap_file(cf, &err)) {
 
-	case READ_SUCCESS:
-	case READ_ERROR:
-	  /* Just because we got an error, that doesn't mean we were unable
-	     to read any of the file; we handle what we could get from the
-	     file. */
-	  break;
+      case READ_SUCCESS:
+      case READ_ERROR:
+	/* Just because we got an error, that doesn't mean we were unable
+	   to read any of the file; we handle what we could get from the
+	   file. */
+	break;
 
-	case READ_ABORTED:
-	  /* The user bailed out of re-reading the capture file; the
-	     capture file has been closed - just return (without
-	     changing any menu settings; "close_cap_file()" set them
-	     correctly for the "no capture file open" state). */
-	  return 0;
-	}
-	set_menus_for_unsaved_capture_file(FALSE);
+      case READ_ABORTED:
+	/* The user bailed out of re-reading the capture file; the
+	   capture file has been closed - just return (without
+	   changing any menu settings; "close_cap_file()" set them
+	   correctly for the "no capture file open" state). */
+	break;
       }
+      set_menus_for_unsaved_capture_file(FALSE);
     }
   }
-  return err;
+  return TRUE;
+
+fail:
+  /* Pop the "Saving:" message off the status bar. */
+  statusbar_pop_file_msg();
+  return FALSE;
 }
 
 char *
-file_open_error_message(int err, gboolean for_writing)
+file_open_error_message(int err, gboolean for_writing, int file_type)
 {
   char *errmsg;
   static char errmsg_errno[1024+1];
@@ -1911,12 +1944,25 @@ file_open_error_message(int err, gboolean for_writing)
     errmsg = "The file \"%s\" is a \"special file\" or socket or other non-regular file.";
     break;
 
+  case WTAP_ERR_RANDOM_OPEN_PIPE:
+    /* Seen only when opening a capture file for reading. */
+    errmsg = "The file \"%s\" is a pipe or FIFO; Ethereal cannot read pipe or FIFO files.";
+    break;
+
   case WTAP_ERR_FILE_UNKNOWN_FORMAT:
   case WTAP_ERR_UNSUPPORTED:
     /* Seen only when opening a capture file for reading. */
     errmsg = "The file \"%s\" is not a capture file in a format Ethereal understands.";
     break;
 
+  case WTAP_ERR_CANT_WRITE_TO_PIPE:
+    /* Seen only when opening a capture file for writing. */
+    snprintf(errmsg_errno, sizeof(errmsg_errno),
+	     "The file \"%%s\" is a pipe, and %s capture files cannot be "
+	     "written to a pipe.", wtap_file_type_string(file_type));
+    errmsg = errmsg_errno;
+    break;
+
   case WTAP_ERR_UNSUPPORTED_FILE_TYPE:
     /* Seen only when opening a capture file for writing. */
     errmsg = "Ethereal does not support writing capture files in that format.";
@@ -1970,7 +2016,8 @@ file_open_error_message(int err, gboolean for_writing)
 
   default:
     snprintf(errmsg_errno, sizeof(errmsg_errno),
-		    "The file \"%%s\" could not be opened: %s.",
+		    "The file \"%%s\" could not be %s: %s.",
+				for_writing ? "created" : "opened",
 				wtap_strerror(err));
     errmsg = errmsg_errno;
     break;
@@ -2101,7 +2148,7 @@ copy_binary_file(char *from_filename, char *to_filename)
       if (from_fd < 0) {
       	err = errno;
 	simple_dialog(ESD_TYPE_CRIT, NULL,
-			file_open_error_message(err, TRUE), from_filename);
+			file_open_error_message(err, TRUE, 0), from_filename);
 	goto done;
       }
 
@@ -2114,7 +2161,7 @@ copy_binary_file(char *from_filename, char *to_filename)
       if (to_fd < 0) {
       	err = errno;
 	simple_dialog(ESD_TYPE_CRIT, NULL,
-			file_open_error_message(err, TRUE), to_filename);
+			file_open_error_message(err, TRUE, 0), to_filename);
 	close(from_fd);
 	goto done;
       }
