@@ -1,7 +1,7 @@
 /* capture_prefs.c
  * Dialog box for capture preferences
  *
- * $Id: capture_prefs.c,v 1.9 2002/03/05 11:55:58 guy Exp $
+ * $Id: capture_prefs.c,v 1.13 2002/07/17 00:22:30 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -26,6 +26,8 @@
 #include "config.h"
 #endif
 
+#ifdef HAVE_LIBPCAP
+
 #include <string.h>
 #include <errno.h>
 #include <gtk/gtk.h>
@@ -43,8 +45,6 @@
 #include "pcap-util.h"
 #include "main.h"
 
-#ifdef HAVE_LIBPCAP
-
 #define DEVICE_KEY		"device"
 #define PROM_MODE_KEY		"prom_mode"
 #define CAPTURE_REAL_TIME_KEY	"capture_real_time"
@@ -124,7 +124,6 @@ capture_prefs_fetch(GtkWidget *w)
 {
 	GtkWidget *if_cb, *promisc_cb, *sync_cb, *auto_scroll_cb;
 	gchar	*if_text;
-	gchar	*if_name;
 
 	if_cb = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(w), DEVICE_KEY);
 	promisc_cb = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(w),
@@ -138,12 +137,18 @@ capture_prefs_fetch(GtkWidget *w)
 		g_free(prefs.capture_device);
 		prefs.capture_device = NULL;
 	}
-	if_text =
-	    g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(if_cb)->entry)));
-	if_name = strtok(if_text, " \t");
-	if (if_name != NULL)
-		prefs.capture_device = g_strdup(if_name);
-	g_free(if_text);
+
+	if_text = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(if_cb)->entry)));
+	/* Strip out white space */
+	g_strstrip(if_text);
+	/* If there was nothing but white space, treat that as an
+	   indication that the user doesn't want to wire in a default
+	   device, and just wants the first device in the list chosen. */
+	if (*if_text == '\0') {
+		g_free(if_text);
+		if_text = NULL;
+	}
+	prefs.capture_device = if_text;
 
 	prefs.capture_prom_mode = GTK_TOGGLE_BUTTON (promisc_cb)->active;
 
@@ -162,25 +167,4 @@ capture_prefs_destroy(GtkWidget *w _U_)
 {
 }
 
-#else /* HAVE_LIBPCAP */
-
-/*
- * Stub routines.
- */
-
-void
-capture_prefs_apply(GtkWidget *w)
-{
-}
-
-void
-capture_prefs_destroy(GtkWidget *w)
-{
-}
-
-void
-capture_prefs_fetch(GtkWidget *w)
-{
-}
-
 #endif /* HAVE_LIBPCAP */
