@@ -1,7 +1,7 @@
 /* display_opts.c
  * Routines for packet display windows
  *
- * $Id: display_opts.c,v 1.26 2002/03/05 11:55:58 guy Exp $
+ * $Id: display_opts.c,v 1.28 2002/08/02 22:34:53 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -26,10 +26,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <gtk/gtk.h>
 
 #include <stdlib.h>
@@ -46,10 +42,6 @@
 # include <sys/sockio.h>
 #endif
 
-#ifdef NEED_SNPRINTF_H
-# include "snprintf.h"
-#endif
-
 #include "globals.h"
 #include <epan/resolv.h>
 #include <epan/timestamp.h>
