@@ -1,6 +1,6 @@
 /* main.c
  *
- * $Id: main.c,v 1.249 2002/05/14 18:27:28 guy Exp $
+ * $Id: main.c,v 1.257 2002/08/02 22:34:53 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -52,10 +52,6 @@
 
 #include <errno.h>
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
@@ -68,10 +64,6 @@
 #include <direct.h>
 #endif
 
-#ifdef HAVE_NETINET_IN_H
-#include <netinet/in.h>
-#endif
-
 #include <signal.h>
 
 #ifdef HAVE_LIBPCAP
@@ -760,6 +752,8 @@ tree_view_select_row_cb(GtkCTree *ctree, GList *node, gint column _U_, gpointer
 {
 	field_info	*finfo;
 	gchar		*help_str = NULL;
+	gchar		len_str[2+10+1+5+1];	/* ", {N} bytes\0",
+						   N < 4294967296 */
 	gboolean        has_blurb = FALSE;
 	guint           length = 0, byte_len;
 	GtkWidget	*byte_view;
@@ -786,13 +780,20 @@ tree_view_select_row_cb(GtkCTree *ctree, GList *node, gint column _U_, gpointer
 	  } else {
 	    length = strlen(finfo->hfinfo->name);
 	  }
+	  if (finfo->length == 0) {
+	    len_str[0] = '\0';
+	  } else if (finfo->length == 1) {
+	    strcpy (len_str, ", 1 byte");
+	  } else {
+	    snprintf (len_str, sizeof len_str, ", %d bytes", finfo->length);
+	  }
 	  statusbar_pop_field_msg();	/* get rid of current help msg */
           if (length) {
-	    length += strlen(finfo->hfinfo->abbrev) + 10;
+	    length += strlen(finfo->hfinfo->abbrev) + strlen(len_str) + 10;
 	    help_str = g_malloc(sizeof(gchar) * length);
-	    sprintf(help_str, "%s (%s)", 
+	    sprintf(help_str, "%s (%s)%s", 
 	       (has_blurb) ? finfo->hfinfo->blurb : finfo->hfinfo->name,
-	       finfo->hfinfo->abbrev);
+	       finfo->hfinfo->abbrev, len_str);
 	    statusbar_push_field_msg(help_str);
 	    g_free(help_str);
           } else {
@@ -1066,12 +1067,14 @@ file_quit_cmd_cb (GtkWidget *widget _U_, gpointer data _U_)
 }
 
 static void 
-print_usage(void) {
+print_usage(gboolean print_ver) {
 
-  fprintf(stderr, "This is GNU " PACKAGE " " VERSION ", compiled %s\n",
+  if (print_ver) {
+    fprintf(stderr, "This is GNU " PACKAGE " " VERSION ", compiled %s\n",
 	  comp_info_str->str);
+  }  
 #ifdef HAVE_LIBPCAP
-  fprintf(stderr, "%s [ -vh ] [ -klpQS ] [ -a <capture autostop condition> ] ...\n",
+  fprintf(stderr, "\n%s [ -vh ] [ -klpQS ] [ -a <capture autostop condition> ] ...\n",
 	  PACKAGE);
   fprintf(stderr, "\t[ -b <number of ringbuffer files> ] [ -B <byte view height> ]\n");
   fprintf(stderr, "\t[ -c <count> ] [ -f <capture filter> ] [ -i <interface> ]\n");
@@ -1081,7 +1084,7 @@ print_usage(void) {
   fprintf(stderr, "\t[ -t <time stamp format> ] [ -T <tree view height> ]\n");
   fprintf(stderr, "\t[ -w <savefile> ] [ <infile> ]\n");
 #else
-  fprintf(stderr, "%s [ -vh ] [ -B <byte view height> ] [ -m <medium font> ]\n",
+  fprintf(stderr, "\n%s [ -vh ] [ -B <byte view height> ] [ -m <medium font> ]\n",
 	  PACKAGE);
   fprintf(stderr, "\t[ -n ] [ -N <resolving> ]\n");
   fprintf(stderr, "\t[ -o <preference setting> ... [ -P <packet list height> ]\n");
@@ -1140,7 +1143,7 @@ get_positive_int(const char *string, const char *name)
 static gboolean
 set_autostop_criterion(const char *autostoparg)
 {
-  u_char *p, *colonp;
+  guchar *p, *colonp;
 
   colonp = strchr(autostoparg, ':');
   if (colonp == NULL)
@@ -1202,7 +1205,7 @@ main(int argc, char *argv[])
 #endif
 
   char                *gpf_path, *cf_path, *df_path;
-  const char          *pf_path;
+  char                *pf_path;
   int                  gpf_open_errno, pf_open_errno, cf_open_errno, df_open_errno;
   int                  err;
 #ifdef HAVE_LIBPCAP
@@ -1225,6 +1228,20 @@ main(int argc, char *argv[])
   gint                 desk_x, desk_y;
   gboolean             prefs_write_needed = FALSE;
 
+#define OPTSTRING_INIT "a:b:B:c:f:hi:klm:nN:o:pP:Qr:R:Ss:t:T:w:v"
+
+#ifdef HAVE_LIBPCAP
+#ifdef WIN32
+#define OPTSTRING_CHILD "W:Z:"
+#else
+#define OPTSTRING_CHILD "W:"
+#endif  /* WIN32 */
+#else
+#define OPTSTRING_CHILD ""
+#endif  /* HAVE_LIBPCAP */
+
+  char optstring[sizeof(OPTSTRING_INIT) + sizeof(OPTSTRING_CHILD) - 1] =
+    OPTSTRING_INIT;
 
   ethereal_path = argv[0];
 
@@ -1251,6 +1268,8 @@ main(int argc, char *argv[])
   /* Set "capture_child" to indicate whether this is going to be a child
      process for a "-S" capture. */
   capture_child = (strcmp(command_name, CHILD_NAME) == 0);
+  if (capture_child)
+    strcat(optstring, OPTSTRING_CHILD);
 #endif
 
   /* Register all dissectors; we must do this before checking for the
@@ -1376,7 +1395,6 @@ main(int argc, char *argv[])
   cfile.has_snap	= FALSE;
   cfile.snap		= WTAP_MAX_PACKET_SIZE;
   cfile.count		= 0;
-  col_init(&cfile.cinfo, prefs->num_cols);
 
   /* Assemble the compile-time options */
   comp_info_str = g_string_new("");
@@ -1434,7 +1452,7 @@ main(int argc, char *argv[])
 #endif
 
   /* Now get our args */
-  while ((opt = getopt(argc, argv, "a:b:B:c:f:hi:klm:nN:o:pP:Qr:R:Ss:t:T:w:W:vZ:")) != -1) {
+  while ((opt = getopt(argc, argv, optstring)) != -1) {
     switch (opt) {
       case 'a':        /* autostop criteria */
 #ifdef HAVE_LIBPCAP
@@ -1480,7 +1498,7 @@ main(int argc, char *argv[])
 #endif
 	break;
       case 'h':        /* Print help and exit */
-	print_usage();
+	print_usage(TRUE);
 	exit(0);
         break;
       case 'i':        /* Use interface xxx */
@@ -1623,29 +1641,27 @@ main(int argc, char *argv[])
         arg_error = TRUE;
 #endif
 	break;
-      case 'W':        /* Write to capture file FD xxx */
 #ifdef HAVE_LIBPCAP
+      /* This is a hidden option supporting Sync mode, so we don't set
+       * the error flags for the user in the non-libpcap case.
+       */
+      case 'W':        /* Write to capture file FD xxx */
         cfile.save_file_fd = atoi(optarg);
-#else
-        capture_option_specified = TRUE;
-        arg_error = TRUE;
-#endif
 	break;
+#endif
 
 #ifdef _WIN32
-      case 'Z':        /* Write to pipe FD XXX */
 #ifdef HAVE_LIBPCAP
+      /* Hidden option supporting Sync mode */
+      case 'Z':        /* Write to pipe FD XXX */
         /* associate stdout with pipe */
         i = atoi(optarg);
         if (dup2(i, 1) < 0) {
           fprintf(stderr, "Unable to dup pipe handle\n");
           exit(1);
         }
-#else
-        capture_option_specified = TRUE;
-        arg_error = TRUE;
-#endif /* HAVE_LIBPCAP */
         break;
+#endif /* HAVE_LIBPCAP */
 #endif /* _WIN32 */
 
       default:
@@ -1684,8 +1700,13 @@ main(int argc, char *argv[])
     /*
      * Extra command line arguments were specified; complain.
      */
+    fprintf(stderr, "Invalid argument: %s\n", argv[0]);
     arg_error = TRUE;
   }
+  if (arg_error) {
+    print_usage(FALSE);
+    exit(1);
+  }
 
 #ifdef HAVE_LIBPCAP
   if (capture_opts.ringbuffer_on) {
@@ -1720,38 +1741,42 @@ main(int argc, char *argv[])
 
   /* Notify all registered modules that have had any of their preferences
      changed either from one of the preferences file or from the command
-     line that its preferences have changed. */
+     line that their preferences have changed. */
   prefs_apply_all();
 
 #ifndef HAVE_LIBPCAP
   if (capture_option_specified)
     fprintf(stderr, "This version of Ethereal was not built with support for capturing packets.\n");
 #endif
-  if (arg_error)
-    print_usage();
 #ifdef HAVE_LIBPCAP
   if (start_capture) {
     /* We're supposed to do a live capture; did the user specify an interface
        to use? */
     if (cfile.iface == NULL) {
-      /* No - pick the first one from the list of interfaces. */
-      if_list = get_interface_list(&err, err_str);
-      if (if_list == NULL) {
-        switch (err) {
-
-        case CANT_GET_INTERFACE_LIST:
-            fprintf(stderr, "ethereal: Can't get list of interfaces: %s\n",
-			err_str);
-            break;
-
-        case NO_INTERFACES_FOUND:
-            fprintf(stderr, "ethereal: There are no interfaces on which a capture can be done\n");
-            break;
+      /* No - is a default specified in the preferences file? */
+      if (prefs->capture_device != NULL) {
+          /* Yes - use it. */
+          cfile.iface = g_strdup(prefs->capture_device);
+      } else {
+        /* No - pick the first one from the list of interfaces. */
+        if_list = get_interface_list(&err, err_str);
+        if (if_list == NULL) {
+          switch (err) {
+  
+          case CANT_GET_INTERFACE_LIST:
+              fprintf(stderr, "ethereal: Can't get list of interfaces: %s\n",
+  			err_str);
+              break;
+  
+          case NO_INTERFACES_FOUND:
+              fprintf(stderr, "ethereal: There are no interfaces on which a capture can be done\n");
+              break;
+          }
+          exit(2);
         }
-        exit(2);
+        cfile.iface = g_strdup(if_list->data);	/* first interface */
+        free_interface_list(if_list);
       }
-      cfile.iface = g_strdup(if_list->data);	/* first interface */
-      free_interface_list(if_list);
     }
   }
   if (capture_child) {
@@ -1765,6 +1790,7 @@ main(int argc, char *argv[])
 #endif
 
   /* Build the column format array */  
+  col_init(&cfile.cinfo, prefs->num_cols);
   for (i = 0; i < cfile.cinfo.num_cols; i++) {
     cfile.cinfo.col_fmt[i] = get_column_format(i);
     cfile.cinfo.col_title[i] = g_strdup(get_column_title(i));
@@ -1851,7 +1877,7 @@ main(int argc, char *argv[])
     create_main_window(pl_size, tv_size, bv_size, prefs);
     set_menus_for_capture_file(FALSE);
 
-    cfile.colors = colfilter_new();
+    colfilter_init();
 
     /* If we were given the name of a capture file, read it in now;
        we defer it until now, so that, if we can't open it, and pop
@@ -1919,6 +1945,8 @@ main(int argc, char *argv[])
       simple_dialog(ESD_TYPE_WARN, NULL,
         "Could not open your preferences file\n\"%s\": %s.", pf_path,
         strerror(pf_open_errno));
+      g_free(pf_path);
+      pf_path = NULL;
   }
 
   /* If the user's capture filter file exists but we failed to open it,
@@ -2026,6 +2054,9 @@ main(int argc, char *argv[])
 		if (prefs_write_needed) {
 			write_prefs(&pf_path);
 		}
+	} else {
+		/* Ignore errors silently */
+		g_free(pf_path);
 	}
 	
   epan_cleanup();
@@ -2170,6 +2201,20 @@ boldify(const char *font_name)
 	/* Is this an XLFD font?  If it begins with "-", yes, otherwise no. */
 	if (font_name[0] == '-') {
 		xlfd_tokens = g_strsplit(font_name, "-", XLFD_WEIGHT+1);
+
+		/*
+		 * Make sure we *have* a weight (this might not be a valid
+		 * XLFD font name).
+		 */
+		for (i = 0; i < XLFD_WEIGHT+1; i++) {
+			if (xlfd_tokens[i] == NULL) {
+				/*
+				 * We don't, so treat this as a non-XLFD
+				 * font name.
+				 */
+				goto not_xlfd;
+			}
+		}
 		for (i = 0; i < N_WEIGHTS; i++) {
 			if (strcmp(xlfd_tokens[XLFD_WEIGHT],
 			    weight_map[i].light) == 0) {
@@ -2181,10 +2226,15 @@ boldify(const char *font_name)
 		}
 		bold_font_name = g_strjoinv("-", xlfd_tokens);
 		g_strfreev(xlfd_tokens);
-	} else {
-		/* Append "bold" to the name of the font. */
-		bold_font_name = g_strconcat(font_name, "bold", NULL);
+		return bold_font_name;
 	}
+
+not_xlfd:
+	/*
+	 * This isn't an XLFD font name; just append "bold" to the name
+	 * of the font.
+	 */
+	bold_font_name = g_strconcat(font_name, "bold", NULL);
 	return bold_font_name;
 }
 
