@@ -1,7 +1,7 @@
 /* prefs_dlg.c
  * Routines for handling preferences
  *
- * $Id: prefs_dlg.c,v 1.46 2002/04/20 20:29:28 guy Exp $
+ * $Id: prefs_dlg.c,v 1.51 2002/08/02 22:34:54 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -26,10 +26,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <gtk/gtk.h>
 
 #include <stdlib.h>
@@ -165,10 +161,10 @@ pref_show(pref_t *pref, gpointer user_data)
     break;
 
   case PREF_BOOL:
-    pref->saved_val.bool = *pref->varp.bool;
+    pref->saved_val.boolval = *pref->varp.boolp;
     pref->control = create_preference_check_button(main_tb, pref->ordinal,
 					       label_string, pref->description,
-					       pref->saved_val.bool);
+					       pref->saved_val.boolval);
     break;
 
   case PREF_ENUM:
@@ -249,7 +245,10 @@ prefs_cb(GtkWidget *w _U_, gpointer dummy _U_)
 {
   GtkWidget        *main_vb, *top_hb, *bbox, *prefs_nb, *ct_sb, *frame,
                    *ok_bt, *apply_bt, *save_bt, *cancel_bt;
-  GtkWidget        *print_pg, *column_pg, *stream_pg, *gui_pg, *capture_pg;
+  GtkWidget        *print_pg, *column_pg, *stream_pg, *gui_pg;
+#ifdef HAVE_LIBPCAP
+  GtkWidget        *capture_pg;
+#endif
   GtkWidget        *nameres_pg;
   gchar            label_str[MAX_TREE_NODE_NAME_LEN], *label_ptr = label_str;
   GtkCTreeNode     *ct_node;
@@ -715,9 +714,9 @@ pref_fetch(pref_t *pref, gpointer user_data)
 
   case PREF_BOOL:
     bval = GTK_TOGGLE_BUTTON(pref->control)->active;
-    if (*pref->varp.bool != bval) {
+    if (*pref->varp.boolp != bval) {
       *pref_changed_p = TRUE;
-      *pref->varp.bool = bval;
+      *pref->varp.boolp = bval;
     }
     break;
 
@@ -816,7 +815,16 @@ prefs_main_ok_cb(GtkWidget *ok_bt _U_, gpointer parent_w)
   column_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_COLUMN_PAGE_KEY));
   stream_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_STREAM_PAGE_KEY));
   gui_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_GUI_PAGE_KEY));
+#ifdef HAVE_LIBPCAP
+#ifdef _WIN32
+  /* Is WPcap loaded? */
+  if (has_wpcap) {
+#endif /* _WIN32 */
   capture_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_CAPTURE_PAGE_KEY));
+#ifdef _WIN32
+  }
+#endif /* _WIN32 */
+#endif /* HAVE_LIBPCAP */
   nameres_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_NAMERES_PAGE_KEY));
   prefs_module_foreach(module_prefs_fetch, &must_redissect);
 
@@ -825,7 +833,16 @@ prefs_main_ok_cb(GtkWidget *ok_bt _U_, gpointer parent_w)
   column_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_COLUMN_PAGE_KEY));
   stream_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_STREAM_PAGE_KEY));
   gui_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_GUI_PAGE_KEY));
+#ifdef HAVE_LIBPCAP
+#ifdef _WIN32
+  /* Is WPcap loaded? */
+  if (has_wpcap) {
+#endif /* _WIN32 */
   capture_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_CAPTURE_PAGE_KEY));
+#ifdef _WIN32
+  }
+#endif /* _WIN32 */
+#endif /* HAVE_LIBPCAP */
   nameres_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_NAMERES_PAGE_KEY));
   prefs_apply_all();
 
@@ -850,7 +867,16 @@ prefs_main_apply_cb(GtkWidget *apply_bt _U_, gpointer parent_w)
   column_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_COLUMN_PAGE_KEY));
   stream_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_STREAM_PAGE_KEY));
   gui_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_GUI_PAGE_KEY));
+#ifdef HAVE_LIBPCAP
+#ifdef _WIN32
+  /* Is WPcap loaded? */
+  if (has_wpcap) {
+#endif /* _WIN32 */
   capture_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_CAPTURE_PAGE_KEY));
+#ifdef _WIN32
+  }
+#endif /* _WIN32 */
+#endif /* HAVE_LIBPCAP */
   nameres_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_NAMERES_PAGE_KEY));
   prefs_module_foreach(module_prefs_fetch, &must_redissect);
 
@@ -859,7 +885,16 @@ prefs_main_apply_cb(GtkWidget *apply_bt _U_, gpointer parent_w)
   column_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_COLUMN_PAGE_KEY));
   stream_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_STREAM_PAGE_KEY));
   gui_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_GUI_PAGE_KEY));
+#ifdef HAVE_LIBPCAP
+#ifdef _WIN32
+  /* Is WPcap loaded? */
+  if (has_wpcap) {
+#endif /* _WIN32 */
   capture_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_CAPTURE_PAGE_KEY));
+#ifdef _WIN32
+  }
+#endif /* _WIN32 */
+#endif /* HAVE_LIBPCAP */
   nameres_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_NAMERES_PAGE_KEY));
   prefs_apply_all();
 
@@ -875,7 +910,7 @@ prefs_main_save_cb(GtkWidget *save_bt _U_, gpointer parent_w)
   gboolean must_redissect = FALSE;
   int err;
   char *pf_dir_path;
-  const char *pf_path;
+  char *pf_path;
 
   /* Fetch the preferences (i.e., make sure all the values set in all of
      the preferences panes have been copied to "prefs" and the registered
@@ -884,7 +919,16 @@ prefs_main_save_cb(GtkWidget *save_bt _U_, gpointer parent_w)
   column_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_COLUMN_PAGE_KEY));
   stream_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_STREAM_PAGE_KEY));
   gui_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_GUI_PAGE_KEY));
+#ifdef HAVE_LIBPCAP
+#ifdef _WIN32
+  /* Is WPcap loaded? */
+  if (has_wpcap) {
+#endif /* _WIN32 */
   capture_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_CAPTURE_PAGE_KEY));
+#ifdef _WIN32
+  }
+#endif /* _WIN32 */
+#endif /* HAVE_LIBPCAP */
   nameres_prefs_fetch(gtk_object_get_data(GTK_OBJECT(parent_w), E_NAMERES_PAGE_KEY));
   prefs_module_foreach(module_prefs_fetch, &must_redissect);
 
@@ -902,6 +946,7 @@ prefs_main_save_cb(GtkWidget *save_bt _U_, gpointer parent_w)
        simple_dialog(ESD_TYPE_WARN, NULL,
         "Can't open preferences file\n\"%s\": %s.", pf_path,
         strerror(err));
+       g_free(pf_path);
     }
   }
 
@@ -923,7 +968,16 @@ prefs_main_save_cb(GtkWidget *save_bt _U_, gpointer parent_w)
   column_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_COLUMN_PAGE_KEY));
   stream_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_STREAM_PAGE_KEY));
   gui_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_GUI_PAGE_KEY));
+#ifdef HAVE_LIBPCAP
+#ifdef _WIN32
+  /* Is WPcap loaded? */
+  if (has_wpcap) {
+#endif /* _WIN32 */
   capture_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_CAPTURE_PAGE_KEY));
+#ifdef _WIN32
+  }
+#endif /* _WIN32 */
+#endif /* HAVE_LIBPCAP */
   nameres_prefs_apply(gtk_object_get_data(GTK_OBJECT(parent_w), E_NAMERES_PAGE_KEY));
   prefs_apply_all();
 
@@ -949,9 +1003,9 @@ pref_revert(pref_t *pref, gpointer user_data)
     break;
 
   case PREF_BOOL:
-    if (*pref->varp.bool != pref->saved_val.bool) {
+    if (*pref->varp.boolp != pref->saved_val.boolval) {
       *pref_changed_p = TRUE;
-      *pref->varp.bool = pref->saved_val.bool;
+      *pref->varp.boolp = pref->saved_val.boolval;
     }
     break;
 
@@ -1046,7 +1100,16 @@ prefs_main_destroy_cb(GtkWidget *win _U_, gpointer user_data _U_)
   column_prefs_destroy(gtk_object_get_data(GTK_OBJECT(prefs_w), E_COLUMN_PAGE_KEY));
   stream_prefs_destroy(gtk_object_get_data(GTK_OBJECT(prefs_w), E_STREAM_PAGE_KEY));
   gui_prefs_destroy(gtk_object_get_data(GTK_OBJECT(prefs_w), E_GUI_PAGE_KEY));
+#ifdef HAVE_LIBPCAP
+#ifdef _WIN32
+  /* Is WPcap loaded? */
+  if (has_wpcap) {
+#endif /* _WIN32 */
   capture_prefs_destroy(gtk_object_get_data(GTK_OBJECT(prefs_w), E_CAPTURE_PAGE_KEY));
+#ifdef _WIN32
+  }
+#endif /* _WIN32 */
+#endif /* HAVE_LIBPCAP */
   nameres_prefs_destroy(gtk_object_get_data(GTK_OBJECT(prefs_w), E_NAMERES_PAGE_KEY));
 
   /* Free up the saved preferences (both for "prefs" and for registered
