@@ -2,7 +2,7 @@
  * 4.4-Lite-2 Internet checksum routine, modified to take a vector of
  * pointers/lengths giving the pieces to be checksummed.
  *
- * $Id: in_cksum.c,v 1.4 2001/06/09 01:02:29 guy Exp $
+ * $Id: in_cksum.c,v 1.8 2002/08/03 20:01:13 guy Exp $
  */
 
 /*
@@ -40,22 +40,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
-#ifdef HAVE_ARPA_INET_H
-#include <arpa/inet.h>
-#endif
-
-#ifdef HAVE_WINSOCK_H
-#include <winsock.h>
-#endif
-
 #include <glib.h>
 
 #include "in_cksum.h"
@@ -166,9 +150,9 @@ in_cksum(const vec_t *vec, int veclen)
 
 /*
  * Given the host-byte-order value of the checksum field in a packet
- * header, and the one's complement negation of the host-byte-order
- * checksum of the packet, compute what the checksum field *should*
- * have been.
+ * header, and the network-byte-order computed checksum of the data
+ * that the checksum covers (including the checksum itself), compute
+ * what the checksum field *should* have been.
  */
 guint16
 in_cksum_shouldbe(guint16 sum, guint16 computed_sum)
@@ -204,14 +188,13 @@ in_cksum_shouldbe(guint16 sum, guint16 computed_sum)
 	 * byte-swapped before being stuffed into a big-endian checksum
 	 * field.
 	 *
-	 * "computed_sum" is a host-byte-order value, so we must put
-	 * it in network byte order before subtracting it from the
-	 * network-byte-order value from the header; the adjusted
-	 * checksum will be in network byte order, which is what
-	 * we'll return.
+	 * "computed_sum" is a network-byte-order value, so we must put
+	 * it in host byte order before subtracting it from the
+	 * host-byte-order value from the header; the adjusted checksum
+	 * will be in host byte order, which is what we'll return.
 	 */
 	shouldbe = sum;
-	shouldbe += htons(computed_sum);
+	shouldbe += g_ntohs(computed_sum);
 	shouldbe = (shouldbe & 0xFFFF) + (shouldbe >> 16);
 	shouldbe = (shouldbe & 0xFFFF) + (shouldbe >> 16);
 	return shouldbe;
