@@ -8,7 +8,7 @@
  * Portions based on information/specs retrieved from the OpenAFS sources at
  *   www.openafs.org, Copyright IBM. 
  *
- * $Id: packet-afs-macros.h,v 1.12 2001/09/14 07:10:05 guy Exp $
+ * $Id: packet-afs-macros.h,v 1.18 2002/02/10 02:22:02 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -66,6 +66,28 @@
 		tvb_get_letohl(tvb, offset));\
 	offset += 4;
 
+/* Output a simple rx array */
+#define OUT_RXArray8(func) \
+	{ \
+		unsigned int j,i; \
+		j = tvb_get_guint8(tvb, offset); \
+		offset += 1; \
+		for (i=0; i<j; i++) { \
+			func; \
+		} \
+	}
+
+/* Output a simple rx array */
+#define OUT_RXArray32(func) \
+	{ \
+		unsigned int j,i; \
+		j = tvb_get_ntohl(tvb, offset); \
+		offset += sizeof(guint32); \
+		for (i=0; i<j; i++) { \
+			func; \
+		} \
+	}
+
 /* Output a UNIX seconds/microseconds timestamp, after converting to an
    nstime_t */
 #define OUT_TIMESTAMP(field) \
@@ -85,6 +107,38 @@
 	offset += 4; \
 	}
 
+/* Output a rx style string, up to a maximum length first 
+   4 bytes - length, then char data */
+#define OUT_RXString(field) \
+	{	int i,len; \
+		char *tmp; \
+		i = tvb_get_ntohl(tvb, offset); \
+		offset += 4; \
+		len = ((i+4-1)/4)*4; \
+		tmp = g_malloc(i+1); \
+		memcpy(tmp, tvb_get_ptr(tvb,offset,i), i); \
+		tmp[i] = '\0'; \
+		proto_tree_add_string(tree, field, tvb, offset-4, len+4, \
+		(void *)tmp); \
+		g_free(tmp); \
+		offset += len; \
+	}
+
+/* Output a fixed length vectorized string (each char is a 32 bit int) */
+#define OUT_RXStringV(field, length) \
+	{ 	char tmp[length+1]; \
+		int i,soff; \
+		soff = offset;\
+		for (i=0; i<length; i++)\
+		{\
+			tmp[i] = (char) tvb_get_ntohl(tvb, offset);\
+			offset += sizeof(guint32);\
+		}\
+		tmp[length] = '\0';\
+		proto_tree_add_string(tree, field, tvb, soff, length*sizeof(guint32), tmp);\
+	}
+
+
 /* Output a callback */
 #define OUT_FS_AFSCallBack() \
 	{ 	proto_tree *save, *ti; \
@@ -109,7 +163,6 @@
 		tree = save; \
 	}
 
-
 /* Output a File ID */
 #define OUT_FS_AFSFid(label) \
 	{ 	proto_tree *save, *ti; \
@@ -132,22 +185,45 @@
 			sizeof(guint32), mask); \
 		save = tree; \
 		tree = proto_item_add_subtree(ti, ett_afs_status_mask); \
-		proto_tree_add_uint(tree, hf_afs_fs_status_mask_setmodtime, \
+		proto_tree_add_boolean(tree, hf_afs_fs_status_mask_setmodtime, \
 			tvb,offset,sizeof(guint32), mask); \
-		proto_tree_add_uint(tree, hf_afs_fs_status_mask_setowner, \
+		proto_tree_add_boolean(tree, hf_afs_fs_status_mask_setowner, \
 			tvb,offset,sizeof(guint32), mask); \
-		proto_tree_add_uint(tree, hf_afs_fs_status_mask_setgroup, \
+		proto_tree_add_boolean(tree, hf_afs_fs_status_mask_setgroup, \
 			tvb,offset,sizeof(guint32), mask); \
-		proto_tree_add_uint(tree, hf_afs_fs_status_mask_setmode, \
+		proto_tree_add_boolean(tree, hf_afs_fs_status_mask_setmode, \
 			tvb,offset,sizeof(guint32), mask); \
-		proto_tree_add_uint(tree, hf_afs_fs_status_mask_setsegsize, \
+		proto_tree_add_boolean(tree, hf_afs_fs_status_mask_setsegsize, \
 			tvb,offset,sizeof(guint32), mask); \
-		proto_tree_add_uint(tree, hf_afs_fs_status_mask_fsync, \
+		proto_tree_add_boolean(tree, hf_afs_fs_status_mask_fsync, \
 			tvb,offset,sizeof(guint32), mask); \
 		offset += 4; \
 		tree = save; \
 	}
 
+/* Output vldb flags */
+#define OUT_VLDB_Flags() \
+	{ 	proto_tree *save, *ti; \
+		guint32 flags; \
+		flags = tvb_get_ntohl(tvb, offset); \
+		ti = proto_tree_add_uint(tree, hf_afs_vldb_flags, tvb, offset, \
+			sizeof(guint32), flags); \
+		save = tree; \
+		tree = proto_item_add_subtree(ti, ett_afs_vldb_flags); \
+		proto_tree_add_boolean(tree, hf_afs_vldb_flags_rwexists, \
+			tvb,offset,sizeof(guint32), flags); \
+		proto_tree_add_boolean(tree, hf_afs_vldb_flags_roexists, \
+			tvb,offset,sizeof(guint32), flags); \
+		proto_tree_add_boolean(tree, hf_afs_vldb_flags_bkexists, \
+			tvb,offset,sizeof(guint32), flags); \
+		proto_tree_add_boolean(tree, hf_afs_vldb_flags_dfsfileset, \
+			tvb,offset,sizeof(guint32), flags); \
+		offset += 4; \
+		tree = save; \
+	}
+
+
+
 /* Output a File ID */
 #define OUT_CB_AFSFid(label) \
 	{ 	proto_tree *save, *ti; \
@@ -215,7 +291,7 @@
 			"VolSync"); \
 		save = tree; \
 		tree = proto_item_add_subtree(ti, ett_afs_volsync); \
-		OUT_UINT(hf_afs_fs_volsync_spare1); \
+		OUT_DATE(hf_afs_fs_volsync_spare1); \
 		OUT_UINT(hf_afs_fs_volsync_spare2); \
 		OUT_UINT(hf_afs_fs_volsync_spare3); \
 		OUT_UINT(hf_afs_fs_volsync_spare4); \
@@ -226,59 +302,23 @@
 
 /* Output a AFSCBFids */
 #define OUT_FS_AFSCBFids() \
-	{ \
-		guint32 j,i; \
-		j = tvb_get_ntohl(tvb, offset); \
-		offset += 4; \
-		for (i=0; i<j; i++) { \
-			OUT_FS_AFSFid("Target"); \
-		} \
-	}	
+	OUT_RXArray32(OUT_FS_AFSFid("Target"));
 
 /* Output a ViceIds */
 #define OUT_FS_ViceIds() \
-	{ \
-		unsigned int j,i; \
-		j = tvb_get_guint8(tvb,offset); \
-		offset += 1; \
-		for (i=0; i<j; i++) { \
-			OUT_UINT(hf_afs_fs_viceid); \
-		} \
-	}
+	OUT_RXArray8(OUT_UINT(hf_afs_fs_viceid));
 
 /* Output a IPAddrs */
 #define OUT_FS_IPAddrs() \
-	{ \
-		unsigned int j,i; \
-		j = tvb_get_guint8(tvb, offset); \
-		offset += 1; \
-		for (i=0; i<j; i++) { \
-			OUT_IP(hf_afs_fs_ipaddr); \
-		} \
-	}
+	OUT_RXArray8(OUT_IP(hf_afs_fs_ipaddr));
 
 /* Output a AFSCBs */
 #define OUT_FS_AFSCBs()	\
-	{ \
-		guint32 j,i; \
-		j = tvb_get_ntohl(tvb,offset); \
-		offset += 4; \
-		for (i=0; i<j; i++) { \
-			OUT_FS_AFSCallBack(); \
-		} \
-	}
-
+	OUT_RXArray32(OUT_FS_AFSCallBack());
 
 /* Output a AFSBulkStats */
 #define OUT_FS_AFSBulkStats() \
-	{ \
-		unsigned int j,i; \
-		j = tvb_get_guint8(tvb,offset); \
-		offset += 1; \
-		for (i=0; i<j; i++) { \
-			OUT_FS_AFSFetchStatus("Status"); \
-		} \
-	}
+	OUT_RXArray32(OUT_FS_AFSFetchStatus("Status"));
 
 /* Output a AFSFetchVolumeStatus */
 #define OUT_FS_AFSFetchVolumeStatus()
@@ -296,7 +336,7 @@
 #define OUT_FS_VolumeInfo()
 
 /* Output an AFS Token - might just be bytes though */
-#define OUT_FS_AFSTOKEN() VECOUT(hf_afs_fs_token, 1024)
+#define OUT_FS_AFSTOKEN() OUT_RXStringV(hf_afs_fs_token, 1024)
 
 /* Output a AFS acl */
 #define ACLOUT(who, positive, acl, bytes) \
@@ -320,16 +360,27 @@
 		proto_tree_add_string(tree,hf_afs_fs_acl_entity, tvb,offset,strlen(who), who);\
 		tmpoffset = offset + strlen(who) + 1; \
 		acllen = bytes - strlen(who) - 1; \
-		proto_tree_add_uint(tree,hf_afs_fs_acl_r, tvb,tmpoffset,acllen,acl);\
-		proto_tree_add_uint(tree,hf_afs_fs_acl_l, tvb,tmpoffset,acllen,acl);\
-		proto_tree_add_uint(tree,hf_afs_fs_acl_i, tvb,tmpoffset,acllen,acl);\
-		proto_tree_add_uint(tree,hf_afs_fs_acl_d, tvb,tmpoffset,acllen,acl);\
-		proto_tree_add_uint(tree,hf_afs_fs_acl_w, tvb,tmpoffset,acllen,acl);\
-		proto_tree_add_uint(tree,hf_afs_fs_acl_k, tvb,tmpoffset,acllen,acl);\
-		proto_tree_add_uint(tree,hf_afs_fs_acl_a, tvb,tmpoffset,acllen,acl);\
+		proto_tree_add_boolean(tree,hf_afs_fs_acl_r, tvb,tmpoffset,acllen,acl);\
+		proto_tree_add_boolean(tree,hf_afs_fs_acl_l, tvb,tmpoffset,acllen,acl);\
+		proto_tree_add_boolean(tree,hf_afs_fs_acl_i, tvb,tmpoffset,acllen,acl);\
+		proto_tree_add_boolean(tree,hf_afs_fs_acl_d, tvb,tmpoffset,acllen,acl);\
+		proto_tree_add_boolean(tree,hf_afs_fs_acl_w, tvb,tmpoffset,acllen,acl);\
+		proto_tree_add_boolean(tree,hf_afs_fs_acl_k, tvb,tmpoffset,acllen,acl);\
+		proto_tree_add_boolean(tree,hf_afs_fs_acl_a, tvb,tmpoffset,acllen,acl);\
 		tree = save; \
 	}
 
+/* Output a UUID */
+#define OUT_UUID(x) \
+	OUT_BYTES(x, 11*sizeof(guint32));
+#define SKIP_UUID() \
+	SKIP(11*sizeof(guint32));
+
+
+/* Output a bulkaddr */
+#define OUT_VLDB_BulkAddr() \
+	OUT_RXArray32(OUT_IP(hf_afs_vldb_serverip));
+
 /* output a bozo_key */
 #define OUT_BOS_KEY() \
 	OUT_BYTES(hf_afs_bos_key, 8);
@@ -422,40 +473,7 @@
 	proto_tree_add_item(tree, field, tvb, offset, bytes, FALSE);\
 	offset += bytes;
 
-/* Output a rx style string, up to a maximum length first 
-   4 bytes - length, then char data */
-#define OUT_STRING(field) \
-	{	int i; \
-		i = tvb_get_ntohl(tvb, offset); \
-		offset += 4; \
-		if ( i > 0 ) { \
-			char *tmp; \
-			tmp = g_malloc(i+1); \
-			memcpy(tmp, tvb_get_ptr(tvb,offset,i), i); \
-			tmp[i] = '\0'; \
-			proto_tree_add_string(tree, field, tvb, offset-4, i+4, \
-			(void *)tmp); \
-			g_free(tmp); \
-		} else { \
-			proto_tree_add_string(tree, field, tvb, offset-4, 4, \
-			""); \
-		} \
-		offset += i; \
-	}
 
-/* Output a fixed length vectorized string (each char is a 32 bit int) */
-#define VECOUT(field, length) \
-	{ 	char tmp[length+1]; \
-		int i,soff; \
-		soff = offset;\
-		for (i=0; i<length; i++)\
-		{\
-			tmp[i] = (char) tvb_get_ntohl(tvb, offset);\
-			offset += sizeof(guint32);\
-		}\
-		tmp[length] = '\0';\
-		proto_tree_add_string(tree, field, tvb, soff, length, tmp);\
-	}
 
 /* Skip the opcode */
 #define SKIP_OPCODE() \
