@@ -2,7 +2,7 @@
  * Routines for AppleTalk packet disassembly: LLAP, DDP, NBP, ATP, ASP,
  * RTMP.
  *
- * $Id: packet-atalk.c,v 1.72 2002/05/10 23:20:37 guy Exp $
+ * $Id: packet-atalk.c,v 1.80 2002/08/02 23:35:47 jmayer Exp $
  *
  * Simon Wilkinson <sxw@dcs.ed.ac.uk>
  *
@@ -29,14 +29,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <glib.h>
 #include <epan/packet.h>
 #include <string.h>
@@ -70,7 +62,9 @@ static int proto_ddp = -1;
 static int hf_ddp_hopcount = -1;
 static int hf_ddp_len = -1;
 static int hf_ddp_checksum = -1;
+static int hf_ddp_dst = -1;
 static int hf_ddp_dst_net = -1;
+static int hf_ddp_src = -1;
 static int hf_ddp_src_net = -1;
 static int hf_ddp_dst_node = -1;
 static int hf_ddp_src_node = -1;
@@ -114,15 +108,15 @@ static int hf_ddp_type = -1;
 static dissector_handle_t asp_handle;
 
 static int proto_atp = -1;
-static int hf_atp_ctrlinfo  = -1; /* u_int8_t    control information */
+static int hf_atp_ctrlinfo  = -1; /* guint8_t    control information */
 static int hf_atp_function  = -1; /* bits 7,6    function */
 static int hf_atp_xo        = -1; /* bit 5       exactly-once */
 static int hf_atp_eom       = -1; /* bit 4       end-of-message */
 static int hf_atp_sts       = -1; /* bit 3       send transaction status */
 static int hf_atp_treltimer = -1; /* bits 2,1,0  TRel timeout indicator */
 
-static int hf_atp_bitmap = -1;   /* u_int8_t  bitmap or sequence number */
-static int hf_atp_tid = -1;      /* u_int16_t transaction id. */
+static int hf_atp_bitmap = -1;   /* guint8_t  bitmap or sequence number */
+static int hf_atp_tid = -1;      /* guint16_t transaction id. */
 static int hf_atp_user_bytes = -1;
 
 static int hf_atp_segments = -1;
@@ -133,6 +127,57 @@ static int hf_atp_segment_multiple_tails = -1;
 static int hf_atp_segment_too_long_segment = -1;
 static int hf_atp_segment_error = -1;
 
+/* ------------------------- */    
+static int proto_zip = -1;
+static dissector_handle_t zip_atp_handle;
+
+static int hf_zip_function = -1;
+static int hf_zip_atp_function = -1;
+static int hf_zip_start_index = -1;
+static int hf_zip_count = -1;
+static int hf_zip_zero_value	= -1;
+
+static int hf_zip_network_count = -1;
+static int hf_zip_network = -1;
+static int hf_zip_network_start = -1;
+static int hf_zip_network_end = -1;
+
+static int hf_zip_flags = -1;
+
+static int hf_zip_flags_zone_invalid  = -1;
+static int hf_zip_flags_use_broadcast = -1;
+static int hf_zip_flags_only_one_zone = -1;
+
+static int hf_zip_last_flag = -1;
+
+static int hf_zip_zone_name    = -1;
+static int hf_zip_default_zone = -1;
+
+static int hf_zip_multicast_length  = -1;
+static int hf_zip_multicast_address = -1;
+
+static const value_string zip_function_vals[] = {
+  {1, "Query"},
+  {2, "Reply"},
+  {5, "GetNetInfo request"},
+  {6, "GetNetInfo reply"},
+  {7, "notify"},
+  {8, "Extended reply"},
+  {0, NULL}
+};
+
+static const value_string zip_atp_function_vals[] = {
+  {7, "GetMyZone"},
+  {8, "GetZoneList"},
+  {9, "GetLocalZones"},
+  {0, NULL}
+};
+
+static gint ett_zip              = -1;
+static gint ett_zip_flags        = -1;
+static gint ett_zip_zones_list   = -1;
+static gint ett_zip_network_list = -1;
+
 /* --------------------------------
  * from netatalk/include/atalk/ats.h
  */
@@ -287,6 +332,19 @@ static gint ett_ddp = -1;
 static gint ett_llap = -1;
 static gint ett_pstring = -1;
 
+fragment_items atp_frag_items = {
+	&ett_atp_segment,
+	&ett_atp_segments,
+	&hf_atp_segments,
+	&hf_atp_segment,
+	&hf_atp_segment_overlap,
+	&hf_atp_segment_overlap_conflict,
+	&hf_atp_segment_multiple_tails,
+	&hf_atp_segment_too_long_segment,
+	&hf_atp_segment_error,
+	"segments"
+};
+
 static dissector_table_t ddp_dissector_table;
 
 static dissector_handle_t data_handle;
@@ -375,7 +433,7 @@ static const value_string asp_func_vals[] = {
   {0,			NULL } };
 
 const value_string asp_error_vals[] = {
-  {AFP_OK			, "success"},
+  {AFP_OK		, "success"},
   {AFPERR_ACCESS	, "permission denied" },
   {AFPERR_AUTHCONT	, "logincont" },
   {AFPERR_BADUAM	, "uam doesn't exist" },
@@ -483,7 +541,7 @@ dissect_rtmp_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 
   if (check_col(pinfo->cinfo, COL_INFO))
     col_add_fstr(pinfo->cinfo, COL_INFO, "%s",
-	val_to_str(function, rtmp_function_vals, "Unknown function (%02)"));
+	val_to_str(function, rtmp_function_vals, "Unknown function (%02x)"));
   
   if (tree) {
     ti = proto_tree_add_item(tree, proto_rtmp, tvb, 0, 1, FALSE);
@@ -623,7 +681,7 @@ dissect_nbp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
       int soffset = offset;
 
       node_item = proto_tree_add_text(nbp_tree, tvb, offset, -1, 
-			"Node %d", i+1);
+			"Node %u", i+1);
       node_tree = proto_item_add_subtree(node_item, ett_nbp_node);
 
       proto_tree_add_item(node_tree, hf_nbp_node_net, tvb, offset, 2, FALSE);
@@ -646,67 +704,6 @@ dissect_nbp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
   return;
 }
 
-static void
-show_fragments(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
-	       fragment_data *fd_head)
-{
-  guint32 offset;
-  fragment_data *fd;
-  proto_tree *ft;
-  proto_item *fi;
-
-  fi = proto_tree_add_item(tree, hf_atp_segments, tvb, 0, -1, FALSE);
-  ft = proto_item_add_subtree(fi, ett_atp_segments);
-  offset = 0;
-  for (fd = fd_head->next; fd != NULL; fd = fd->next){
-    if (fd->flags & (FD_OVERLAP|FD_OVERLAPCONFLICT|FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-      /*
-       * This segment has some flags set; create a subtree for it and
-       * display the flags.
-       */
-      proto_tree *fet = NULL;
-      proto_item *fei = NULL;
-      int hf;
-
-      if (fd->flags & (FD_OVERLAPCONFLICT|FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-	hf = hf_atp_segment_error;
-      } else {
-	hf = hf_atp_segment;
-      }
-      fei = proto_tree_add_none_format(ft, hf, tvb, offset, fd->len,
-				       "Frame:%u payload:%u-%u",
-				       fd->frame, offset, offset+fd->len-1);
-      fet = proto_item_add_subtree(fei, ett_atp_segment);
-      if (fd->flags&FD_OVERLAP)
-	proto_tree_add_boolean(fet, hf_atp_segment_overlap, tvb, 0, 0, TRUE);
-      if (fd->flags&FD_OVERLAPCONFLICT) {
-	proto_tree_add_boolean(fet, hf_atp_segment_overlap_conflict, tvb, 0, 0,
-			       TRUE);
-      }
-      if (fd->flags&FD_MULTIPLETAILS) {
-	proto_tree_add_boolean(fet, hf_atp_segment_multiple_tails, tvb, 0, 0,
-			       TRUE);
-      }
-      if (fd->flags&FD_TOOLONGFRAGMENT) {
-	proto_tree_add_boolean(fet, hf_atp_segment_too_long_segment, tvb, 0, 0,
-			       TRUE);
-      }
-    } else {
-      /*
-       * Nothing of interest for this segment.
-       */
-      proto_tree_add_text (ft, tvb, offset, fd->len,
-			   "Frame:%u payload:%u-%u",
-			   fd->frame, offset, offset+fd->len-1);
-    }
-    offset += fd->len;
-  }
-  if (fd_head->flags & (FD_OVERLAPCONFLICT|FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-    if (check_col(pinfo->cinfo, COL_INFO))
-      col_set_str(pinfo->cinfo, COL_INFO, "[Illegal segments]");
-  }
-}
-
 /* ----------------------------- 
    ATP protocol cf. inside appletalk chap. 9
    desegmentation from packet-ieee80211.c
@@ -795,7 +792,7 @@ dissect_atp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
   
   if (check_col(pinfo->cinfo, COL_INFO)) {
     col_clear(pinfo->cinfo, COL_INFO);
-    col_add_fstr(pinfo->cinfo, COL_INFO, "%s transaction %d", 
+    col_add_fstr(pinfo->cinfo, COL_INFO, "%s transaction %u", 
     	val_to_str(op, atp_function_vals, "Unknown (0x%01x)"),tid);
     if (more_fragment) 
 	col_append_fstr(pinfo->cinfo, COL_INFO, " [fragment]");
@@ -819,7 +816,7 @@ dissect_atp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
     }
     if (query) {
       proto_tree_add_text(atp_tree, tvb, offset +1, 1,
-			  "Bitmap: 0x%02x  %d packet(s) max", bitmap, nbe);
+			  "Bitmap: 0x%02x  %u packet(s) max", bitmap, nbe);
     }
     else {
       proto_tree_add_item(atp_tree, hf_atp_bitmap, tvb, offset +1, 1, FALSE);
@@ -858,10 +855,12 @@ dissect_atp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 	if (fd_head->next != NULL) {
             new_tvb = tvb_new_real_data(fd_head->data, fd_head->len, fd_head->len);
             tvb_set_child_real_data_tvbuff(tvb, new_tvb);
-            add_new_data_source(pinfo->fd, new_tvb, "Reassembled ATP");
+            add_new_data_source(pinfo, new_tvb, "Reassembled ATP");
 	    /* Show all fragments. */
-	    if (tree)
-		    show_fragments(new_tvb, pinfo, atp_tree, fd_head);
+	    if (tree) {
+		    show_fragment_seq_tree(fd_head, &atp_frag_items,
+		        atp_tree, pinfo, new_tvb);
+	    }
         }
         else 
       	    new_tvb = tvb_new_subset(tvb, ATP_HDRSIZE -1, -1, -1);
@@ -877,7 +876,11 @@ dissect_atp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
   
   if (new_tvb) {
      pinfo->private_data = &aspinfo;
-     call_dissector(asp_handle, new_tvb, pinfo, tree);
+     /* if port == 6 it's not an ASP packet but a ZIP packet */
+     if (pinfo->srcport == 6 || pinfo->destport == 6 )
+    	call_dissector(zip_atp_handle, new_tvb, pinfo, tree);
+     else
+     	call_dissector(asp_handle, new_tvb, pinfo, tree);
   }
   else {
     /* Just show this as a fragment. */
@@ -889,7 +892,7 @@ dissect_atp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 }
 
 /*
-	copy and past from dsi 
+	copy and paste from dsi 
 */
 static gint 
 dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, gint offset)
@@ -913,16 +916,16 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 	tree = proto_item_add_subtree(ti, ett_asp_status);
 
 	ofs = tvb_get_ntohs(tvb, offset +AFPSTATUS_MACHOFF);
-	proto_tree_add_text(tree, tvb, offset +AFPSTATUS_MACHOFF, 2, "Machine offset: %d", ofs);
+	proto_tree_add_text(tree, tvb, offset +AFPSTATUS_MACHOFF, 2, "Machine offset: %u", ofs);
 
 	ofs = tvb_get_ntohs(tvb, offset +AFPSTATUS_VERSOFF);
-	proto_tree_add_text(tree, tvb, offset +AFPSTATUS_VERSOFF, 2, "Version offset: %d", ofs);
+	proto_tree_add_text(tree, tvb, offset +AFPSTATUS_VERSOFF, 2, "Version offset: %u", ofs);
 
 	ofs = tvb_get_ntohs(tvb, offset +AFPSTATUS_UAMSOFF);
-	proto_tree_add_text(tree, tvb, offset +AFPSTATUS_UAMSOFF, 2, "UAMS offset: %d", ofs);
+	proto_tree_add_text(tree, tvb, offset +AFPSTATUS_UAMSOFF, 2, "UAMS offset: %u", ofs);
 
 	ofs = tvb_get_ntohs(tvb, offset +AFPSTATUS_ICONOFF);
-	proto_tree_add_text(tree, tvb, offset +AFPSTATUS_ICONOFF, 2, "Icon offset: %d", ofs);
+	proto_tree_add_text(tree, tvb, offset +AFPSTATUS_ICONOFF, 2, "Icon offset: %u", ofs);
 
 	ofs = offset +AFPSTATUS_FLAGOFF;
 	ti = proto_tree_add_item(tree, hf_asp_server_flag, tvb, ofs, 2, FALSE);
@@ -947,20 +950,20 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 			ofs++;
 
 		sign_ofs = tvb_get_ntohs(tvb, ofs);
-		proto_tree_add_text(tree, tvb, ofs, 2, "Signature offset: %d", sign_ofs);
+		proto_tree_add_text(tree, tvb, ofs, 2, "Signature offset: %u", sign_ofs);
 		sign_ofs += offset;
 
 		if ((flag & AFPSRVRINFO_TCPIP)) {
 			ofs += 2;
 			adr_ofs =  tvb_get_ntohs(tvb, ofs);
-			proto_tree_add_text(tree, tvb, ofs, 2, "Network address offset: %d", adr_ofs);
+			proto_tree_add_text(tree, tvb, ofs, 2, "Network address offset: %u", adr_ofs);
 			adr_ofs += offset;
 		}
 
 		if ((flag & AFPSRVRINFO_SRVDIRECTORY)) {
 			ofs += 2;
 			dir_ofs =  tvb_get_ntohs(tvb, ofs);
-			proto_tree_add_text(tree, tvb, ofs, 2, "Directory services offset: %d", dir_ofs);
+			proto_tree_add_text(tree, tvb, ofs, 2, "Directory services offset: %u", dir_ofs);
 			dir_ofs += offset;
 		}
 	}
@@ -972,7 +975,7 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 	ofs = offset +tvb_get_ntohs(tvb, offset +AFPSTATUS_VERSOFF);
 	if (ofs) {
 		nbe = tvb_get_guint8(tvb, ofs);
-		ti = proto_tree_add_text(tree, tvb, ofs, 1, "Version list: %d", nbe);
+		ti = proto_tree_add_text(tree, tvb, ofs, 1, "Version list: %u", nbe);
 		ofs++;
 		sub_tree = proto_item_add_subtree(ti, ett_asp_vers);
 		for (i = 0; i < nbe; i++) {
@@ -985,7 +988,7 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 	ofs = offset +tvb_get_ntohs(tvb, offset +AFPSTATUS_UAMSOFF);
 	if (ofs) {
 		nbe = tvb_get_guint8(tvb, ofs);
-		ti = proto_tree_add_text(tree, tvb, ofs, 1, "UAMS list: %d", nbe);
+		ti = proto_tree_add_text(tree, tvb, ofs, 1, "UAMS list: %u", nbe);
 		ofs++;
 		sub_tree = proto_item_add_subtree(ti, ett_asp_uams);
 		for (i = 0; i < nbe; i++) {
@@ -1013,7 +1016,7 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 		        	
 		ofs = adr_ofs;
 		nbe = tvb_get_guint8(tvb, ofs);
-		ti = proto_tree_add_text(tree, tvb, ofs, 1, "Address list: %d", nbe);
+		ti = proto_tree_add_text(tree, tvb, ofs, 1, "Address list: %u", nbe);
 		ofs++;
 		adr_tree = proto_item_add_subtree(ti, ett_asp_addr);
 		for (i = 0; i < nbe; i++) {
@@ -1029,7 +1032,7 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 			case 2: /* IP + port */
 				ip = tvb_get_ptr(tvb, ofs+2, 4);
 				port = tvb_get_ntohs(tvb, ofs+6);
-				ti = proto_tree_add_text(adr_tree, tvb, ofs, len, "ip %s:%d",ip_to_str(ip),port);
+				ti = proto_tree_add_text(adr_tree, tvb, ofs, len, "ip %s:%u",ip_to_str(ip),port);
 				break;
 			case 3: /* DDP, atalk_addr_to_str want host order not network */
 				net  = tvb_get_ntohs(tvb, ofs+2);
@@ -1049,7 +1052,7 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 				} 
 				/* else fall to default malformed record */
 			default:
-				ti = proto_tree_add_text(adr_tree, tvb, ofs, len,"Unknow type : %d", type);
+				ti = proto_tree_add_text(adr_tree, tvb, ofs, len,"Unknow type : %u", type);
 				break;
 			}			
 			len -= 2;
@@ -1066,7 +1069,7 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 	if (dir_ofs) {
 		ofs = dir_ofs;
 		nbe = tvb_get_guint8(tvb, ofs);
-		ti = proto_tree_add_text(tree, tvb, ofs, 1, "Directory services list: %d", nbe);
+		ti = proto_tree_add_text(tree, tvb, ofs, 1, "Directory services list: %u", nbe);
 		ofs++;
 		sub_tree = proto_item_add_subtree(ti, ett_asp_directory);
 		for (i = 0; i < nbe; i++) {
@@ -1082,23 +1085,14 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 /* ----------------------------- 
    ASP protocol cf. inside appletalk chap. 11
 */
-static void
-dissect_asp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) 
+static struct aspinfo *
+get_transaction(tvbuff_t *tvb, packet_info *pinfo)
 {
   struct aspinfo *aspinfo = pinfo->private_data;
-  int offset = 0;
-  proto_tree *asp_tree = NULL;
-  proto_item *ti;
-  guint8 fn;
-  int len;
   conversation_t	*conversation;
   asp_request_key request_key, *new_request_key;
   asp_request_val *request_val;
-    
-  if (check_col(pinfo->cinfo, COL_PROTOCOL))
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "ASP");
-  if (check_col(pinfo->cinfo, COL_INFO))
-    col_clear(pinfo->cinfo, COL_INFO);
+  guint8 fn;
 
   conversation = find_conversation(&pinfo->src, &pinfo->dst, pinfo->ptype,
 		pinfo->srcport, pinfo->destport, 0);
@@ -1115,9 +1109,8 @@ dissect_asp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   request_val = (asp_request_val *) g_hash_table_lookup(
 								asp_request_hash, &request_key);
-
   if (!request_val && !aspinfo->reply )  {
-	 fn = tvb_get_guint8(tvb, offset);
+	 fn = tvb_get_guint8(tvb, 0);
 	 new_request_key = g_mem_chunk_alloc(asp_request_keys);
 	 *new_request_key = request_key;
 
@@ -1128,18 +1121,40 @@ dissect_asp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 								request_val);
   }
 
-  if (!request_val) { 
-	return;
-  }
+  if (!request_val) 
+	return NULL;
 
-  fn = request_val->value;
-  aspinfo->command = fn;
+  aspinfo->command = request_val->value;
+  return aspinfo;
+}
+
+
+static void 
+dissect_asp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) 
+{
+  struct aspinfo *aspinfo;
+  int offset = 0;
+  proto_tree *asp_tree = NULL;
+  proto_item *ti;
+  guint8 fn;
+  int len;
+    
+  if (check_col(pinfo->cinfo, COL_PROTOCOL))
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "ASP");
+  if (check_col(pinfo->cinfo, COL_INFO))
+    col_clear(pinfo->cinfo, COL_INFO);
+
+  aspinfo = get_transaction(tvb, pinfo);
+  if (!aspinfo)
+     return;
+
+  fn = aspinfo->command;
 
   if (check_col(pinfo->cinfo, COL_INFO)) {
 	if (aspinfo->reply)
-		col_add_fstr(pinfo->cinfo, COL_INFO, "Reply tid %d",aspinfo->seq);
+		col_add_fstr(pinfo->cinfo, COL_INFO, "Reply tid %u",aspinfo->seq);
 	else
-		col_add_fstr(pinfo->cinfo, COL_INFO, "Function: %s  tid %d",
+		col_add_fstr(pinfo->cinfo, COL_INFO, "Function: %s  tid %u",
       				val_to_str(fn, asp_func_vals, "Unknown (0x%01x)"), aspinfo->seq);
   }
 
@@ -1235,6 +1250,7 @@ dissect_asp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	case ASPFUNC_CMD:
   	case ASPFUNC_WRITE:
     		proto_item_set_len(asp_tree, 4);
+		aspinfo->code = tvb_get_ntohl(tvb, offset);;
 		proto_tree_add_item(asp_tree, hf_asp_error, tvb, offset, 4, FALSE);
 		offset += 4;
 		len = tvb_reported_length_remaining(tvb,offset);
@@ -1256,6 +1272,216 @@ dissect_asp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   }
 }
 
+/* ----------------------------- 
+   ZIP protocol cf. inside appletalk chap. 8
+*/
+static void
+dissect_atp_zip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) 
+{
+  struct aspinfo *aspinfo;
+  int offset = 0;
+  proto_tree *zip_tree;
+  proto_tree *sub_tree;
+  proto_item *ti;
+  guint8 fn;
+  guint16 count;
+  guint8 len;
+    
+  if (check_col(pinfo->cinfo, COL_PROTOCOL))
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "ZIP");
+  if (check_col(pinfo->cinfo, COL_INFO))
+    col_clear(pinfo->cinfo, COL_INFO);
+
+  aspinfo = get_transaction(tvb, pinfo);
+  if (!aspinfo)
+     return;
+
+  fn = aspinfo->command;
+
+  if (check_col(pinfo->cinfo, COL_INFO)) {
+	if (aspinfo->reply)
+		col_add_fstr(pinfo->cinfo, COL_INFO, "Reply tid %u",aspinfo->seq);
+	else
+		col_add_fstr(pinfo->cinfo, COL_INFO, "Function: %s  tid %u",
+      				val_to_str(fn, zip_atp_function_vals, "Unknown (0x%01x)"), aspinfo->seq);
+  }
+
+  if (!tree) 
+     return;
+     
+  ti = proto_tree_add_item(tree, proto_zip, tvb, offset, -1, FALSE);
+  zip_tree = proto_item_add_subtree(ti, ett_zip);
+
+  if (!aspinfo->reply) {
+     proto_tree_add_item(zip_tree, hf_zip_atp_function, tvb, offset, 1, FALSE);
+     offset++;
+     switch(fn) {
+     case 7:	/* start_index = 0 */
+     case 8:
+     case 9:
+         proto_tree_add_item(zip_tree, hf_zip_zero_value, tvb, offset, 1, FALSE);
+         offset++;
+         proto_tree_add_item(zip_tree, hf_zip_start_index, tvb, offset, 2, FALSE);
+         break;
+     }
+  }
+  else {
+  guint8 i;
+  
+     proto_tree_add_uint(zip_tree, hf_zip_atp_function, tvb, 0, 0, fn);
+     switch(fn) {
+     case 7:
+     case 8:
+     case 9:
+         proto_tree_add_item(zip_tree, hf_zip_last_flag, tvb, offset, 1, FALSE);
+         offset++;
+     
+         proto_tree_add_item(zip_tree, hf_zip_zero_value, tvb, offset, 1, FALSE);
+         offset++;
+	 count = tvb_get_ntohs(tvb, offset);
+         ti = proto_tree_add_item(zip_tree, hf_zip_count, tvb, offset, 2, FALSE);
+         offset += 2;
+      	 sub_tree = proto_item_add_subtree(ti, ett_zip_zones_list);
+	 for (i= 1; i <= count; i++) {
+	     len = tvb_get_guint8(tvb, offset);
+             proto_tree_add_item(sub_tree, hf_zip_zone_name, tvb, offset, 1,FALSE);
+	     offset += len +1;
+	 }
+         break;
+     }
+  }
+}
+
+static void
+dissect_ddp_zip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) 
+{
+  proto_tree *zip_tree = NULL;
+  proto_item *ti;
+  guint8  fn;
+  guint8  len;
+  gint    offset = 0;
+  proto_tree *flag_tree;
+  proto_tree *sub_tree;
+  proto_tree *net_tree;
+  guint8 flag;
+  guint16  net;
+  guint8 i;
+  guint8 count;
+  
+  if (check_col(pinfo->cinfo, COL_PROTOCOL))
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "ZIP");
+  if (check_col(pinfo->cinfo, COL_INFO))
+    col_clear(pinfo->cinfo, COL_INFO);
+
+  fn = tvb_get_guint8(tvb, 0);
+  if (check_col(pinfo->cinfo, COL_INFO)) {
+    col_add_str(pinfo->cinfo, COL_INFO,
+      val_to_str(fn, zip_function_vals, "Unknown ZIP function (%02x)"));
+  }
+
+  if (!tree) 
+     return;
+     
+  ti = proto_tree_add_item(tree, proto_zip, tvb, 0, -1, FALSE);
+  zip_tree = proto_item_add_subtree(ti, ett_zip);
+
+  proto_tree_add_item(zip_tree, hf_zip_function, tvb, offset, 1,FALSE);
+  offset++;
+  /* fn 1,7,2,8 are not tested */
+  switch (fn) {
+  case 1: /* Query */
+      count = tvb_get_guint8(tvb, offset);
+      ti = proto_tree_add_item(zip_tree, hf_zip_network_count, tvb, offset, 1, FALSE);
+      offset++;
+      sub_tree = proto_item_add_subtree(ti, ett_zip_network_list);
+      for (i= 1; i <= count; i++) {
+          proto_tree_add_item(sub_tree, hf_zip_network, tvb, offset, 2, FALSE);
+          offset += 2;
+      }
+      break;
+  case 7: /* Notify */
+      flag = tvb_get_guint8(tvb, offset);
+      ti = proto_tree_add_text(zip_tree, tvb, offset , 1,"Flags : 0x%02x", flag);
+      flag_tree = proto_item_add_subtree(ti, ett_zip_flags);
+      proto_tree_add_item(flag_tree, hf_zip_flags_zone_invalid, tvb, offset, 1,FALSE);
+      proto_tree_add_item(flag_tree, hf_zip_flags_use_broadcast,tvb, offset, 1,FALSE);
+      proto_tree_add_item(flag_tree, hf_zip_flags_only_one_zone,tvb, offset, 1,FALSE);
+      offset++;
+
+      proto_tree_add_item(zip_tree, hf_zip_zero_value, tvb, offset, 4, FALSE);
+      offset += 4;
+
+      len = tvb_get_guint8(tvb, offset);
+      proto_tree_add_item(zip_tree, hf_zip_zone_name, tvb, offset, 1,FALSE);
+      offset += len +1;
+
+      len = tvb_get_guint8(tvb, offset);
+      proto_tree_add_item(zip_tree, hf_zip_multicast_length,tvb, offset, 1,FALSE);
+      offset++;
+      proto_tree_add_item(zip_tree, hf_zip_multicast_address,tvb, offset, len,FALSE);
+      offset += len;
+
+      proto_tree_add_item(zip_tree, hf_zip_zone_name, tvb, offset, 1,FALSE);
+      break;
+
+  case 2: /* Reply */
+  case 8: /* Extended Reply */
+      count = tvb_get_guint8(tvb, offset);
+      ti = proto_tree_add_item(zip_tree, hf_zip_network_count, tvb, offset, 1, FALSE);
+      offset++;
+      sub_tree = proto_item_add_subtree(ti, ett_zip_network_list);
+      for (i= 1; i <= count; i++) {
+          net = tvb_get_ntohs(tvb, offset);
+          ti = proto_tree_add_text(zip_tree, tvb, offset , 2, "Zone for network : %u", net);
+          net_tree = proto_item_add_subtree(ti, ett_zip_network_list);
+          proto_tree_add_item(net_tree, hf_zip_network, tvb, offset, 2, FALSE);
+          offset += 2;
+          len = tvb_get_guint8(tvb, offset);
+          proto_tree_add_item(net_tree, hf_zip_zone_name, tvb, offset, 1,FALSE);
+          offset += len +1;
+      }
+      break;
+      
+  case 5 :  /* GetNetInfo request */
+      proto_tree_add_item(zip_tree, hf_zip_zero_value, tvb, offset, 1, FALSE);
+      offset++;
+      proto_tree_add_item(zip_tree, hf_zip_zero_value, tvb, offset, 4, FALSE);
+      offset += 4;
+      proto_tree_add_item(zip_tree, hf_zip_zone_name, tvb, offset, 1,FALSE);
+      break;
+
+  case 6 :  /* GetNetInfo reply */
+      flag = tvb_get_guint8(tvb, offset);
+      ti = proto_tree_add_text(zip_tree, tvb, offset , 1,"Flags : 0x%02x", flag);
+      flag_tree = proto_item_add_subtree(ti, ett_zip_flags);
+      proto_tree_add_item(flag_tree, hf_zip_flags_zone_invalid, tvb, offset, 1,FALSE);
+      proto_tree_add_item(flag_tree, hf_zip_flags_use_broadcast,tvb, offset, 1,FALSE);
+      proto_tree_add_item(flag_tree, hf_zip_flags_only_one_zone,tvb, offset, 1,FALSE);
+      offset++;
+
+      proto_tree_add_item(zip_tree, hf_zip_network_start, tvb, offset, 2, FALSE);
+      offset += 2;
+
+      proto_tree_add_item(zip_tree, hf_zip_network_end, tvb, offset, 2, FALSE);
+      offset += 2;
+
+      len = tvb_get_guint8(tvb, offset);
+      proto_tree_add_item(zip_tree, hf_zip_zone_name, tvb, offset, 1,FALSE);
+      offset += len +1;
+      
+      len = tvb_get_guint8(tvb, offset);
+      proto_tree_add_item(zip_tree, hf_zip_multicast_length,tvb, offset, 1,FALSE);
+      offset++;
+      proto_tree_add_item(zip_tree, hf_zip_multicast_address,tvb, offset, len,FALSE);
+      offset += len;
+      if ((flag & 0x80) != 0)
+         proto_tree_add_item(zip_tree, hf_zip_default_zone, tvb, offset, 1,FALSE);
+      break;
+
+  default:
+      break;
+  }
+}
 
 static void
 dissect_ddp_short(tvbuff_t *tvb, packet_info *pinfo, guint8 dnode,
@@ -1293,22 +1519,29 @@ dissect_ddp_short(tvbuff_t *tvb, packet_info *pinfo, guint8 dnode,
   
   src.net = 0;
   src.node = snode;
-  src.port = sport;
   dst.net = 0;
   dst.node = dnode;
-  dst.port = dport;
   SET_ADDRESS(&pinfo->net_src, AT_ATALK, sizeof src, (guint8 *)&src);
   SET_ADDRESS(&pinfo->src, AT_ATALK, sizeof src, (guint8 *)&src);
   SET_ADDRESS(&pinfo->net_dst, AT_ATALK, sizeof dst, (guint8 *)&dst);
   SET_ADDRESS(&pinfo->dst, AT_ATALK, sizeof dst, (guint8 *)&dst);
 
+  pinfo->ptype = PT_DDP;
+  pinfo->destport = dport;
+  pinfo->srcport = sport;
+  
   if (check_col(pinfo->cinfo, COL_INFO)) {
     col_add_str(pinfo->cinfo, COL_INFO,
       val_to_str(type, op_vals, "Unknown DDP protocol (%02x)"));
   }
-  if (tree)
+  if (tree) {
+    proto_tree_add_string_hidden(ddp_tree, hf_ddp_src, tvb, 
+				 4, 3, atalk_addr_to_str(&src));
+    proto_tree_add_string_hidden(ddp_tree, hf_ddp_dst, tvb, 
+				 6, 3, atalk_addr_to_str(&dst));
+
     proto_tree_add_uint(ddp_tree, hf_ddp_type, tvb, 4, 1, type);
-  
+  }  
   new_tvb = tvb_new_subset(tvb, DDP_SHORT_HEADER_SIZE, -1, -1);
 
   if (!dissector_try_port(ddp_dissector_table, type, new_tvb, pinfo, tree))
@@ -1330,22 +1563,24 @@ dissect_ddp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     col_clear(pinfo->cinfo, COL_INFO);
 
   tvb_memcpy(tvb, (guint8 *)&ddp, 0, sizeof(e_ddp));
-  ddp.dnet=ntohs(ddp.dnet);
-  ddp.snet=ntohs(ddp.snet);
-  ddp.sum=ntohs(ddp.sum);
-  ddp.hops_len=ntohs(ddp.hops_len);
+  ddp.dnet=g_ntohs(ddp.dnet);
+  ddp.snet=g_ntohs(ddp.snet);
+  ddp.sum=g_ntohs(ddp.sum);
+  ddp.hops_len=g_ntohs(ddp.hops_len);
   
   src.net = ddp.snet;
   src.node = ddp.snode;
-  src.port = ddp.sport;
   dst.net = ddp.dnet;
   dst.node = ddp.dnode;
-  dst.port = ddp.dport;
   SET_ADDRESS(&pinfo->net_src, AT_ATALK, sizeof src, (guint8 *)&src);
   SET_ADDRESS(&pinfo->src, AT_ATALK, sizeof src, (guint8 *)&src);
   SET_ADDRESS(&pinfo->net_dst, AT_ATALK, sizeof dst, (guint8 *)&dst);
   SET_ADDRESS(&pinfo->dst, AT_ATALK, sizeof dst, (guint8 *)&dst);
 
+  pinfo->ptype = PT_DDP;
+  pinfo->destport = ddp.dport;
+  pinfo->srcport = ddp.sport;
+
   if (check_col(pinfo->cinfo, COL_INFO))
     col_add_str(pinfo->cinfo, COL_INFO,
       val_to_str(ddp.type, op_vals, "Unknown DDP protocol (%02x)"));
@@ -1354,6 +1589,12 @@ dissect_ddp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     ti = proto_tree_add_item(tree, proto_ddp, tvb, 0, DDP_HEADER_SIZE,
 			     FALSE);
     ddp_tree = proto_item_add_subtree(ti, ett_ddp);
+
+    proto_tree_add_string_hidden(ddp_tree, hf_ddp_src, tvb, 
+				 4, 3, atalk_addr_to_str(&src));
+    proto_tree_add_string_hidden(ddp_tree, hf_ddp_dst, tvb, 
+				 6, 3, atalk_addr_to_str(&dst));
+
     proto_tree_add_uint(ddp_tree, hf_ddp_hopcount,   tvb, 0, 1,
 			ddp_hops(ddp.hops_len));
     proto_tree_add_uint(ddp_tree, hf_ddp_len,        tvb, 0, 2, 
@@ -1530,10 +1771,18 @@ proto_register_atalk(void)
       { "Checksum",		"ddp.checksum",	FT_UINT16, BASE_DEC, NULL, 0x0,
       	"", HFILL }},
 
+    { &hf_ddp_dst,
+      { "Destination address",	"ddp.dst",	FT_STRING, BASE_NONE, NULL, 0x0,
+      	"", HFILL }},
+
     { &hf_ddp_dst_net,
       { "Destination Net",	"ddp.dst.net",	FT_UINT16, BASE_DEC, NULL, 0x0,
       	"", HFILL }},
 
+    { &hf_ddp_src,
+      { "Source address",	"ddp.src",	FT_STRING, BASE_NONE, NULL, 0x0,
+      	"", HFILL }},
+
     { &hf_ddp_src_net,
       { "Source Net",		"ddp.src.net",	FT_UINT16, BASE_DEC, NULL, 0x0,
       	"", HFILL }},
@@ -1547,11 +1796,11 @@ proto_register_atalk(void)
       	"", HFILL }},
 
     { &hf_ddp_dst_socket,
-      { "Destination Socket",	"ddp.dst.socket", FT_UINT8,  BASE_DEC, NULL, 0x0,
+      { "Destination Socket",	"ddp.dst_socket", FT_UINT8,  BASE_DEC, NULL, 0x0,
       	"", HFILL }},
 
     { &hf_ddp_src_socket,
-      { "Source Socket",       	"ddp.src.socket", FT_UINT8,  BASE_DEC, NULL, 0x0,
+      { "Source Socket",       	"ddp.src_socket", FT_UINT8,  BASE_DEC, NULL, 0x0,
       	"", HFILL }},
 
     { &hf_ddp_type,
@@ -1830,6 +2079,78 @@ proto_register_atalk(void)
 
   };
   
+  static hf_register_info hf_zip[] = {
+    { &hf_zip_function,
+      { "Function",	"zip.function",	FT_UINT8,  BASE_DEC, VALS(zip_function_vals), 0x0,
+      	"ZIP function", HFILL }},
+
+    { &hf_zip_zero_value,
+      { "Pad (0)",      "zip.zero_value",FT_BYTES, BASE_HEX, NULL, 0x0,
+      	"Pad", HFILL }},
+
+    { &hf_zip_atp_function,
+      { "Function",	"zip.atp_function", FT_UINT8,  BASE_DEC, VALS(zip_atp_function_vals), 0x0,
+      	"", HFILL }},
+
+    { &hf_zip_start_index,
+      { "Start index",	"zip.start_index", FT_UINT16, BASE_DEC, NULL, 0x0,
+      	"", HFILL }},
+
+    { &hf_zip_count,
+      { "Count",	"zip.count", FT_UINT16, BASE_DEC, NULL, 0x0,
+      	"", HFILL }},
+
+    { &hf_zip_network_count,
+      { "Count",	"zip.network_count", FT_UINT8, BASE_DEC, NULL, 0x0,
+      	"", HFILL }},
+    { &hf_zip_network,
+      { "Network","zip.network", FT_UINT16, BASE_DEC, NULL, 0x0,
+      	"", HFILL }},
+    { &hf_zip_network_start,
+      { "Network start","zip.network_start", FT_UINT16, BASE_DEC, NULL, 0x0,
+      	"", HFILL }},
+    { &hf_zip_network_end,
+      { "Network end",	"zip.network_end", FT_UINT16, BASE_DEC, NULL, 0x0,
+      	"", HFILL }},
+
+    { &hf_zip_flags,
+      { "Flags",	"zip.flags", FT_BOOLEAN, 8, NULL, 0xC0,
+      	"", HFILL }},
+
+    { &hf_zip_last_flag,
+      { "Last Flag",	"zip.last_flag", FT_BOOLEAN, 8, NULL, 0,
+      	"Non zero if contains last zone name in the zone list", HFILL }},
+
+    { &hf_zip_flags_zone_invalid,
+      { "Zone invalid",	"zip.flags.zone_invalid", FT_BOOLEAN, 8, NULL, 0x80,
+      	"", HFILL }},
+
+    { &hf_zip_flags_use_broadcast,
+      { "Use broadcast","zip.flags.use_broadcast", FT_BOOLEAN, 8, NULL, 0x40,
+      	"", HFILL }},
+
+    { &hf_zip_flags_only_one_zone,
+      { "Only one zone","zip.flags.only_one_zone", FT_BOOLEAN, 8, NULL, 0x20,
+      	"", HFILL }},
+
+    { &hf_zip_zone_name,
+      { "Zone",         "zip.zone_name", FT_UINT_STRING, BASE_NONE, NULL, 0x0,
+      	"", HFILL }},
+
+    { &hf_zip_default_zone,
+      { "Default zone", "zip.default_zone",FT_UINT_STRING, BASE_NONE, NULL, 0x0,
+      	"", HFILL }},
+
+    { &hf_zip_multicast_length,
+      { "Multicast length",	"zip.multicast_length", FT_UINT8,  BASE_DEC, NULL, 0x0,
+      	"Multicast address length", HFILL }},
+
+    { &hf_zip_multicast_address,
+      { "Multicast address", "zip.multicast_address",FT_BYTES, BASE_HEX, NULL, 0x0,
+      	"Multicast address", HFILL }},
+
+  };
+  
   static gint *ett[] = {
   	&ett_llap,
 	&ett_ddp,
@@ -1854,6 +2175,11 @@ proto_register_atalk(void)
 	&ett_pstring,
 	&ett_rtmp,
 	&ett_rtmp_tuple,
+
+	&ett_zip,
+	&ett_zip_flags,
+        &ett_zip_zones_list, 
+        &ett_zip_network_list, 
   };
   module_t *atp_module;
 
@@ -1872,6 +2198,9 @@ proto_register_atalk(void)
   proto_asp = proto_register_protocol("AppleTalk Session Protocol", "ASP", "asp");
   proto_register_field_array(proto_asp, hf_asp, array_length(hf_asp));
 
+  proto_zip = proto_register_protocol("Zone Information Protocol", "ZIP", "zip");
+  proto_register_field_array(proto_zip, hf_zip, array_length(hf_zip));
+
   atp_module = prefs_register_protocol(proto_atp, NULL);
   prefs_register_bool_preference(atp_module, "desegment",
     "Desegment all ATP messages spanning multiple DDP packets",
@@ -1894,6 +2223,7 @@ proto_reg_handoff_atalk(void)
 {
   dissector_handle_t ddp_handle, nbp_handle, rtmp_request_handle;
   dissector_handle_t atp_handle;
+  dissector_handle_t zip_ddp_handle;
   dissector_handle_t rtmp_data_handle, llap_handle;
 
   ddp_handle = create_dissector_handle(dissect_ddp, proto_ddp);
@@ -1915,6 +2245,11 @@ proto_reg_handoff_atalk(void)
   dissector_add("ddp.type", DDP_RTMPREQ, rtmp_request_handle);
   dissector_add("ddp.type", DDP_RTMPDATA, rtmp_data_handle);
 
+  zip_ddp_handle = create_dissector_handle(dissect_ddp_zip, proto_zip);
+  dissector_add("ddp.type", DDP_ZIP, zip_ddp_handle);
+
+  zip_atp_handle = create_dissector_handle(dissect_atp_zip, proto_zip);
+
   llap_handle = create_dissector_handle(dissect_llap, proto_llap);
   dissector_add("wtap_encap", WTAP_ENCAP_LOCALTALK, llap_handle);
 
