@@ -1,11 +1,10 @@
 /* packet-atm.h
  *
- * $Id: packet-atm.h,v 1.5 2000/08/11 13:34:17 deniel Exp $
+ * $Id: packet-atm.h,v 1.8 2002/08/02 23:35:47 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,6 +24,7 @@
 #ifndef __PACKET_ATM_H__
 #define __PACKET_ATM_H__
 
-void dissect_atm(tvbuff_t *, packet_info *, proto_tree *);
+void capture_atm(const union wtap_pseudo_header *, const guchar *, int,
+    packet_counts *);
 
 #endif
