@@ -2,7 +2,7 @@
  * Routines for BOOTP/DHCP packet disassembly
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-bootp.c,v 1.63 2002/01/24 09:20:47 guy Exp $
+ * $Id: packet-bootp.c,v 1.69 2002/08/02 23:35:47 jmayer Exp $
  *
  * The information used comes from:
  * RFC  951: Bootstrap Protocol
@@ -39,10 +39,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 #include <glib.h>
 #include <epan/int-64bit.h>
@@ -56,7 +52,9 @@ static int hf_bootp_hw_len = -1;
 static int hf_bootp_hops = -1;
 static int hf_bootp_id = -1;
 static int hf_bootp_secs = -1;
-static int hf_bootp_flag = -1;
+static int hf_bootp_flags = -1;
+static int hf_bootp_flags_broadcast = -1;
+static int hf_bootp_flags_reserved = -1;
 static int hf_bootp_ip_client = -1;
 static int hf_bootp_ip_your = -1;
 static int hf_bootp_ip_server = -1;
@@ -65,12 +63,18 @@ static int hf_bootp_hw_addr = -1;
 static int hf_bootp_server = -1;
 static int hf_bootp_file = -1;
 static int hf_bootp_cookie = -1;
+static int hf_bootp_vendor = -1;
 static int hf_bootp_dhcp = -1;
 
 static guint ett_bootp = -1;
+static guint ett_bootp_flags = -1;
 static guint ett_bootp_option = -1;
 
 #define UDP_PORT_BOOTPS  67
+#define UDP_PORT_BOOTPC  68
+
+#define BOOTP_BC	0x8000
+#define BOOTP_MBZ	0x7FFF
 
 enum field_type { none, ipv4, string, toggle, yes_no, special, opaque,
 	time_in_secs,
@@ -82,6 +86,11 @@ struct opt_info {
 	enum field_type ftype;
 };
 
+static const true_false_string flag_set_broadcast = {
+  "Broadcast",
+  "Unicast"
+};
+
 #define NUM_OPT_INFOS 211
 #define NUM_O63_SUBOPTS 11
 
@@ -133,11 +142,11 @@ bootp_option(tvbuff_t *tvb, proto_tree *bp_tree, int voff, int eoff,
 {
 	char			*text;
 	enum field_type		ftype;
-	u_char			code = tvb_get_guint8(tvb, voff);
+	guchar			code = tvb_get_guint8(tvb, voff);
 	int			vlen;
-	u_char			byte;
+	guchar			byte;
 	int			i,optp, consumed;
-	u_long			time_secs;
+	gulong			time_secs;
 	proto_tree		*v_tree;
 	proto_item		*vti;
 	guint8			protocol;
@@ -754,12 +763,12 @@ bootp_option(tvbuff_t *tvb, proto_tree *bp_tree, int voff, int eoff,
 
 		case val_u_short:
 			if (vlen == 2) {
-				/* one u_short */
+				/* one gushort */
 				proto_tree_add_text(bp_tree, tvb, voff, consumed,
 						"Option %d: %s = %d", code, text,
 						tvb_get_ntohs(tvb, voff+2));
 			} else {
-				/* > 1 u_short */
+				/* > 1 gushort */
 				vti = proto_tree_add_text(bp_tree, tvb, voff,
 					consumed, "Option %d: %s", code, text);
 				v_tree = proto_item_add_subtree(vti, ett_bootp_option);
@@ -1085,6 +1094,8 @@ dissect_bootp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	proto_tree	*bp_tree = NULL;
 	proto_item	*ti;
+	proto_tree	*flag_tree = NULL;
+	proto_item	*fi;
 	guint8		op;
 	guint8		htype, hlen;
 	const guint8	*haddr;
@@ -1093,6 +1104,7 @@ dissect_bootp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	gboolean	at_end;
 	const char	*dhcp_type = NULL;
 	const guint8	*vendor_class_id = NULL;
+	guint16		flags;
 
 	if (check_col(pinfo->cinfo, COL_PROTOCOL))
 		col_set_str(pinfo->cinfo, COL_PROTOCOL, "BOOTP");
@@ -1147,9 +1159,16 @@ dissect_bootp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				    4, 4, FALSE);
 		proto_tree_add_item(bp_tree, hf_bootp_secs, tvb,
 				    8, 2, FALSE);
-		proto_tree_add_uint(bp_tree, hf_bootp_flag, tvb,
-				    10, 2, tvb_get_ntohs(tvb, 10) & 0x8000);
-
+		flags = tvb_get_ntohs(tvb, 10);
+		fi = proto_tree_add_uint(bp_tree, hf_bootp_flags, tvb,
+				    10, 2, flags);
+		proto_item_append_text(fi, " (%s)",
+		    (flags & BOOTP_BC) ? "Broadcast" : "Unicast");
+    		flag_tree = proto_item_add_subtree(fi, ett_bootp_flags);
+		proto_tree_add_boolean(flag_tree, hf_bootp_flags_broadcast, tvb,
+				    10, 2, flags);
+		proto_tree_add_uint(flag_tree, hf_bootp_flags_reserved, tvb,
+				    10, 2, flags);
 		proto_tree_add_item(bp_tree, hf_bootp_ip_client, tvb, 
 				    12, 4, FALSE);
 		proto_tree_add_item(bp_tree, hf_bootp_ip_your, tvb, 
@@ -1197,20 +1216,30 @@ dissect_bootp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 						   tvb_get_ptr(tvb, 108, 1),
 						   "Boot file name not given");
 		}
+	}
 
-		tvb_memcpy(tvb, (void *)&ip_addr, 236, sizeof(ip_addr));
-		if (tvb_get_ntohl(tvb, 236) == 0x63825363) {
-			proto_tree_add_ipv4_format(bp_tree, hf_bootp_cookie, tvb,
-					    236, 4, ip_addr,
-					    "Magic cookie: (OK)");
+	voff = 236;
+
+	/* rfc2132 says it SHOULD exist, not that it MUST exist */
+	if (tvb_bytes_exist(tvb, voff, 4)) {
+		if (tvb_get_ntohl(tvb, voff) == 0x63825363) {
+			if (tree) {
+				tvb_memcpy(tvb, (void *)&ip_addr, voff, sizeof(ip_addr));
+				proto_tree_add_ipv4_format(bp_tree, hf_bootp_cookie, tvb,
+				    voff, 4, ip_addr,
+				    "Magic cookie: (OK)");
+			}
+			voff += 4;
 		}
 		else {
-			proto_tree_add_ipv4(bp_tree, hf_bootp_cookie, tvb,
-					    236, 4, ip_addr);
+			if (tree) {
+				proto_tree_add_text(bp_tree,  tvb,
+					voff, 64, "Bootp vendor specific options");
+			}
+			voff += 64;
 		}
 	}
 
-	voff = 240;
 	eoff = tvb_reported_length(tvb);
 
 	/*
@@ -1305,11 +1334,21 @@ proto_register_bootp(void)
         BASE_DEC,			 NULL,		 0x0,
       	"", HFILL }},
 
-    { &hf_bootp_flag,
-      { "Broadcast flag",	       	"bootp.flag",    FT_UINT16,
+    { &hf_bootp_flags,
+      { "Bootp flags",		       	"bootp.flags",   FT_UINT16,
         BASE_HEX,			NULL,		 0x0,
       	"", HFILL }},
 
+    { &hf_bootp_flags_broadcast,
+      { "Broadcast flag",	       	"bootp.flags.bc", FT_BOOLEAN,
+        16,			TFS(&flag_set_broadcast), BOOTP_BC,
+      	"", HFILL }},
+
+    { &hf_bootp_flags_reserved,
+      { "Reserved flags",	       	"bootp.flags.reserved", FT_UINT16,
+        BASE_HEX,			NULL,		BOOTP_MBZ,
+      	"", HFILL }},
+
     { &hf_bootp_ip_client,
       { "Client IP address",	       	"bootp.ip.client",FT_IPv4,
         BASE_NONE,			NULL,		  0x0,
@@ -1349,9 +1388,15 @@ proto_register_bootp(void)
       { "Magic cookie",			"bootp.cookie",	 FT_IPv4,
          BASE_NONE,			NULL,		 0x0,
       	"", HFILL }},
+
+    { &hf_bootp_vendor,
+      { "Bootp Vendor Options",		"bootp.vendor", FT_BYTES,
+        BASE_NONE,			NULL,		 0x0,
+      	"", HFILL }},
   };
   static gint *ett[] = {
     &ett_bootp,
+    &ett_bootp_flags,
     &ett_bootp_option,
   };
   
@@ -1368,4 +1413,5 @@ proto_reg_handoff_bootp(void)
 
   bootp_handle = create_dissector_handle(dissect_bootp, proto_bootp);
   dissector_add("udp.port", UDP_PORT_BOOTPS, bootp_handle);
+  dissector_add("udp.port", UDP_PORT_BOOTPC, bootp_handle);
 }
