@@ -2,7 +2,7 @@
  * Routines for the disassembly of the "Cisco Discovery Protocol"
  * (c) Copyright Hannes R. Boehm <hannes@boehm.org>
  *
- * $Id: packet-cdp.c,v 1.44 2002/01/24 09:20:47 guy Exp $
+ * $Id: packet-cdp.c,v 1.48 2002/08/18 15:30:38 gerald Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -25,10 +25,6 @@
  
 #include "config.h"
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <stdlib.h>
 #include <string.h>
 
@@ -356,7 +352,8 @@ dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		offset += length;
 	    }
 	}
-    	call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, cdp_tree);
+	call_dissector(data_handle, tvb_new_subset(tvb, offset, -1, -1), pinfo,
+			cdp_tree);
     }
 }
 
@@ -529,7 +526,7 @@ add_multi_line_string_to_tree(proto_tree *tree, tvbuff_t *tvb, gint start,
 	blanks[i] = ' ';
     blanks[i] = '\0';
     while (len > 0) {
-	line_len = tvb_find_line_end(tvb, start, len, &next);
+	line_len = tvb_find_line_end(tvb, start, len, &next, FALSE);
 	data_len = next - start;
 	proto_tree_add_text(tree, tvb, start, data_len, "%s%.*s", prefix,
 	   line_len, tvb_get_ptr(tvb, start, line_len));
@@ -585,4 +582,5 @@ proto_reg_handoff_cdp(void)
     cdp_handle = create_dissector_handle(dissect_cdp, proto_cdp);
     dissector_add("llc.cisco_pid", 0x2000, cdp_handle);
     dissector_add("chdlctype", 0x2000, cdp_handle);
+    dissector_add("ppp.protocol", 0x0207, cdp_handle);
 }
