@@ -1,7 +1,7 @@
 /* packet-clnp.c
  * Routines for ISO/OSI network and transport protocol packet disassembly
  *
- * $Id: packet-clnp.c,v 1.54 2002/04/30 23:56:58 guy Exp $
+ * $Id: packet-clnp.c,v 1.58 2002/08/02 23:35:48 jmayer Exp $
  * Laurent Deniel <deniel@worldnet.fr>
  * Ralf Schneider <Ralf.Schneider@t-online.de>
  *
@@ -28,10 +28,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -77,6 +73,19 @@ static int hf_clnp_segment_multiple_tails = -1;
 static int hf_clnp_segment_too_long_segment = -1;
 static int hf_clnp_segment_error = -1;
 
+fragment_items clnp_frag_items = {
+	&ett_clnp_segment,
+	&ett_clnp_segments,
+	&hf_clnp_segments,
+	&hf_clnp_segment,
+	&hf_clnp_segment_overlap,
+	&hf_clnp_segment_overlap_conflict,
+	&hf_clnp_segment_multiple_tails,
+	&hf_clnp_segment_too_long_segment,
+	&hf_clnp_segment_error,
+	"segments"
+};
+
 static dissector_handle_t data_handle;
 
 /*
@@ -142,9 +151,9 @@ static const value_string npdu_type_vals[] = {
 /* Segmentation part */
 
 struct clnp_segment {
-  u_short	cng_id;		/* data unit identifier */
-  u_short	cng_off;	/* segment offset */
-  u_short	cng_tot_len;	/* total length */
+  gushort	cng_id;		/* data unit identifier */
+  gushort	cng_off;	/* segment offset */
+  gushort	cng_tot_len;	/* total length */
 };
 
 /* NSAP selector */
@@ -263,8 +272,8 @@ static const value_string tp_vpart_type_vals[] = {
 
 /* global variables */
 
-static u_char  li, tpdu, cdt; 	/* common fields */
-static u_short dst_ref;
+static guchar  li, tpdu, cdt; 	/* common fields */
+static gushort dst_ref;
 
 /* List of dissectors to call for COTP packets put atop the Inactive
    Subset of CLNP. */
@@ -283,7 +292,7 @@ static gboolean clnp_reassemble = FALSE;
 /* function definitions */
 
 #define MAX_TSAP_LEN	32
-static gchar *print_tsap(const u_char *tsap, int length)
+static gchar *print_tsap(const guchar *tsap, int length)
 {
 
   static gchar  str[3][MAX_TSAP_LEN * 2 + 1];
@@ -664,8 +673,8 @@ static int osi_decode_DR(tvbuff_t *tvb, int offset,
 {
   proto_tree *cotp_tree;
   proto_item *ti;
-  u_short src_ref;
-  u_char  reason;
+  gushort src_ref;
+  guchar  reason;
   char *str;
   
   if (li < LI_MIN_DR) 
@@ -716,7 +725,7 @@ static int osi_decode_DR(tvbuff_t *tvb, int offset,
   offset += li + 1;
 
   /* User data */
-  call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+  call_dissector(data_handle, tvb_new_subset(tvb, offset, -1, -1), pinfo, tree);
   offset += tvb_length_remaining(tvb, offset);
      /* we dissected all of the containing PDU */
 
@@ -733,8 +742,8 @@ static int osi_decode_DT(tvbuff_t *tvb, int offset,
   proto_item *ti;
   gboolean is_extended;
   gboolean is_class_234;
-  u_int    tpdu_nr ;
-  u_int    fragment = 0;
+  guint    tpdu_nr ;
+  guint    fragment = 0;
   tvbuff_t *next_tvb;
     
   /* VP_CHECKSUM is the only parameter allowed in the variable part.
@@ -867,7 +876,7 @@ static int osi_decode_ED(tvbuff_t *tvb, int offset,
   proto_tree *cotp_tree = NULL;
   proto_item *ti;
   gboolean is_extended;
-  u_int    tpdu_nr ;
+  guint    tpdu_nr ;
   tvbuff_t *next_tvb;
 
   /* ED TPDUs are never fragmented */
@@ -972,8 +981,8 @@ static int osi_decode_RJ(tvbuff_t *tvb, int offset,
 {
   proto_tree *cotp_tree;
   proto_item *ti;
-  u_int    tpdu_nr ;
-  u_short  credit = 0;
+  guint    tpdu_nr ;
+  gushort  credit = 0;
 
   switch(li) {
     case LI_NORMAL_RJ   :
@@ -1030,8 +1039,8 @@ static int osi_decode_CC(tvbuff_t *tvb, int offset,
 
   proto_tree *cotp_tree = NULL;
   proto_item *ti;
-  u_short src_ref;
-  u_char  class_option;
+  gushort src_ref;
+  guchar  class_option;
 
   src_ref = tvb_get_ntohs(tvb, offset + P_SRC_REF);
   class_option = (tvb_get_guint8(tvb, offset + P_CLASS_OPTION) >> 4 ) & 0x0F;
@@ -1087,7 +1096,7 @@ static int osi_decode_CC(tvbuff_t *tvb, int offset,
   offset += li;
 
   /* User data */
-  call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+  call_dissector(data_handle, tvb_new_subset(tvb, offset, -1, -1), pinfo, tree);
   offset += tvb_length_remaining(tvb, offset);
      /* we dissected all of the containing PDU */
 
@@ -1100,7 +1109,7 @@ static int osi_decode_DC(tvbuff_t *tvb, int offset,
 {
   proto_tree *cotp_tree = NULL;
   proto_item *ti;
-  u_short src_ref;
+  gushort src_ref;
 
   if (li > LI_MAX_DC) 
     return -1;
@@ -1155,8 +1164,8 @@ static int osi_decode_AK(tvbuff_t *tvb, int offset,
 {
   proto_tree *cotp_tree = NULL;
   proto_item *ti;
-  u_int      tpdu_nr;
-  u_short    cdt_in_ak;
+  guint      tpdu_nr;
+  gushort    cdt_in_ak;
 
   if (li > LI_MAX_AK) 
     return -1;
@@ -1265,7 +1274,7 @@ static int osi_decode_EA(tvbuff_t *tvb, int offset,
   proto_tree *cotp_tree = NULL;
   proto_item *ti;
   gboolean is_extended;
-  u_int    tpdu_nr ;
+  guint    tpdu_nr ;
 
   if (li > LI_MAX_EA) 
     return -1;
@@ -1358,7 +1367,7 @@ static int osi_decode_ER(tvbuff_t *tvb, int offset,
 {
   proto_tree *cotp_tree;
   proto_item *ti;
-  u_char *str;
+  guchar *str;
 
   if (li > LI_MAX_ER) 
     return -1;
@@ -1480,7 +1489,8 @@ static gboolean dissect_ositp_internal(tvbuff_t *tvb, packet_info *pinfo,
       if (check_col(pinfo->cinfo, COL_INFO))
         col_append_str(pinfo->cinfo, COL_INFO, "Length indicator is zero");
       if (!first_tpdu)
-        call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+        call_dissector(data_handle, tvb_new_subset(tvb, offset, -1, -1),
+                       pinfo, tree);
       return found_ositp;
     }
 
@@ -1533,7 +1543,8 @@ static gboolean dissect_ositp_internal(tvbuff_t *tvb, packet_info *pinfo,
 
     if (new_offset == -1) { /* incorrect TPDU */
       if (!first_tpdu)
-        call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+        call_dissector(data_handle, tvb_new_subset(tvb, offset, -1, -1),
+                       pinfo, tree);
       break;
     }
 
@@ -1580,7 +1591,7 @@ static void dissect_clnp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   guint16     cnf_cksum;
   cksum_status_t cksum_status;
   int         offset;
-  u_char      src_len, dst_len, nsel, opt_len = 0;
+  guchar      src_len, dst_len, nsel, opt_len = 0;
   const guint8     *dst_addr, *src_addr;
   gint        len;
   guint       next_length;
@@ -1825,10 +1836,6 @@ static void dissect_clnp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			   cnf_type & CNF_MORE_SEGS);
 
     if (fd_head != NULL) {
-      fragment_data *fd;
-      proto_tree *ft=NULL;
-      proto_item *fi=NULL;
-
       /* OK, we have the complete reassembled payload.
          Allocate a new tvbuff, referring to the reassembled payload. */
       next_tvb = tvb_new_real_data(fd_head->data, fd_head->datalen,
@@ -1840,77 +1847,10 @@ static void dissect_clnp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       tvb_set_child_real_data_tvbuff(tvb, next_tvb);
 
       /* Add the defragmented data to the data source list. */
-      add_new_data_source(pinfo->fd, next_tvb, "Reassembled CLNP");
+      add_new_data_source(pinfo, next_tvb, "Reassembled CLNP");
 
-      /* It's not fragmented. */
-      pinfo->fragmented = FALSE;
-
-      /* show all segments */
-      fi = proto_tree_add_item(clnp_tree, hf_clnp_segments, 
-                next_tvb, 0, -1, FALSE);
-      ft = proto_item_add_subtree(fi, ett_clnp_segments);
-      for (fd = fd_head->next; fd != NULL; fd = fd->next){
-        if (fd->flags & (FD_OVERLAP|FD_OVERLAPCONFLICT
-                          |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-          /* this segment has some flags set, create a subtree 
-           * for it and display the flags.
-           */
-          proto_tree *fet = NULL;
-          proto_item *fei = NULL;
-          int hf;
-
-          if (fd->flags & (FD_OVERLAPCONFLICT
-                      |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-            hf = hf_clnp_segment_error;
-          } else {
-            hf = hf_clnp_segment;
-          }
-          fei = proto_tree_add_none_format(ft, hf, 
-                   next_tvb, fd->offset, fd->len,
-                   "Frame:%u payload:%u-%u",
-                   fd->frame,
-                   fd->offset,
-                   fd->offset+fd->len-1
-          );
-          fet = proto_item_add_subtree(fei, ett_clnp_segment);
-          if (fd->flags&FD_OVERLAP) {
-            proto_tree_add_boolean(fet, 
-                 hf_clnp_segment_overlap, next_tvb, 0, 0, 
-                 TRUE);
-          }
-          if (fd->flags&FD_OVERLAPCONFLICT) {
-            proto_tree_add_boolean(fet, 
-                 hf_clnp_segment_overlap_conflict, next_tvb, 0, 0, 
-                 TRUE);
-          }
-          if (fd->flags&FD_MULTIPLETAILS) {
-            proto_tree_add_boolean(fet, 
-                 hf_clnp_segment_multiple_tails, next_tvb, 0, 0, 
-                 TRUE);
-          }
-          if (fd->flags&FD_TOOLONGFRAGMENT) {
-            proto_tree_add_boolean(fet, 
-                 hf_clnp_segment_too_long_segment, next_tvb, 0, 0, 
-                 TRUE);
-          }
-        } else {
-          /* nothing of interest for this segment */
-          proto_tree_add_none_format(ft, hf_clnp_segment, 
-                   next_tvb, fd->offset, fd->len,
-                   "Frame:%u payload:%u-%u",
-                   fd->frame,
-                   fd->offset,
-                   fd->offset+fd->len-1
-          );
-        }
-      }
-      if (fd_head->flags & (FD_OVERLAPCONFLICT
-                        |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-        if (check_col(pinfo->cinfo, COL_INFO)) {
-          col_set_str(pinfo->cinfo, COL_INFO, "[Illegal segments]");
-          update_col_info = FALSE;
-        }
-      }
+      update_col_info = !show_fragment_tree(fd_head, &clnp_frag_items,
+        clnp_tree, pinfo, next_tvb);
     } else {
       /* We don't have the complete reassembled payload. */
       next_tvb = NULL;
@@ -1949,7 +1889,8 @@ static void dissect_clnp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     /* As we haven't reassembled anything, we haven't changed "pi", so
        we don't have to restore it. */
-    call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+    call_dissector(data_handle, tvb_new_subset(tvb, offset, -1, -1), pinfo,
+                   tree);
     pinfo->fragmented = save_fragmented;
     return;
   }
