@@ -2,7 +2,7 @@
  * Routines for dcerpc conv dissection
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  *
- * $Id: packet-dcerpc-conv.c,v 1.2 2002/01/21 07:36:33 guy Exp $
+ * $Id: packet-dcerpc-conv.c,v 1.5 2002/08/02 23:35:48 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -28,10 +28,6 @@
 #endif
 
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <string.h>
 
 #include <glib.h>
@@ -54,7 +50,7 @@ static dcerpc_sub_dissector conv_dissectors[] = {
     { 2, "conv_are_you_there", NULL, NULL },
     { 3, "conv_who_are_you_auth", NULL, NULL },
     { 4, "conv_who_are_you_auth_more", NULL, NULL },
-    { 0, NULL, NULL, NULL },
+    { 0, NULL, NULL, NULL }
 };
 
 
@@ -67,7 +63,7 @@ proto_register_conv (void)
 #endif
 
 	static gint *ett[] = {
-		&ett_conv,
+		&ett_conv
 	};
 	proto_conv = proto_register_protocol ("DCE/RPC Conversation Manager", "CONV", "conv");
 #if 0
@@ -80,5 +76,5 @@ void
 proto_reg_handoff_conv (void)
 {
 	/* Register the protocol as dcerpc */
-	dcerpc_init_uuid (proto_conv, ett_conv, &uuid_conv, ver_conv, conv_dissectors);
+	dcerpc_init_uuid (proto_conv, ett_conv, &uuid_conv, ver_conv, conv_dissectors, -1);
 }
