@@ -2,7 +2,7 @@
  * Routines for SMB \PIPE\lsarpc packet disassembly
  * Copyright 2001, Tim Potter <tpot@samba.org>
  *
- * $Id: packet-dcerpc-lsa.h,v 1.4 2002/04/17 09:24:08 sahlberg Exp $
+ * $Id: packet-dcerpc-lsa.h,v 1.7 2002/08/09 09:27:33 sahlberg Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -72,8 +72,8 @@
 #define LSA_LSARETRIEVEPRIVATEDATA	0x2b
 #define LSA_LSAOPENPOLICY2	0x2c
 #define LSA_LSAGETUSERNAME	0x2d
-#define LSA_LSAFUNCTION_2E	0x2e
-#define LSA_LSAFUNCTION_2F	0x2f
+#define LSA_LSAQUERYINFORMATIONPOLICY2	0x2e
+#define LSA_LSASETINFORMATIONPOLICY2	0x2f
 #define LSA_LSAQUERYTRUSTEDDOMAININFOBYNAME	0x30
 #define LSA_LSASETTRUSTEDDOMAININFOBYNAME	0x31
 #define LSA_LSAENUMERATETRUSTEDDOMAINSEX	0x32
@@ -92,6 +92,10 @@ lsa_dissect_LSA_SECURITY_DESCRIPTOR(tvbuff_t *tvb, int offset,
                              packet_info *pinfo, proto_tree *tree,
                              char *drep);
 int
+lsa_dissect_LSA_SECURITY_DESCRIPTOR_data(tvbuff_t *tvb, int offset, 
+                             packet_info *pinfo, proto_tree *tree,
+			     char *drep);
+int
 lsa_dissect_LSA_SECRET(tvbuff_t *tvb, int offset,
 			packet_info *pinfo, proto_tree *parent_tree,
 			char *drep);
