@@ -2,7 +2,7 @@
  * Routines for dcerpc mgmt dissection
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  *
- * $Id: packet-dcerpc-mgmt.c,v 1.2 2002/01/21 07:36:33 guy Exp $
+ * $Id: packet-dcerpc-mgmt.c,v 1.5 2002/08/02 23:35:48 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -28,10 +28,6 @@
 #endif
 
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <string.h>
 
 #include <glib.h>
@@ -54,7 +50,7 @@ static dcerpc_sub_dissector mgmt_dissectors[] = {
     { 2, "rpc__mgmt_is_server_listening", NULL, NULL },
     { 3, "rpc__mgmt_stop_server_listening", NULL, NULL },
     { 4, "rpc__mgmt_inq_princ_name", NULL, NULL },
-    { 0, NULL, NULL, NULL },
+    { 0, NULL, NULL, NULL }
 };
 
 
@@ -67,7 +63,7 @@ proto_register_mgmt (void)
 #endif
 
 	static gint *ett[] = {
-		&ett_mgmt,
+		&ett_mgmt
 	};
 	proto_mgmt = proto_register_protocol ("DCE/RPC Remote Management", "MGMT", "mgmt");
 #if 0
@@ -80,5 +76,5 @@ void
 proto_reg_handoff_mgmt (void)
 {
 	/* Register the protocol as dcerpc */
-	dcerpc_init_uuid (proto_mgmt, ett_mgmt, &uuid_mgmt, ver_mgmt, mgmt_dissectors);
+	dcerpc_init_uuid (proto_mgmt, ett_mgmt, &uuid_mgmt, ver_mgmt, mgmt_dissectors, -1);
 }
