@@ -2,7 +2,7 @@
  * Routines for DCERPC over SMB packet disassembly
  * Copyright 2001, Tim Potter <tpot@samba.org>
  *
- * $Id: packet-dcerpc-nt.c,v 1.35 2002/05/15 03:28:43 tpot Exp $
+ * $Id: packet-dcerpc-nt.c,v 1.42 2002/08/07 00:54:32 tpot Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -347,28 +347,6 @@ int prs_UNISTR2(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	return offset;
 }
 
-/* Parse a policy handle. */
-
-int prs_policy_hnd(tvbuff_t *tvb, int offset, packet_info *pinfo _U_, 
-		   proto_tree *tree, const guint8 **data)
-{
-	const guint8 *data8;
-
-	offset = prs_align(offset, 4);
-
-	proto_tree_add_text(tree, tvb, offset, 20, "Policy Handle: %s", 
-                tvb_bytes_to_str(tvb, offset, 20));
-
-	data8 = tvb_get_ptr(tvb, offset, 20);
-	
-	if (data)
-		*data = data8;
-
-	return offset + 20;
-}
-
-
-
 /* following are a few functions for dissecting common structures used by NT 
    services. These might need to be cleaned up at a later time but at least we get
    them out of the real service dissectors.
@@ -542,28 +520,28 @@ dissect_ndr_nt_STRING_string (tvbuff_t *tvb, int offset,
 	}
 
         offset = dissect_ndr_uint32 (tvb, offset, pinfo, tree, drep,
-                                     hf_nt_str_len, &len);
+                                     hf_nt_str_max_len, &max_len);
         offset = dissect_ndr_uint32 (tvb, offset, pinfo, tree, drep,
                                      hf_nt_str_off, &off);
         offset = dissect_ndr_uint32 (tvb, offset, pinfo, tree, drep,
-                                     hf_nt_str_max_len, &max_len);
+                                     hf_nt_str_len, &len);
 
 	old_offset=offset;
 	hfi = proto_registrar_get_nth(di->hf_index);
 
 	switch(hfi->type){
 	case FT_STRING:
-		offset = prs_uint8s(tvb, offset, pinfo, tree, max_len,
+		offset = prs_uint8s(tvb, offset, pinfo, tree, len,
 			&text_offset, NULL);
-		text = tvb_get_ptr(tvb, text_offset, max_len);
+		text = tvb_get_ptr(tvb, text_offset, len);
 		proto_tree_add_string_format(tree, di->hf_index, 
 			tvb, old_offset, offset-old_offset,
 			text, "%s: %s", hfi->name, text);
 		break;
 	case FT_BYTES:
 		text = NULL;
-		proto_tree_add_item(tree, di->hf_index, tvb, offset, max_len, FALSE);
-		offset += max_len;
+		proto_tree_add_item(tree, di->hf_index, tvb, offset, len, FALSE);
+		offset += len;
 		break;
 	default:
 		text = NULL;
@@ -688,7 +666,7 @@ static guint pol_hash_fn(gconstpointer k)
 
 /* Return true if a policy handle is all zeros */
 
-static gboolean is_null_pol(const guint8 *policy_hnd)
+static gboolean is_null_pol(e_ctx_hnd *policy_hnd)
 {
 	static guint8 null_policy_hnd[20];
 
@@ -706,15 +684,15 @@ static gint pol_hash_compare(gconstpointer k1, gconstpointer k2)
 		      sizeof(key1->policy_hnd)) == 0;
 }
 
-/* Store a policy handle */
+/* Store the open and close frame numbers of a policy handle */
 
-void dcerpc_smb_store_pol(const guint8 *policy_hnd, char *name,
-			  guint32 open_frame, guint32 close_frame)
+void dcerpc_smb_store_pol_pkts(e_ctx_hnd *policy_hnd, guint32 open_frame, 
+			       guint32 close_frame)
 {
 	pol_hash_key *key;
 	pol_hash_value *value;
 
-	if (is_null_pol(policy_hnd))
+	if (is_null_pol(policy_hnd) || (open_frame == 0 && close_frame == 0))
 		return;
 
 	/* Look up existing value */
@@ -727,15 +705,6 @@ void dcerpc_smb_store_pol(const guint8 *policy_hnd, char *name,
 
 		/* Update existing value */
 
-		if (value->name && name) {
-#ifdef DEBUG_HASH_COLL
-			if (strcmp(value->name, name) != 0)
-				g_warning("dcerpc_smb: pol_hash name collision %s/%s\n", value->name, name);
-#endif
-			free(value->name);
-			value->name = strdup(name);
-		}
-
 		if (open_frame) {
 #ifdef DEBUG_HASH_COLL
 			if (value->open_frame != open_frame)
@@ -762,6 +731,51 @@ void dcerpc_smb_store_pol(const guint8 *policy_hnd, char *name,
 	value->open_frame = open_frame;
 	value->close_frame = close_frame;
 
+	value->name = NULL;
+
+	g_hash_table_insert(pol_hash, key, value);
+}
+
+/* Store a text string with a policy handle */
+
+void dcerpc_smb_store_pol_name(e_ctx_hnd *policy_hnd, char *name)
+{
+	pol_hash_key *key;
+	pol_hash_value *value;
+
+	if (is_null_pol(policy_hnd))
+		return;
+
+	/* Look up existing value */
+
+	key = g_mem_chunk_alloc(pol_hash_key_chunk);
+
+	memcpy(&key->policy_hnd, policy_hnd, sizeof(key->policy_hnd));
+
+	if ((value = g_hash_table_lookup(pol_hash, key))) {
+
+		/* Update existing value */
+
+		if (value->name && name) {
+#ifdef DEBUG_HASH_COLL
+			if (strcmp(value->name, name) != 0)
+				g_warning("dcerpc_smb: pol_hash name collision %s/%s\n", value->name, name);
+#endif
+			free(value->name);
+		}
+
+		value->name = strdup(name);
+
+		return;
+	}
+
+	/* Create a new value */
+
+	value = g_mem_chunk_alloc(pol_hash_value_chunk);
+
+	value->open_frame = 0;
+	value->close_frame = 0;
+
 	if (name)
 		value->name = strdup(name);
 	else
@@ -772,7 +786,7 @@ void dcerpc_smb_store_pol(const guint8 *policy_hnd, char *name,
 
 /* Retrieve a policy handle */
 
-gboolean dcerpc_smb_fetch_pol(const guint8 *policy_hnd, char **name, 
+gboolean dcerpc_smb_fetch_pol(e_ctx_hnd *policy_hnd, char **name, 
 			      guint32 *open_frame, guint32 *close_frame)
 {
 	pol_hash_key key;
@@ -795,21 +809,20 @@ gboolean dcerpc_smb_fetch_pol(const guint8 *policy_hnd, char **name,
 
 	value = g_hash_table_lookup(pol_hash, &key);
 
-	if (!value)
-		return FALSE;
-
 	/* Return name and frame numbers */
+	
+	if (value) {
+		if (name)
+			*name = value->name;
 
-	if (name)
-		*name = value->name;
+		if (open_frame)
+			*open_frame = value->open_frame;
 
-	if (open_frame)
-		*open_frame = value->open_frame;
+		if (close_frame)
+			*close_frame = value->close_frame;
+	}
 
-	if (close_frame)
-		*close_frame = value->close_frame;
-
-	return TRUE;
+	return value != NULL;
 }
 
 /* Iterator to free a policy handle key/value pair */
@@ -924,10 +937,10 @@ dissect_ntstatus(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 	offset = dissect_ndr_uint32(tvb, offset, pinfo, tree, drep,
 				    hfindex, &status);
 
-	if (status != 0 && check_col(pinfo->cinfo, COL_INFO))
+	if (tree && status != 0 && check_col(pinfo->cinfo, COL_INFO))
 		col_append_fstr(pinfo->cinfo, COL_INFO, ", %s",
 				val_to_str(status, NT_errors, 
-					   "Unknown error"));
+					   "Unknown error 0x%08x"));
 	if (pdata)
 		*pdata = status;
 
@@ -946,10 +959,10 @@ dissect_doserror(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 	offset = dissect_ndr_uint32(tvb, offset, pinfo, tree, drep,
 				    hfindex, &status);
 
-	if (status != 0 && check_col(pinfo->cinfo, COL_INFO))
+	if (tree && status != 0 && check_col(pinfo->cinfo, COL_INFO))
 		col_append_fstr(pinfo->cinfo, COL_INFO, ", %s",
 				val_to_str(status, DOS_errors, 
-					   "Unknown error"));
+					   "Unknown error 0x%08x"));
 	if (pdata)
 		*pdata = status;
 
@@ -963,7 +976,6 @@ dissect_nt_policy_hnd(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 		      proto_tree *tree, char *drep, int hfindex, 
 		      e_ctx_hnd *pdata, gboolean is_open, gboolean is_close)
 {
-	dcerpc_info *di = (dcerpc_info *)pinfo->private_data;
 	proto_item *item;
 	proto_tree *subtree;
 	e_ctx_hnd hnd;
@@ -983,18 +995,12 @@ dissect_nt_policy_hnd(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 
 	/* Store request/reply information */
 		
-	if (di->request) {
-		dcerpc_smb_store_pol((const guint8 *)&hnd, NULL, 0,
-				     is_close ? pinfo->fd->num : 0);
-	} else {
-		dcerpc_smb_store_pol((const guint8 *)&hnd, NULL, 
-				     is_open ? pinfo->fd->num: 0, 0);
-	}
+	dcerpc_smb_store_pol_pkts(&hnd, 0, is_close ? pinfo->fd->num : 0);
+	dcerpc_smb_store_pol_pkts(&hnd, is_open ? pinfo->fd->num: 0, 0);
 
 	/* Insert request/reply information if known */
 
-	if (dcerpc_smb_fetch_pol((const guint8 *)&hnd, &name, &open_frame, 
-				 &close_frame)) {
+	if (dcerpc_smb_fetch_pol(&hnd, &name, &open_frame, &close_frame)) {
 
 		if (open_frame)
 			proto_tree_add_text(subtree, tvb, old_offset,
@@ -1056,3 +1062,42 @@ dissect_ndr_uint8s(tvbuff_t *tvb, gint offset, packet_info *pinfo,
     return dissect_dcerpc_uint8s(tvb, offset, pinfo, 
                                  tree, drep, hfindex, length, pdata);
 }
+
+int
+dissect_dcerpc_uint16s(tvbuff_t *tvb, gint offset, packet_info *pinfo _U_,
+                      proto_tree *tree, char *drep, int hfindex, 
+		      int length, guint16 **pdata)
+{
+    guint16 *data;
+
+    data = (guint16 *)tvb_get_ptr(tvb, offset, length * 2);
+
+    if (tree) {
+        proto_tree_add_item (tree, hfindex, tvb, offset, length * 2, (drep[0] & 0x10));
+    }
+
+    if (pdata)
+        *pdata = data;
+
+    return offset + length * 2;
+}
+
+int
+dissect_ndr_uint16s(tvbuff_t *tvb, gint offset, packet_info *pinfo,
+                   proto_tree *tree, char *drep, 
+                   int hfindex, int length, guint16 **pdata)
+{
+    dcerpc_info *di;
+
+    di=pinfo->private_data;
+    if(di->conformant_run){
+      /* just a run to handle conformant arrays, no scalars to dissect */
+      return offset;
+    }
+
+    if (offset % 2)
+        offset++;
+
+    return dissect_dcerpc_uint16s(tvb, offset, pinfo, 
+                                 tree, drep, hfindex, length, pdata);
+}
