@@ -2,7 +2,7 @@
  * Routines for DCOM OXID Resolver
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  *
- * $Id: packet-dcerpc-oxid.c,v 1.2 2002/01/21 07:36:33 guy Exp $
+ * $Id: packet-dcerpc-oxid.c,v 1.5 2002/08/02 23:35:48 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -27,18 +27,12 @@
 #include "config.h"
 #endif
 
-
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <string.h>
 
 #include <glib.h>
 #include <epan/packet.h>
 #include "packet-dcerpc.h"
 
-
 static int proto_oxid = -1;
 
 static gint ett_oxid = -1;
@@ -46,7 +40,6 @@ static gint ett_oxid = -1;
 static e_uuid_t uuid_oxid = { 0x99fcfec4, 0x5260, 0x101b, { 0xbb, 0xcb, 0x00, 0xaa, 0x00, 0x21, 0x34, 0x7a } };
 static guint16  ver_oxid = 0;
 
-
 static dcerpc_sub_dissector oxid_dissectors[] = {
     { 0, "ResolveOxid", NULL, NULL },
     { 1, "SimplePing", NULL, NULL },
@@ -55,7 +48,6 @@ static dcerpc_sub_dissector oxid_dissectors[] = {
     { 0, NULL, NULL, NULL },
 };
 
-
 void
 proto_register_oxid (void)
 {
@@ -65,7 +57,7 @@ proto_register_oxid (void)
 #endif
 
 	static gint *ett[] = {
-		&ett_oxid,
+		&ett_oxid
 	};
 	proto_oxid = proto_register_protocol ("DCOM OXID Resolver", "OXID", "oxid");
 #if 0
@@ -78,5 +70,5 @@ void
 proto_reg_handoff_oxid (void)
 {
 	/* Register the protocol as dcerpc */
-	dcerpc_init_uuid (proto_oxid, ett_oxid, &uuid_oxid, ver_oxid, oxid_dissectors);
+	dcerpc_init_uuid (proto_oxid, ett_oxid, &uuid_oxid, ver_oxid, oxid_dissectors, -1);
 }
