@@ -1,7 +1,7 @@
 /* packet-dcerpc.h
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  *
- * $Id: packet-dcerpc.h,v 1.15 2002/05/10 02:30:22 tpot Exp $
+ * $Id: packet-dcerpc.h,v 1.18 2002/06/24 00:03:18 tpot Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -74,21 +74,26 @@ typedef struct _e_dce_dg_common_hdr_t {
 
 
 
-#define PDU_REQ        0
-#define PDU_PING       1
-#define PDU_RESP       2
-#define PDU_FAULT      3
-#define PDU_WORKING    4
-#define PDU_NOCALL     5
-#define PDU_REJECT     6
-#define PDU_ACK        7
-#define PDU_FACK       9
-#define PDU_BIND      11
-#define PDU_BIND_ACK  12
-#define PDU_BIND_NAK  13
-#define PDU_ALTER     14
-#define PDU_ALTER_ACK 15
-#define PDU_AUTH3     16
+#define PDU_REQ         0
+#define PDU_PING        1
+#define PDU_RESP        2
+#define PDU_FAULT       3
+#define PDU_WORKING     4
+#define PDU_NOCALL      5
+#define PDU_REJECT      6
+#define PDU_ACK         7
+#define PDU_CL_CANCEL   8
+#define PDU_FACK        9
+#define PDU_CANCEL_ACK 10
+#define PDU_BIND       11
+#define PDU_BIND_ACK   12
+#define PDU_BIND_NAK   13
+#define PDU_ALTER      14
+#define PDU_ALTER_ACK  15
+#define PDU_AUTH3      16
+#define PDU_SHUTDOWN   17
+#define PDU_CO_CANCEL  18
+#define PDU_ORPHANED   19
 
 /*
  * helpers for packet-dcerpc.c and packet-dcerpc-ndr.c
@@ -140,6 +145,7 @@ typedef int (dcerpc_dissect_fnct_t)(tvbuff_t *tvb, int offset, packet_info *pinf
 #define NDR_POINTER_REF		1
 #define NDR_POINTER_UNIQUE	2
 #define NDR_POINTER_PTR		3
+	
 int dissect_ndr_pointer (tvbuff_t *tvb, gint offset, packet_info *pinfo,
                         proto_tree *tree, char *drep, 
                         dcerpc_dissect_fnct_t *fnct, int type, char *text, int hf_index, int levels);
@@ -164,7 +170,7 @@ typedef struct _dcerpc_sub_dissector {
 } dcerpc_sub_dissector;
 
 /* registration function for subdissectors */
-void dcerpc_init_uuid (int proto, int ett, e_uuid_t *uuid, guint16 ver, dcerpc_sub_dissector *procs);
+void dcerpc_init_uuid (int proto, int ett, e_uuid_t *uuid, guint16 ver, dcerpc_sub_dissector *procs, int opnum_hf);
 
 /* Private data structure to pass to DCERPC dissector. This is used to
    pass transport specific information down to the dissector from the
