@@ -1,7 +1,7 @@
 /* packet-dns.c
  * Routines for DNS packet disassembly
  *
- * $Id: packet-dns.c,v 1.87 2002/05/15 07:24:20 guy Exp $
+ * $Id: packet-dns.c,v 1.91 2002/08/19 16:02:45 itojun Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -26,8 +26,8 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
+#ifdef NEED_SNPRINTF_H
+# include "snprintf.h"
 #endif
 
 #include <stdio.h>
@@ -76,6 +76,8 @@ static gboolean dns_desegment = TRUE;
 /* Ports used for DNS. */
 #define UDP_PORT_DNS     53
 #define TCP_PORT_DNS     53
+#define UDP_PORT_MDNS    5353
+#define TCP_PORT_MDNS    5353
 
 /* Offsets of fields in the DNS header. */
 #define	DNS_ID		0
@@ -266,7 +268,7 @@ http://www.microsoft.com/windows2000/library/resources/reskit/samplechapters/cnc
 
    which discuss them to some extent. */
 static char *
-dns_type_name (u_int type)
+dns_type_name (guint type)
 {
   char *type_names[] = {
     "unused",
@@ -358,7 +360,7 @@ dns_type_name (u_int type)
 
 
 static char *
-dns_long_type_name (u_int type)
+dns_long_type_name (guint type)
 {
   char *type_names[] = {
     "unused",
@@ -536,17 +538,55 @@ get_dns_name(tvbuff_t *tvb, int offset, int dns_data_offset,
 	{
 	  int bit_count;
 	  int label_len;
+	  int print_len;
 
 	  bit_count = tvb_get_guint8(tvb, offset);
 	  offset++;
 	  label_len = (bit_count - 1) / 8 + 1;
 	
-	  np += sprintf(np, "\\[x");
+	  if (maxname > 0) {
+	    print_len = snprintf(np, maxname + 1, "\\[x");
+	    if (print_len != -1) {
+	      /* Some versions of snprintf return -1 if they'd truncate
+	         the output. */
+	      np += print_len;
+	      maxname -= print_len;
+	    } else {
+	      /* Nothing printed, as there's no room.
+	         Suppress all subsequent printing. */
+	      maxname = 0;
+	    }
+	  }
 	  while(label_len--) {
-	    np += sprintf(np, "%02x", tvb_get_guint8(tvb, offset));
+	    if (maxname > 0) {
+	      print_len = snprintf(np, maxname + 1, "%02x",
+	        tvb_get_guint8(tvb, offset));
+	      if (print_len != -1) {
+		/* Some versions of snprintf return -1 if they'd truncate
+		 the output. */
+		np += print_len;
+		maxname -= print_len;
+	      } else {
+		/* Nothing printed, as there's no room.
+		   Suppress all subsequent printing. */
+		maxname = 0;
+	      }
+	    }
 	    offset++;
 	  }
-	  np += sprintf(np, "/%d]", bit_count);
+	  if (maxname > 0) {
+	    print_len = snprintf(np, maxname + 1, "/%d]", bit_count);
+	    if (print_len != -1) {
+	      /* Some versions of snprintf return -1 if they'd truncate
+	         the output. */
+	      np += print_len;
+	      maxname -= print_len;
+	    } else {
+	      /* Nothing printed, as there's no room.
+	         Suppress all subsequent printing. */
+	      maxname = 0;
+	    }
+	  }
 	}
 	break;
 
@@ -731,7 +771,7 @@ dissect_dns_query(tvbuff_t *tvb, int offset, int dns_data_offset,
 proto_tree *
 add_rr_to_tree(proto_item *trr, int rr_type, tvbuff_t *tvb, int offset,
   const char *name, int namelen, const char *type_name, const char *class_name,
-  u_int ttl, u_short data_len)
+  guint ttl, gushort data_len)
 {
   proto_tree *rr_tree;
 
@@ -752,7 +792,7 @@ add_rr_to_tree(proto_item *trr, int rr_type, tvbuff_t *tvb, int offset,
 static proto_tree *
 add_opt_rr_to_tree(proto_item *trr, int rr_type, tvbuff_t *tvb, int offset,
   const char *name, int namelen, const char *type_name, int class,
-  u_int ttl, u_short data_len)
+  guint ttl, gushort data_len)
 {
   proto_tree *rr_tree;
 
@@ -828,8 +868,8 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
   int data_offset;
   int cur_offset;
   int data_start;
-  u_int ttl;
-  u_short data_len;
+  guint ttl;
+  gushort data_len;
   proto_tree *rr_tree = NULL;
   proto_item *trr = NULL;
 
@@ -2107,4 +2147,6 @@ proto_reg_handoff_dns(void)
   dns_tcp_handle = create_dissector_handle(dissect_dns_tcp, proto_dns);
   dissector_add("udp.port", UDP_PORT_DNS, dns_udp_handle);
   dissector_add("tcp.port", TCP_PORT_DNS, dns_tcp_handle);
+  dissector_add("udp.port", UDP_PORT_MDNS, dns_udp_handle);
+  dissector_add("tcp.port", TCP_PORT_MDNS, dns_tcp_handle);
 }
