@@ -1,7 +1,7 @@
 /* ethertype.c
  * Routines for calling the right protocol for the ethertype.
  *
- * $Id: packet-ethertype.c,v 1.28 2002/04/24 06:03:33 guy Exp $
+ * $Id: packet-ethertype.c,v 1.30 2002/08/02 23:35:49 jmayer Exp $
  *
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -28,10 +28,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <glib.h>
 #include <epan/packet.h>
 #include "packet-ip.h"
@@ -77,6 +73,7 @@ const value_string etype_vals[] = {
     {ETHERTYPE_DEC_SCA,		"DEC LAVC/SCA"			},
     {ETHERTYPE_ETHBRIDGE,	"Transparent Ethernet bridging" },
     {ETHERTYPE_CGMP,		"Cisco Group Management Protocol" },
+    {ETHERTYPE_SLOW_PROTOCOLS,	"Slow Protocols"		},
 
     /*
      * NDISWAN on Windows translates Ethernet frames from higher-level
@@ -103,7 +100,7 @@ static void add_trailer(proto_tree *fh_tree, int trailer_id, tvbuff_t *tvb,
     tvbuff_t *next_tvb, int offset_after_etype, guint length_before);
 
 void
-capture_ethertype(guint16 etype, const u_char *pd, int offset, int len,
+capture_ethertype(guint16 etype, const guchar *pd, int offset, int len,
 		  packet_counts *ld)
 {
   switch (etype) {
