@@ -5,6 +5,8 @@
  * Based on the code from packet-gvrp.c (GVRP) from
  * Kevin Shi <techishi@ms22.hinet.net> Copyright 2000
  *
+ * $Id: packet-gmrp.c,v 1.9 2002/08/02 23:35:49 jmayer Exp $
+ *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
@@ -32,20 +34,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <glib.h>
 
-#ifdef NEED_SNPRINTF_H
-# include "snprintf.h"
-#endif
-
 #include <epan/packet.h>
 #include "llcsaps.h"
 
@@ -159,7 +149,9 @@ dissect_gmrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	{
 	    proto_tree_add_text(gmrp_tree, tvb, GARP_PROTOCOL_ID, sizeof(guint16), 
  "   (Warning: this version of Ethereal only knows about protocol id = 1)");
-	    call_dissector(data_handle,tvb_new_subset(tvb, GARP_PROTOCOL_ID + sizeof(guint16), -1,tvb_reported_length_remaining(tvb,GARP_PROTOCOL_ID + sizeof(guint16))),pinfo, tree);
+	    call_dissector(data_handle,
+	        tvb_new_subset(tvb, GARP_PROTOCOL_ID + sizeof(guint16), -1, -1),
+	        pinfo, tree);
 	    return;
 	}
 
@@ -189,7 +181,9 @@ dissect_gmrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				}
 				else
 				{
-					call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+					call_dissector(data_handle,
+					    tvb_new_subset(tvb, offset, -1, -1),
+					    pinfo, tree);
 					return;
 				}
 			}
@@ -206,7 +200,9 @@ dissect_gmrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			/* GMRP supports Group Membership and Service Requirement as attribute types */
 			if ( (octet != GMRP_ATTRIBUTE_TYPE_GROUP_MEMBERSHIP) && (octet != GMRP_ATTRIBUTE_TYPE_SERVICE_REQUIREMENT) )
 			{
-				call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+				call_dissector(data_handle,
+				    tvb_new_subset(tvb, offset, -1, -1), pinfo,
+				    tree);
 				return;
 			}
 
@@ -239,7 +235,9 @@ dissect_gmrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					}
 					else
 					{
-						call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+						call_dissector(data_handle,
+						    tvb_new_subset(tvb, offset, -1, -1),
+						    pinfo, tree);
 						return;
 					}
 				}
@@ -270,7 +268,9 @@ dissect_gmrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					case GMRP_EVENT_LEAVEALL:
 						if (octet != GMRP_LENGTH_LEAVEALL)
 						{
-							call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+							call_dissector(data_handle,
+							    tvb_new_subset(tvb, offset, -1, -1),
+							    pinfo, tree);
 							return;
 						}
 						break;
@@ -282,7 +282,9 @@ dissect_gmrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					 case GMRP_EVENT_EMPTY:
 						if ( (octet != GMRP_GROUP_MEMBERSHIP_NON_LEAVEALL) && (octet != GMRP_SERVICE_REQUIREMENT_NON_LEAVEALL) )
 						{
-							call_dissector(data_handle,tvb_new_subset(tvb, offset, -1,tvb_reported_length_remaining(tvb,offset)),pinfo, tree);
+							call_dissector(data_handle,
+							    tvb_new_subset(tvb, offset, -1, -1),
+							    pinfo, tree);
 							return;
 						}
 
@@ -309,14 +311,18 @@ dissect_gmrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					}
 					else
 					{
-						call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+						call_dissector(data_handle,
+						    tvb_new_subset(tvb, offset, -1, -1),
+						    pinfo, tree);
 						return;
 					}
 
 					break;
 
 					 default:
-					call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+					call_dissector(data_handle,
+					    tvb_new_subset(tvb, offset, -1, -1),
+					    pinfo, tree);
 					return;
 					}
 				}
