@@ -2,7 +2,7 @@
  * Routines for hclnfsd (Hummingbird NFS Daemon) dissection
  * Copyright 2001, Mike Frisch <frisch@hummingbird.com>
  *
- * $Id: packet-hclnfsd.c,v 1.14 2002/05/10 23:20:38 guy Exp $
+ * $Id: packet-hclnfsd.c,v 1.16 2002/08/02 23:35:50 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -29,10 +29,6 @@
 #include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <string.h>
 
 #include "packet-rpc.h"
@@ -204,11 +200,11 @@ dissect_hclnfsd_authorize_call(tvbuff_t *tvb, int offset, packet_info *pinfo _U_
 				newoffset = dissect_rpc_string(tvb, ident_tree,
 					hf_hclnfsd_auth_ident_obscure, offset, &ident);
 
-				proto_item_set_len(ident_item, newoffset - offset);
-
 				if (ident)
 				{
-					ident_len = newoffset - offset;
+					ident_len = strlen(ident);
+
+					proto_item_set_len(ident_item, ident_len);
 
 					hclnfsd_decode_obscure(ident, ident_len);
 
