@@ -3,7 +3,10 @@
  *
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-http.c,v 1.47 2002/04/01 21:12:30 guy Exp $
+ * Copyright 2002, Tim Potter <tpot@samba.org>
+ * Copyright 1999, Andrew Tridgell <tridge@samba.org>
+ *
+ * $Id: packet-http.c,v 1.55 2002/08/14 23:34:20 tpot Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -28,10 +31,6 @@
 #include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <string.h>
 #include <ctype.h>
 
@@ -54,6 +53,7 @@ static int hf_http_response = -1;
 static int hf_http_request = -1;
 
 static gint ett_http = -1;
+static gint ett_http_ntlmssp = -1;
 
 static dissector_handle_t data_handle;
 static dissector_handle_t http_handle;
@@ -69,6 +69,13 @@ static dissector_handle_t http_handle;
 #define TCP_PORT_SSDP			1900
 #define UDP_PORT_SSDP			1900
 
+/*
+ * Some headers that we dissect more deeply - Microsoft's abomination
+ * called NTLMSSP over HTTP.
+ */
+#define NTLMSSP_AUTH    "Authorization: NTLM "
+#define NTLMSSP_WWWAUTH "WWW-Authenticate: NTLM "
+
 /*
  * Protocols implemented atop HTTP.
  */
@@ -77,11 +84,76 @@ typedef enum {
 	PROTO_SSDP		/* Simple Service Discovery Protocol */
 } http_proto_t;
 
-static int is_http_request_or_reply(const u_char *data, int linelen, http_type_t *type);
+static int is_http_request_or_reply(const guchar *data, int linelen, http_type_t *type);
 
 static dissector_table_t subdissector_table;
 static heur_dissector_list_t heur_subdissector_list;
 
+static dissector_handle_t ntlmssp_handle=NULL;
+
+/* Decode a base64 string in-place - simple and slow algorithm.
+   Return length of result. Taken from rproxy/librsync/base64.c by
+   Andrew Tridgell. */
+
+static size_t base64_decode(char *s)
+{
+	const char *b64 = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+	int bit_offset, byte_offset, idx, i, n;
+	unsigned char *d = (unsigned char *)s;
+	char *p;
+
+	n=i=0;
+
+	while (*s && (p=strchr(b64, *s))) {
+		idx = (int)(p - b64);
+		byte_offset = (i*6)/8;
+		bit_offset = (i*6)%8;
+		d[byte_offset] &= ~((1<<(8-bit_offset))-1);
+		if (bit_offset < 3) {
+			d[byte_offset] |= (idx << (2-bit_offset));
+			n = byte_offset+1;
+		} else {
+			d[byte_offset] |= (idx >> (bit_offset-2));
+			d[byte_offset+1] = 0;
+			d[byte_offset+1] |= (idx << (8-(bit_offset-2))) & 0xFF;
+			n = byte_offset+2;
+		}
+		s++; i++;
+	}
+
+	return n;
+}
+
+/* Return a tvb that contains the binary representation of a base64
+   string */
+
+static tvbuff_t *
+base64_to_tvb(char *base64)
+{
+	tvbuff_t *tvb;
+	char *data = g_strdup(base64);
+	size_t len;
+
+	len = base64_decode(data);
+	tvb = tvb_new_real_data(data, len, len);
+
+	tvb_set_free_cb(tvb, g_free);
+
+	return tvb;
+}
+
+static void
+dissect_http_ntlmssp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, char *line)
+{
+	tvbuff_t *ntlmssp_tvb;
+
+	ntlmssp_tvb = base64_to_tvb(line);
+	tvb_set_child_real_data_tvbuff(tvb, ntlmssp_tvb);
+	add_new_data_source(pinfo, ntlmssp_tvb, "NTLMSSP Data");
+
+	call_dissector(ntlmssp_handle, ntlmssp_tvb, pinfo, tree);
+}
+
 static void
 dissect_http(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
@@ -90,11 +162,11 @@ dissect_http(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_tree	*http_tree = NULL;
 	proto_item	*ti = NULL;
 	gint		offset = 0;
-	const u_char	*line;
+	const guchar	*line;
 	gint		next_offset;
-	const u_char	*linep, *lineend;
+	const guchar	*linep, *lineend;
 	int		linelen;
-	u_char		c;
+	guchar		c;
 	http_type_t     http_type;
 	int		datalen;
 
@@ -124,7 +196,8 @@ dissect_http(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		 * is not longer than what's in the buffer, so the
 		 * "tvb_get_ptr()" call won't throw an exception.
 		 */
-		linelen = tvb_find_line_end(tvb, offset, -1, &next_offset);
+		linelen = tvb_find_line_end(tvb, offset, -1, &next_offset,
+		    FALSE);
 		line = tvb_get_ptr(tvb, offset, linelen);
 		http_type = HTTP_OTHERS;	/* type not known yet */
 		if (is_http_request_or_reply(line, linelen, &http_type))
@@ -148,7 +221,8 @@ dissect_http(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		/*
 		 * Find the end of the line.
 		 */
-		linelen = tvb_find_line_end(tvb, offset, -1, &next_offset);
+		linelen = tvb_find_line_end(tvb, offset, -1, &next_offset,
+		    FALSE);
 
 		/*
 		 * Get a buffer that refers to the line.
@@ -225,9 +299,28 @@ dissect_http(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		 * Put this line.
 		 */
 		if (tree) {
-			proto_tree_add_text(http_tree, tvb, offset,
-			    next_offset - offset, "%s",
-			    tvb_format_text(tvb, offset, next_offset - offset));
+			proto_tree *hdr_tree;
+			proto_item *hdr_item;
+			char *text;
+
+			text = tvb_format_text(tvb, offset, next_offset - offset);
+
+			hdr_item = proto_tree_add_text(http_tree, tvb, offset,
+			    next_offset - offset, "%s", text);
+
+			if (strncmp(text, NTLMSSP_AUTH, strlen(NTLMSSP_AUTH)) == 0) {
+				hdr_tree = proto_item_add_subtree(
+					hdr_item, ett_http_ntlmssp);
+				text += strlen(NTLMSSP_AUTH);
+				dissect_http_ntlmssp(tvb, pinfo, hdr_tree, text);
+			}
+
+			if (strncmp(text, NTLMSSP_WWWAUTH, strlen(NTLMSSP_WWWAUTH)) == 0) {
+				hdr_tree = proto_item_add_subtree(
+					hdr_item, ett_http_ntlmssp);
+				text += strlen(NTLMSSP_WWWAUTH);
+				dissect_http_ntlmssp(tvb, pinfo, hdr_tree, text);
+			}
 		}
 		offset = next_offset;
 	}
@@ -280,8 +373,11 @@ dissect_http(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			 */
 			if (ti != NULL)
 				proto_item_set_len(ti, offset);
-		} else
-			call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, http_tree);
+		} else {
+			call_dissector(data_handle,
+			    tvb_new_subset(tvb, offset, -1, -1), pinfo,
+			    http_tree);
+		}
 	}
 }
 
@@ -290,7 +386,7 @@ dissect_http(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
  * anyway.
  */
 static int
-is_http_request_or_reply(const u_char *data, int linelen, http_type_t *type)
+is_http_request_or_reply(const guchar *data, int linelen, http_type_t *type)
 {
 	int isHttpRequestOrReply = FALSE;
 
@@ -316,7 +412,7 @@ is_http_request_or_reply(const u_char *data, int linelen, http_type_t *type)
 		*type = HTTP_RESPONSE;
 		isHttpRequestOrReply = TRUE;	/* response */
 	} else {
-		u_char * ptr = (u_char *)data;
+		guchar * ptr = (guchar *)data;
 		int		 index = 0;
 
 		/* Look for the space following the Method */
@@ -444,6 +540,7 @@ proto_register_http(void)
 	};
 	static gint *ett[] = {
 		&ett_http,
+		&ett_http_ntlmssp,
 	};
 
 	proto_http = proto_register_protocol("Hypertext Transfer Protocol",
@@ -509,4 +606,6 @@ proto_reg_handoff_http(void)
 	 */
 	dissector_add("tcp.port", TCP_PORT_SSDP, http_handle);
 	dissector_add("udp.port", UDP_PORT_SSDP, http_handle);
+
+	ntlmssp_handle = find_dissector("ntlmssp");
 }
