@@ -3,7 +3,7 @@
  *
  * Srishylam Simharajan simha@netapp.com
  *
- * packet-icap.c Mon Aug 13 17:50:19 PDT 2001 simha 
+ * $Id: packet-icap.c,v 1.11 2002/08/02 23:35:50 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -28,10 +28,6 @@
 #include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <string.h>
 #include <ctype.h>
 
@@ -59,18 +55,18 @@ static gint ett_icap = -1;
 static dissector_handle_t data_handle;
 
 #define TCP_PORT_ICAP			1344
-static int is_icap_message(const u_char *data, int linelen, icap_type_t *type);
+static int is_icap_message(const guchar *data, int linelen, icap_type_t *type);
 static void
 dissect_icap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	proto_tree	*icap_tree = NULL;
 	proto_item	*ti = NULL;
 	gint		offset = 0;
-	const u_char	*line;
+	const guchar	*line;
 	gint		next_offset;
-	const u_char	*linep, *lineend;
+	const guchar	*linep, *lineend;
 	int		linelen;
-	u_char		c;
+	guchar		c;
 	icap_type_t     icap_type;
 	int		datalen;
 
@@ -88,7 +84,8 @@ dissect_icap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		 * is not longer than what's in the buffer, so the
 		 * "tvb_get_ptr()" call won't throw an exception.
 		 */
-		linelen = tvb_find_line_end(tvb, offset, -1, &next_offset);
+		linelen = tvb_find_line_end(tvb, offset, -1, &next_offset,
+		    FALSE);
 		line = tvb_get_ptr(tvb, offset, linelen);
 		icap_type = ICAP_OTHER;	/* type not known yet */
 		if (is_icap_message(line, linelen, &icap_type))
@@ -114,7 +111,8 @@ dissect_icap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		/*
 		 * Find the end of the line.
 		 */
-		linelen = tvb_find_line_end(tvb, offset, -1, &next_offset);
+		linelen = tvb_find_line_end(tvb, offset, -1, &next_offset,
+		    FALSE);
 
 		/*
 		 * Get a buffer that refers to the line.
@@ -226,13 +224,14 @@ is_icap_header:
 
 	datalen = tvb_length_remaining(tvb, offset);
 	if (datalen > 0) {
-		call_dissector(data_handle,tvb_new_subset(tvb, offset, -1, tvb_reported_length_remaining(tvb,offset)), pinfo, icap_tree);
+		call_dissector(data_handle,
+		    tvb_new_subset(tvb, offset, -1, -1), pinfo, icap_tree);
 	}
 }
 
 	
 static int
-is_icap_message(const u_char *data, int linelen, icap_type_t *type)
+is_icap_message(const guchar *data, int linelen, icap_type_t *type)
 {
 #define ICAP_COMPARE(string, length, msgtype) {		\
 	if (strncmp(data, string, length) == 0) {	\
