@@ -1,7 +1,7 @@
 /* packet-ip.c
  * Routines for IP and miscellaneous IP protocol packet disassembly
  *
- * $Id: packet-ip.c,v 1.165 2002/03/31 21:43:51 guy Exp $
+ * $Id: packet-ip.c,v 1.172 2002/08/02 23:35:51 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -26,14 +26,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <glib.h>
@@ -113,6 +105,19 @@ static gint ett_ip_option_timestamp = -1;
 static gint ett_ip_fragments = -1;
 static gint ett_ip_fragment  = -1;
 
+fragment_items ip_frag_items = {
+	&ett_ip_fragment,
+	&ett_ip_fragments,
+	&hf_ip_fragments,
+	&hf_ip_fragment,
+	&hf_ip_fragment_overlap,
+	&hf_ip_fragment_overlap_conflict,
+	&hf_ip_fragment_multiple_tails,
+	&hf_ip_fragment_too_long_fragment,
+	&hf_ip_fragment_error,
+	"fragments"
+};
+
 /* Used by IPv6 as well, so not static */
 dissector_table_t ip_dissector_table;
 
@@ -334,7 +339,7 @@ ip_defragment_init(void)
 }
 
 void
-capture_ip(const u_char *pd, int offset, int len, packet_counts *ld) {
+capture_ip(const guchar *pd, int offset, int len, packet_counts *ld) {
   if (!BYTES_ARE_IN_FRAME(offset, len, IPH_MIN_LEN)) {
     ld->other++;
     return;
@@ -428,7 +433,7 @@ dissect_ipopt_route(const ip_tcp_opt *optp, tvbuff_t *tvb, int offset,
   proto_item *tf;
   int ptr;
   int optoffset = 0;
-  struct in_addr addr;
+  guint32 addr;
 
   tf = proto_tree_add_text(opt_tree, tvb, offset,      optlen, "%s (%u bytes)",
 				optp->name, optlen);
@@ -458,7 +463,7 @@ dissect_ipopt_route(const ip_tcp_opt *optp, tvbuff_t *tvb, int offset,
 
     proto_tree_add_text(field_tree, tvb, offset + optoffset, 4,
               "%s%s",
-              ((addr.s_addr == 0) ? "-" : (char *)get_hostname(addr.s_addr)),
+              ((addr == 0) ? "-" : (char *)get_hostname(addr)),
               ((optoffset == ptr) ? " <- (current)" : ""));
     optoffset += 4;
     optlen -= 4;
@@ -489,7 +494,7 @@ dissect_ipopt_timestamp(const ip_tcp_opt *optp, tvbuff_t *tvb,
     {IPOPT_TS_TSANDADDR, "Time stamp and address"                },
     {IPOPT_TS_PRESPEC,   "Time stamps for prespecified addresses"},
     {0,                  NULL                                    } };
-  struct in_addr addr;
+  guint32 addr;
   guint ts;
 
   tf = proto_tree_add_text(opt_tree, tvb, offset,      optlen, "%s:", optp->name);
@@ -528,7 +533,7 @@ dissect_ipopt_timestamp(const ip_tcp_opt *optp, tvbuff_t *tvb,
       optlen -= 8;
       proto_tree_add_text(field_tree, tvb, offset + optoffset,      8,
           "Address = %s, time stamp = %u",
-          ((addr.s_addr == 0) ? "-" :  (char *)get_hostname(addr.s_addr)),
+          ((addr == 0) ? "-" :  (char *)get_hostname(addr)),
           ts);
       optoffset += 8;
     } else {
@@ -645,7 +650,7 @@ dissect_ip_tcp_options(tvbuff_t *tvb, int offset, guint length,
 			const ip_tcp_opt *opttab, int nopts, int eol,
 			packet_info *pinfo, proto_tree *opt_tree)
 {
-  u_char            opt;
+  guchar            opt;
   const ip_tcp_opt *optp;
   opt_len_type      len_type;
   unsigned int      optlen;
@@ -835,10 +840,10 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   /* Avoids alignment problems on many architectures. */
   tvb_memcpy(tvb, (guint8 *)&iph, offset, sizeof(e_ip));
-  iph.ip_len = ntohs(iph.ip_len);
-  iph.ip_id  = ntohs(iph.ip_id);
-  iph.ip_off = ntohs(iph.ip_off);
-  iph.ip_sum = ntohs(iph.ip_sum);
+  iph.ip_len = g_ntohs(iph.ip_len);
+  iph.ip_id  = g_ntohs(iph.ip_id);
+  iph.ip_off = g_ntohs(iph.ip_off);
+  iph.ip_sum = g_ntohs(iph.ip_sum);
 
   /* Length of IP datagram.
      XXX - what if this is greater than the reported length of the
@@ -983,10 +988,6 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			     iph.ip_off & IP_MF);
 
     if (ipfd_head != NULL) {
-      fragment_data *ipfd;
-      proto_tree *ft=NULL;
-      proto_item *fi=NULL;
-
       /* OK, we have the complete reassembled payload.
          Allocate a new tvbuff, referring to the reassembled payload. */
       next_tvb = tvb_new_real_data(ipfd_head->data, ipfd_head->datalen,
@@ -998,77 +999,11 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       tvb_set_child_real_data_tvbuff(tvb, next_tvb);
 
       /* Add the defragmented data to the data source list. */
-      add_new_data_source(pinfo->fd, next_tvb, "Reassembled IPv4");
-
-      /* It's not fragmented. */
-      pinfo->fragmented = FALSE;
+      add_new_data_source(pinfo, next_tvb, "Reassembled IPv4");
 
       /* show all fragments */
-      fi = proto_tree_add_item(ip_tree, hf_ip_fragments, 
-                next_tvb, 0, -1, FALSE);
-      ft = proto_item_add_subtree(fi, ett_ip_fragments);
-      for (ipfd=ipfd_head->next; ipfd; ipfd=ipfd->next){
-        if (ipfd->flags & (FD_OVERLAP|FD_OVERLAPCONFLICT
-                          |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-          /* this fragment has some flags set, create a subtree 
-           * for it and display the flags.
-           */
-          proto_tree *fet=NULL;
-          proto_item *fei=NULL;
-          int hf;
-
-          if (ipfd->flags & (FD_OVERLAPCONFLICT
-                      |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-            hf = hf_ip_fragment_error;
-          } else {
-            hf = hf_ip_fragment;
-          }
-          fei = proto_tree_add_none_format(ft, hf, 
-                   next_tvb, ipfd->offset, ipfd->len,
-                   "Frame:%u payload:%u-%u",
-                   ipfd->frame,
-                   ipfd->offset,
-                   ipfd->offset+ipfd->len-1
-          );
-          fet = proto_item_add_subtree(fei, ett_ip_fragment);
-          if (ipfd->flags&FD_OVERLAP) {
-            proto_tree_add_boolean(fet, 
-                 hf_ip_fragment_overlap, next_tvb, 0, 0, 
-                 TRUE);
-          }
-          if (ipfd->flags&FD_OVERLAPCONFLICT) {
-            proto_tree_add_boolean(fet, 
-                 hf_ip_fragment_overlap_conflict, next_tvb, 0, 0, 
-                 TRUE);
-          }
-          if (ipfd->flags&FD_MULTIPLETAILS) {
-            proto_tree_add_boolean(fet, 
-                 hf_ip_fragment_multiple_tails, next_tvb, 0, 0, 
-                 TRUE);
-          }
-          if (ipfd->flags&FD_TOOLONGFRAGMENT) {
-            proto_tree_add_boolean(fet, 
-                 hf_ip_fragment_too_long_fragment, next_tvb, 0, 0, 
-                 TRUE);
-          }
-        } else {
-          /* nothing of interest for this fragment */
-          proto_tree_add_none_format(ft, hf_ip_fragment, 
-                   next_tvb, ipfd->offset, ipfd->len,
-                   "Frame:%u payload:%u-%u",
-                   ipfd->frame,
-                   ipfd->offset,
-                   ipfd->offset+ipfd->len-1
-          );
-        }
-      }
-      if (ipfd_head->flags & (FD_OVERLAPCONFLICT
-                        |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-        if (check_col(pinfo->cinfo, COL_INFO)) {
-          col_set_str(pinfo->cinfo, COL_INFO, "[Illegal fragments]");
-          update_col_info = FALSE;
-        }
-      }
+      update_col_info = !show_fragment_tree(ipfd_head, &ip_frag_items,
+        ip_tree, pinfo, next_tvb);
     } else {
       /* We don't have the complete reassembled payload. */
       next_tvb = NULL;
@@ -1104,7 +1039,8 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if (check_col(pinfo->cinfo, COL_INFO))
       col_add_fstr(pinfo->cinfo, COL_INFO, "Fragmented IP protocol (proto=%s 0x%02x, off=%u)",
 	ipprotostr(iph.ip_p), iph.ip_p, (iph.ip_off & IP_OFFSET) * 8);
-    call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, tree);
+    call_dissector(data_handle, tvb_new_subset(tvb, offset, -1, -1), pinfo,
+                   tree);
     pinfo->fragmented = save_fragmented;
     return;
   }
@@ -1269,7 +1205,7 @@ dissect_mip_extensions(tvbuff_t *tvb, size_t offset, proto_tree *tree)
 	default:
 	  g_warning("Unknown type(%u)!  I hope the length is right (%u)",
 				type, length);
-	  offset += length;
+	  offset += length + 2;
 	  break;
 	} /* switch type */
   } /* end while */
@@ -1576,7 +1512,8 @@ dissect_icmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
       case ICMP_ECHOREPLY:
       case ICMP_ECHO:
-	call_dissector(data_handle,tvb_new_subset(tvb, 8,-1,tvb_reported_length_remaining(tvb,8)), pinfo, icmp_tree);
+	call_dissector(data_handle, tvb_new_subset(tvb, 8, -1, -1), pinfo,
+	               icmp_tree);
 	break;
 
       case ICMP_RTRADVERT:
@@ -1593,7 +1530,8 @@ dissect_icmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		dissect_mip_extensions(tvb, 8 + i*8, icmp_tree);
 	  }
 	} else
-	  call_dissector(data_handle,tvb_new_subset(tvb, 8,-1,tvb_reported_length_remaining(tvb,8)), pinfo, icmp_tree);
+	  call_dissector(data_handle, tvb_new_subset(tvb, 8, -1, -1), pinfo,
+	                 icmp_tree);
 	break;
 
       case ICMP_TSTAMP:
