@@ -3,7 +3,7 @@
  *
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-ipp.c,v 1.30 2002/03/31 22:12:45 guy Exp $
+ * $Id: packet-ipp.c,v 1.32 2002/08/02 23:35:51 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -28,10 +28,6 @@
 #include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <string.h>
 #include <ctype.h>
 
@@ -230,8 +226,11 @@ dissect_ipp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		offset = parse_attributes(tvb, offset, ipp_tree);
 
-		if (tvb_offset_exists(tvb, offset))
-			call_dissector(data_handle,tvb_new_subset(tvb, offset,-1,tvb_reported_length_remaining(tvb,offset)), pinfo, ipp_tree);
+		if (tvb_offset_exists(tvb, offset)) {
+			call_dissector(data_handle,
+			    tvb_new_subset(tvb, offset, -1, -1), pinfo,
+			    ipp_tree);
+		}
 	}
 }
 
