@@ -1,7 +1,7 @@
 /* packet-ipv6.c
  * Routines for IPv6 packet disassembly
  *
- * $Id: packet-ipv6.c,v 1.81 2002/05/02 11:52:52 guy Exp $
+ * $Id: packet-ipv6.c,v 1.86 2002/08/03 20:06:46 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -28,18 +28,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_SYS_SOCKET_h
-#include <sys/socket.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <string.h>
 #include <stdio.h>
 #include <glib.h>
@@ -106,6 +94,19 @@ static gint ett_ipv6 = -1;
 static gint ett_ipv6_fragments = -1;
 static gint ett_ipv6_fragment  = -1;
 
+fragment_items ipv6_frag_items = {
+	&ett_ipv6_fragment,
+	&ett_ipv6_fragments,
+	&hf_ipv6_fragments,
+	&hf_ipv6_fragment,
+	&hf_ipv6_fragment_overlap,
+	&hf_ipv6_fragment_overlap_conflict,
+	&hf_ipv6_fragment_multiple_tails,
+	&hf_ipv6_fragment_too_long_fragment,
+	&hf_ipv6_fragment_error,
+	"fragments"
+};
+
 static dissector_handle_t data_handle;
 
 /* Reassemble fragmented datagrams */
@@ -195,7 +196,7 @@ dissect_frag6(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 
     tvb_memcpy(tvb, (guint8 *)&frag, offset, sizeof(frag));
     len = sizeof(frag);
-    frag.ip6f_offlg = ntohs(frag.ip6f_offlg);
+    frag.ip6f_offlg = g_ntohs(frag.ip6f_offlg);
     *offlg = frag.ip6f_offlg;
     *ident = frag.ip6f_ident;
     if (check_col(pinfo->cinfo, COL_INFO)) {
@@ -672,7 +673,7 @@ dissect_ipv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   pinfo->ipproto = ipv6.ip6_nxt; /* XXX make work TCP follow (ipproto = 6) */
 
   /* Get the payload length */
-  plen = ntohs(ipv6.ip6_plen);
+  plen = g_ntohs(ipv6.ip6_plen);
 
   /* Adjust the length of this tvbuff to include only the IPv6 datagram. */
   set_actual_length(tvb, plen + sizeof (struct ip6_hdr));
@@ -694,7 +695,7 @@ dissect_ipv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     proto_tree_add_uint(ipv6_tree, hf_ipv6_class, tvb,
 		offset + offsetof(struct ip6_hdr, ip6_flow), 4,
-		(guint8)((ntohl(ipv6.ip6_flow) >> 20) & 0xff));
+		(guint8)((g_ntohl(ipv6.ip6_flow) >> 20) & 0xff));
 
     /*
      * there should be no alignment problems for ip6_flow, since it's the first
@@ -702,9 +703,9 @@ dissect_ipv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
      */
     proto_tree_add_uint_format(ipv6_tree, hf_ipv6_flow, tvb,
 		offset + offsetof(struct ip6_hdr, ip6_flow), 4,
-		(unsigned long)(ntohl(ipv6.ip6_flow) & IPV6_FLOWLABEL_MASK),
+		(unsigned long)(g_ntohl(ipv6.ip6_flow) & IPV6_FLOWLABEL_MASK),
 		"Flowlabel: 0x%05lx",
-		(unsigned long)(ntohl(ipv6.ip6_flow) & IPV6_FLOWLABEL_MASK));
+		(unsigned long)(g_ntohl(ipv6.ip6_flow) & IPV6_FLOWLABEL_MASK));
 
     proto_tree_add_uint(ipv6_tree, hf_ipv6_plen, tvb,
 		offset + offsetof(struct ip6_hdr, ip6_plen), 2,
@@ -828,10 +829,6 @@ again:
 			     offlg & IP6F_MORE_FRAG);
 
     if (ipfd_head != NULL) {
-      fragment_data *ipfd;
-      proto_tree *ft = NULL;
-      proto_item *fi = NULL;
-
       /* OK, we have the complete reassembled payload.
          Allocate a new tvbuff, referring to the reassembled payload. */
       next_tvb = tvb_new_real_data(ipfd_head->data, ipfd_head->datalen,
@@ -843,77 +840,11 @@ again:
       tvb_set_child_real_data_tvbuff(tvb, next_tvb);
 
       /* Add the defragmented data to the data source list. */
-      add_new_data_source(pinfo->fd, next_tvb, "Reassembled IPv6");
-
-      /* It's not fragmented. */
-      pinfo->fragmented = FALSE;
+      add_new_data_source(pinfo, next_tvb, "Reassembled IPv6");
 
       /* show all fragments */
-      fi = proto_tree_add_item(ipv6_tree, hf_ipv6_fragments,
-                next_tvb, 0, -1, FALSE);
-      ft = proto_item_add_subtree(fi, ett_ipv6_fragments);
-      for (ipfd = ipfd_head->next; ipfd; ipfd = ipfd->next){
-        if (ipfd->flags & (FD_OVERLAP|FD_OVERLAPCONFLICT
-                          |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-          /* this fragment has some flags set, create a subtree
-           * for it and display the flags.
-           */
-          proto_tree *fet = NULL;
-          proto_item *fei = NULL;
-          int hf;
-
-          if (ipfd->flags & (FD_OVERLAPCONFLICT
-                      |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-            hf = hf_ipv6_fragment_error;
-          } else {
-            hf = hf_ipv6_fragment;
-          }
-          fei = proto_tree_add_none_format(ft, hf,
-                   next_tvb, ipfd->offset, ipfd->len,
-                   "Frame:%u payload:%u-%u",
-                   ipfd->frame,
-                   ipfd->offset,
-                   ipfd->offset+ipfd->len-1
-          );
-          fet = proto_item_add_subtree(fei, ett_ipv6_fragment);
-          if (ipfd->flags&FD_OVERLAP) {
-            proto_tree_add_boolean(fet,
-                 hf_ipv6_fragment_overlap, next_tvb, 0, 0,
-                 TRUE);
-          }
-          if (ipfd->flags&FD_OVERLAPCONFLICT) {
-            proto_tree_add_boolean(fet,
-                 hf_ipv6_fragment_overlap_conflict, next_tvb, 0, 0,
-                 TRUE);
-          }
-          if (ipfd->flags&FD_MULTIPLETAILS) {
-            proto_tree_add_boolean(fet,
-                 hf_ipv6_fragment_multiple_tails, next_tvb, 0, 0,
-                 TRUE);
-          }
-          if (ipfd->flags&FD_TOOLONGFRAGMENT) {
-            proto_tree_add_boolean(fet,
-                 hf_ipv6_fragment_too_long_fragment, next_tvb, 0, 0,
-                 TRUE);
-          }
-        } else {
-          /* nothing of interest for this fragment */
-          proto_tree_add_none_format(ft, hf_ipv6_fragment,
-                   next_tvb, ipfd->offset, ipfd->len,
-                   "Frame:%u payload:%u-%u",
-                   ipfd->frame,
-                   ipfd->offset,
-                   ipfd->offset+ipfd->len-1
-          );
-        }
-      }
-      if (ipfd_head->flags & (FD_OVERLAPCONFLICT
-                        |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
-        if (check_col(pinfo->cinfo, COL_INFO)) {
-          col_set_str(pinfo->cinfo, COL_INFO, "[Illegal fragments]");
-          update_col_info = FALSE;
-        }
-      }
+      update_col_info = !show_fragment_tree(ipfd_head, &ipv6_frag_items,
+        ipv6_tree, pinfo, next_tvb);
     } else {
       /* We don't have the complete reassembled payload. */
       next_tvb = NULL;
@@ -1185,6 +1116,7 @@ proto_reg_handoff_ipv6(void)
   dissector_add("ip.proto", IP_PROTO_IPV6, ipv6_handle);
   dissector_add("null.type", BSD_AF_INET6_BSD, ipv6_handle);
   dissector_add("null.type", BSD_AF_INET6_FREEBSD, ipv6_handle);
+  dissector_add("null.type", BSD_AF_INET6_DARWIN, ipv6_handle);
   dissector_add("chdlctype", ETHERTYPE_IPv6, ipv6_handle);
   dissector_add("fr.ietf", NLPID_IP6, ipv6_handle);
   dissector_add("x.25.spi", NLPID_IP6, ipv6_handle);
