@@ -2,7 +2,7 @@
  * Routines for NetWare's IPX
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-ipx.c,v 1.103 2002/04/24 06:03:34 guy Exp $
+ * $Id: packet-ipx.c,v 1.108 2002/08/02 23:35:51 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -27,10 +27,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <glib.h>
@@ -149,8 +145,8 @@ static const value_string ipx_socket_vals[] = {
 	{ 0x400C,				"HP LaserJet/QuickSilver" },
 	{ 0x907B,				"SMS Testing and Development" },
 	{ 0x8F83,				"Powerchute UPS Monitoring" },
-	{ 0x4006,				"Netware Directory Server" },
-	{ 0x8104,				"Netware 386" },
+	{ 0x4006,				"NetWare Directory Server" },
+	{ 0x8104,				"NetWare 386" },
 	{ 0x0000,				NULL }
 };
 
@@ -188,6 +184,8 @@ static const value_string ipx_packet_type_vals[] = {
 
 static const value_string ipxmsg_sigchar_vals[] = {
 	{ '?', "Poll inactive station" },
+	{ 'Y', "Station is still using the connection" },
+	{ '!', "Broadcast message waiting" },
 	{ 0, NULL }
 };
 
@@ -211,6 +209,7 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint16		ipx_length;
 
 	guint16		ipx_dsocket, ipx_ssocket;
+	guint16		low_socket, high_socket;
 
 	if (check_col(pinfo->cinfo, COL_PROTOCOL))
 		col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX");
@@ -267,21 +266,49 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	/* Make the next tvbuff */
 	next_tvb = tvb_new_subset(tvb, IPX_HEADER_LEN, -1, -1);
 
-	if (dissector_try_port(ipx_type_dissector_table, ipx_type, next_tvb,
-	    pinfo, tree))
-		return;
-
 	/*
 	 * Let the subdissector know what type of IPX packet this is.
 	 */
 	pinfo->ipxptype = ipx_type;
 
-	if (dissector_try_port(ipx_socket_dissector_table, ipx_dsocket,
+	/*
+	 * Check the socket numbers before we check the packet type;
+	 * we've seen non-NCP packets with a type of NCP and a
+	 * destination socket of IPX_SOCKET_IPX_MESSAGE, and SAP
+	 * packets with a type of NCP and a destination socket of
+	 * IPX_SOCKET_SAP.
+	 *
+	 * Assume the lower-numbered socket number is more likely
+	 * to be the right one, along the lines of what we do for
+	 * TCP and UDP.  We've seen NCP packets with a type of NCP,
+	 * a source socket of IPX_SOCKET_NCP, and a destination
+	 * socket of IPX_SOCKET_IPX_MESSAGE, and we've seen NCP
+	 * packets with a type of NCP, a source socket of
+	 * IPX_SOCKET_IPX_MESSAGE, and a destination socket of
+	 * IPX_SOCKET_NCP.
+	 */
+	if (ipx_ssocket > ipx_dsocket) {
+		low_socket = ipx_dsocket;
+		high_socket = ipx_ssocket;
+	} else {
+		low_socket = ipx_ssocket;
+		high_socket = ipx_dsocket;
+	}
+	if (dissector_try_port(ipx_socket_dissector_table, low_socket,
 	    next_tvb, pinfo, tree))
 		return;
-	if (dissector_try_port(ipx_socket_dissector_table, ipx_ssocket,
+	if (dissector_try_port(ipx_socket_dissector_table, high_socket,
 	    next_tvb, pinfo, tree))
 		return;
+
+	/*
+	 * Neither of them are known; try the packet type, which will
+	 * at least let us, for example, dissect SPX packets as SPX.
+	 */
+	if (dissector_try_port(ipx_type_dissector_table, ipx_type, next_tvb,
+	    pinfo, tree))
+		return;
+
 	call_dissector(data_handle,next_tvb, pinfo, tree);
 }
 
@@ -536,8 +563,8 @@ server_type(guint16 type)
 		{ 0x0047,	"Advertising Print Server" },
 		{ 0x004a,	"NetBlazer Modems" },
 		{ 0x004b,	"Btrieve VAP/NLM 5.0" },
-		{ 0x004c,	"Netware SQL VAP/NLM Server" },
-		{ 0x004d,	"Xtree Network Version/Netware XTree" },
+		{ 0x004c,	"NetWare SQL VAP/NLM Server" },
+		{ 0x004d,	"Xtree Network Version/NetWare XTree" },
 		{ 0x0050,	"Btrieve VAP 4.11" },
 		{ 0x0052,	"QuickLink (Cubix)" },
 		{ 0x0053,	"Print Queue User" },
@@ -546,20 +573,20 @@ server_type(guint16 type)
 		{ 0x0064,	"ARCserve" },
 		{ 0x0066,	"ARCserve 3.0" },
 		{ 0x0072,	"WAN Copy Utility" },
-		{ 0x007a,	"TES-Netware for VMS" },
+		{ 0x007a,	"TES-NetWare for VMS" },
 		{ 0x0092,	"WATCOM Debugger or Emerald Tape Backup Server" },
 		{ 0x0095,	"DDA OBGYN" },
-		{ 0x0098,	"Netware Access Server (Asynchronous gateway)" },
-		{ 0x009a,	"Netware for VMS II or Named Pipe Server" },
-		{ 0x009b,	"Netware Access Server" },
-		{ 0x009e,	"Portable Netware Server or SunLink NVT" },
+		{ 0x0098,	"NetWare Access Server (Asynchronous gateway)" },
+		{ 0x009a,	"NetWare for VMS II or Named Pipe Server" },
+		{ 0x009b,	"NetWare Access Server" },
+		{ 0x009e,	"Portable NetWare Server or SunLink NVT" },
 		{ 0x00a1,	"Powerchute APC UPS NLM" },
 		{ 0x00aa,	"LAWserve" },
 		{ 0x00ac,	"Compaq IDA Status Monitor" },
 		{ 0x0100,	"PIPE STAIL" },
 		{ 0x0102,	"LAN Protect Bindery" },
 		{ 0x0103,	"Oracle DataBase Server" },
-		{ 0x0107,	"Netware 386 or RSPX Remote Console" },
+		{ 0x0107,	"NetWare 386 or RSPX Remote Console" },
 		{ 0x010f,	"Novell SNA Gateway" },
 		{ 0x0111,	"Test Server" },
 		{ 0x0112,	"Print Server (HP)" },
@@ -574,12 +601,12 @@ server_type(guint16 type)
 		{ 0x011e,	"CSA APPC (f/Communications Executive)" },
 		{ 0x0126,	"SNA TEST SSA Profile" },
 		{ 0x012a,	"CSA TRACE (f/Communications Executive)" },
-		{ 0x012b,	"Netware for SAA" },
+		{ 0x012b,	"NetWare for SAA" },
 		{ 0x012e,	"IKARUS virus scan utility" },
 		{ 0x0130,	"Communications Executive" },
-		{ 0x0133,	"NNS Domain Server or Netware Naming Services Domain" },
-		{ 0x0135,	"Netware Naming Services Profile" },
-		{ 0x0137,	"Netware 386 Print Queue or NNS Print Queue" },
+		{ 0x0133,	"NNS Domain Server or NetWare Naming Services Domain" },
+		{ 0x0135,	"NetWare Naming Services Profile" },
+		{ 0x0137,	"NetWare 386 Print Queue or NNS Print Queue" },
 		{ 0x0141,	"LAN Spool Server (Vap, Intel)" },
 		{ 0x0152,	"IRMALAN Gateway" },
 		{ 0x0154,	"Named Pipe Server" },
@@ -603,18 +630,18 @@ server_type(guint16 type)
 		{ 0x01dc,	"Castelle FAX/Xerox 7033 Fax Server/Excel Lan Fax" },
 		{ 0x01f0,	"LEGATO" },
 		{ 0x01f5,	"LEGATO" },
-		{ 0x0233,	"NMS Agent or Netware Management Agent" },
+		{ 0x0233,	"NMS Agent or NetWare Management Agent" },
 		{ 0x0237,	"NMS IPX Discovery or LANtern Read/Write Channel" },
 		{ 0x0238,	"NMS IP Discovery or LANtern Trap/Alarm Channel" },
 		{ 0x023a,	"LANtern" },
 		{ 0x023c,	"MAVERICK" },
 		{ 0x023f,	"SMS Testing and Development" },
-		{ 0x024e,	"Netware Connect" },
+		{ 0x024e,	"NetWare Connect" },
 		{ 0x024f,	"NASI server broadcast (Cisco)" },
 		{ 0x026a,	"Network Management (NMS) Service Console" },
-		{ 0x026b,	"Time Synchronization Server (Netware 4.x)" },
-		{ 0x0278,	"Directory Server (Netware 4.x)" },
-		{ 0x027b,	"Netware Management Agent" },
+		{ 0x026b,	"Time Synchronization Server (NetWare 4.x)" },
+		{ 0x0278,	"Directory Server (NetWare 4.x)" },
+		{ 0x027b,	"NetWare Management Agent" },
 		{ 0x0280,	"Novell File and Printer Sharing Service for PC" },
 		{ 0x0304,	"Novell SAA Gateway" },
 		{ 0x0308,	"COM or VERMED 1" },
@@ -639,7 +666,7 @@ server_type(guint16 type)
 		{ 0x03c7,	"LANspool 3.5 (Intel)" },
 		{ 0x03d7,	"Lexmark printer server (type 4033-011)" },
 		{ 0x03d8,	"Lexmark XLE printer server (type 4033-301)" },
-		{ 0x03dd,	"Banyan ENS for Netware Client NLM" },
+		{ 0x03dd,	"Banyan ENS for NetWare Client NLM" },
 		{ 0x03de,	"Gupta Sequel Base Server or NetWare SQL" },
 		{ 0x03e1,	"Univel Unixware" },
 		{ 0x03e4,	"Univel Unixware" },
@@ -708,6 +735,7 @@ server_type(guint16 type)
 		{ 0x6f00,	"Rabbit Gateway (3270)" },
 		{ 0x7703,	"MODEM" },
 		{ 0x8002,	"NetPort Printers (Intel) or LANport" },
+		{ 0x8003,	"SEH InterCon Printserver" },
 		{ 0x8008,	"WordPerfect Network Version" },
 		{ 0x85BE,	"Cisco Enhanced Interior Routing Protocol (EIGRP)" },
 		{ 0x8888,	"WordPerfect Network Version or Quick Network Management" },
