@@ -1,7 +1,7 @@
 /* packet-isis-lsp.c
  * Routines for decoding isis lsp packets and their CLVs
  *
- * $Id: packet-isis-lsp.c,v 1.31 2002/05/07 18:52:26 guy Exp $
+ * $Id: packet-isis-lsp.c,v 1.33 2002/08/04 09:08:03 jmayer Exp $
  * Stuart Stanley <stuarts@mxmail.net>
  *
  * Ethereal - Network traffic analyzer
@@ -27,18 +27,10 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <glib.h>
 
-#ifdef HAVE_NET_INET_H
-#include <net/inet.h>
-#endif
-
 #include "epan/ipv4.h"
 #include <epan/packet.h>
 #include "packet-osi.h"
