@@ -3,7 +3,7 @@
  *
  * (c) Copyright Ashok Narayanan <ashokn@cisco.com>
  *
- * $Id: packet-lmp.c,v 1.6 2002/05/10 18:37:38 ashokn Exp $
+ * $Id: packet-lmp.c,v 1.11 2002/08/02 23:35:54 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -45,20 +45,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <glib.h>
 
-#ifdef NEED_SNPRINTF_H
-# include "snprintf.h"
-#endif
-
 #include <epan/tvbuff.h>
 #include <epan/packet.h>
 #include <prefs.h>
@@ -68,6 +56,7 @@
 
 #include "packet-ip.h"
 #include "packet-rsvp.h"
+#include "packet-frame.h"
 
 static int proto_lmp = -1;
 #define LMP_VER_DRAFT_CCAMP_02  2
@@ -827,8 +816,15 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			    offset+3, 1, message_type);
 	proto_tree_add_text(lmp_header_tree, tvb, offset+4, 2, "Length: %d bytes",
 			    msg_length);
-	proto_tree_add_boolean_hidden(lmp_header_tree, lmp_filter[LMPF_MSG + message_type], tvb, 
+	if (LMPF_MSG + message_type <= LMPF_MSG_CHANNEL_STATUS_RESP &&
+		       message_type > 0) {
+		proto_tree_add_boolean_hidden(lmp_header_tree, lmp_filter[LMPF_MSG + message_type], tvb, 
 				      offset+3, 1, 1);
+	} else {
+		proto_tree_add_protocol_format(lmp_header_tree, proto_malformed, tvb, offset+3, 1,
+			"Invalid message type: %u", message_type);
+		return;
+	}
 	
 	cksum = tvb_get_ntohs(tvb, offset+6);
 	if (!pinfo->fragmented && (int) tvb_length(tvb) >= msg_length) {
@@ -872,8 +868,14 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    object_type = val_to_str(class, lmp_class_vals, "Unknown");
 	    proto_tree_add_uint_hidden(lmp_tree, lmp_filter[LMPF_OBJECT], tvb, 
 					    offset, 1, class);
-	    ti = proto_tree_add_item(lmp_tree, lmp_filter[lmp_class_to_filter_num(class)],
+	    if (VALID_CLASS(class)) {
+		ti = proto_tree_add_item(lmp_tree, lmp_filter[lmp_class_to_filter_num(class)],
 	    			     tvb, offset, obj_length, FALSE);
+	    } else {
+		proto_tree_add_protocol_format(lmp_tree, proto_malformed, tvb, offset+1, 1,
+			"Invalid class: %u", class);
+		return;
+	    }
 
 	    lmp_object_tree = proto_item_add_subtree(ti, lmp_class_to_subtree(class));
 
