@@ -2,7 +2,7 @@
  * Routines for MMS Message Encapsulation dissection
  * Copyright 2001, Tom Uijldert <tom.uijldert@cmg.nl>
  *
- * $Id: packet-mmse.c,v 1.7 2002/01/24 09:20:49 guy Exp $
+ * $Id: packet-mmse.c,v 1.16 2002/08/07 08:34:55 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -24,8 +24,7 @@
  * ----------
  *
  * Dissector of an encoded Multimedia message PDU, as defined by the WAPForum
- * (http://www.wapforum.org) in "WAP-209.102-MMSEncapsulation" according
- * the draft version of 8-February-2001.
+ * (http://www.wapforum.org) in "WAP-209-MMSEncapsulation-20020105-a".
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,20 +35,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <glib.h>
 
-#ifdef NEED_SNPRINTF_H
-# include "snprintf.h"
-#endif
-
 #include <epan/packet.h>
 #include "packet-wap.h"
 #include "packet-wsp.h"
@@ -155,14 +142,14 @@ static const value_string vals_message_class[] = {
     { 0x80, "Personal" },
     { 0x81, "Advertisement" },
     { 0x82, "Informational" },
-    { 0x82, "Auto" },
+    { 0x83, "Auto" },
     { 0x00, NULL },
 };
 
 static const value_string vals_priority[] = {
     { 0x80, "Low" },
     { 0x81, "Normal" },
-    { 0x81, "High" },
+    { 0x82, "High" },
     { 0x00, NULL },
 };
 
@@ -171,8 +158,8 @@ static const value_string vals_response_status[] = {
     { 0x81, "Unspecified" },
     { 0x82, "Service denied" },
     { 0x83, "Message format corrupt" },
-    { 0x84, "sending address unresolved" },
-    { 0x85, "message not found" },
+    { 0x84, "Sending address unresolved" },
+    { 0x85, "Message not found" },
     { 0x86, "Network problem" },
     { 0x87, "Content not accepted" },
     { 0x88, "Unsupported message" },
@@ -189,8 +176,8 @@ static const value_string vals_status[] = {
     { 0x80, "Expired" },
     { 0x81, "Retrieved" },
     { 0x82, "Rejected" },
-    { 0x82, "Deferred" },
-    { 0x82, "Unrecognized" },
+    { 0x83, "Deferred" },
+    { 0x84, "Unrecognized" },
     { 0x00, NULL },
 };
 
@@ -276,7 +263,7 @@ get_encoded_strval(tvbuff_t *tvb, guint offset, char *strval)
 	/* \todo	Something with "Char-set", skip for now	*/
 	tvb_memcpy(tvb, strval, offset + count + 1, length - 1);
 	strval[length - 1] = '\0';	/* Just to make sure	*/
-	return offset + count + length;
+	return count + length;
     } else
 	return get_text_string(tvb, offset, strval);
 }
@@ -332,14 +319,16 @@ dissect_mmse_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     /*
      * Check if data makes sense for it to be dissected as MMSE:  Message-type
-     * field must make sense and followed by Transaction-Id header
+     * field must make sense and followed by either Transaction-Id
+     * or MMS-Version header
      */
     if (tvb_get_guint8(tvb, 0) != MM_MTYPE_HDR)
 	return FALSE;
     pdut = tvb_get_guint8(tvb, 1);
     if (match_strval(pdut, vals_message_type) == NULL)
 	return FALSE;
-    if (tvb_get_guint8(tvb, 2) != MM_TID_HDR)
+    if ((tvb_get_guint8(tvb, 2) != MM_TID_HDR) &&
+	(tvb_get_guint8(tvb, 2) != MM_VERSION_HDR))
 	return FALSE;
     dissect_mmse(tvb, pinfo, tree);
     return TRUE;
@@ -515,8 +504,8 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 						  strval);
 		    }
 		    proto_tree_add_string(mmse_tree, hf_mmse_from, tvb,
-			    		  offset-1, length + 2, strval);
-		    offset += length + 1;
+			    		  offset-1, length + count + 1, strval);
+		    offset += length + count;
 		    break;
 		case MM_MCLASS_HDR:
 		    /*
@@ -624,8 +613,7 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (field == MM_CTYPE_HDR) {
 	    /*
 	     * Eeehh, we're now actually back to good old WSP content-type
-	     * encoding for multipart/related and multipart/mixed MIME-types.
-	     * Let's steal that from the WSP-dissector.
+	     * encoding. Let's steal that from the WSP-dissector.
 	     */
 	    tvbuff_t	*tmp_tvb;
 	    guint	 type;
@@ -633,7 +621,7 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	    offset = add_content_type(mmse_tree, tvb, offset, &type, &type_str);
 	    tmp_tvb = tvb_new_subset(tvb, offset, -1, -1);
-	    add_multipart_data(mmse_tree, tmp_tvb);
+	    add_post_data(mmse_tree, tmp_tvb, type, type_str);
 	}
     }
 
@@ -681,7 +669,7 @@ proto_register_mmse(void)
 	    }
 	},
 	{   &hf_mmse_cc,
-	    {   "Bcc", "mmse.bcc",
+	    {   "Cc", "mmse.cc",
 		FT_STRING, BASE_NONE, NULL, 0x00,
 		"Carbon copy.",
 		HFILL
@@ -808,7 +796,7 @@ proto_register_mmse(void)
 	},
 	{   &hf_mmse_sender_visibility,
 	    {   "Sender-Visibility", "mmse.sender_visibility",
-		FT_UINT8, BASE_HEX, VALS(vals_yes_no), 0x00,
+		FT_UINT8, BASE_HEX, VALS(vals_sender_visibility), 0x00,
 		"Disclose sender identity to receiver or not.",
 		HFILL
 	    }
