@@ -2,7 +2,7 @@
  * Routines for Microsoft Proxy packet dissection
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet-msproxy.c,v 1.29 2002/05/01 08:14:32 guy Exp $
+ * $Id: packet-msproxy.c,v 1.31 2002/08/02 23:35:54 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -45,22 +45,10 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <glib.h>
 
-#ifdef NEED_SNPRINTF_H
-# include "snprintf.h"
-#endif
-
 #include <epan/packet.h>
 #include <epan/resolv.h>
 #include "alignment.h"
@@ -70,7 +58,7 @@
 #include "packet-udp.h"
 
 extern void udp_hash_add(guint16 proto,
-        void (*dissect)(const u_char *, int, frame_data *, proto_tree *));
+        void (*dissect)(const guchar *, int, frame_data *, proto_tree *));
 
 
 static int proto_msproxy = -1;
