@@ -3,7 +3,7 @@
  * Gilbert Ramirez <gram@alumni.rice.edu>
  * Modified to allow NCP over TCP/IP decodes by James Coe <jammer@cin.net>
  *
- * $Id: packet-ncp.c,v 1.61 2002/05/16 09:59:52 guy Exp $
+ * $Id: packet-ncp.c,v 1.65 2002/08/02 23:35:54 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -28,20 +28,13 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <string.h>
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include "prefs.h"
 #include "packet-ipx.h"
+#include "packet-tcp.h"
 #include "packet-ncp-int.h"
 
 int proto_ncp = -1;
@@ -49,6 +42,7 @@ static int hf_ncp_ip_ver = -1;
 static int hf_ncp_ip_length = -1;
 static int hf_ncp_ip_rplybufsize = -1;
 static int hf_ncp_ip_sig = -1;
+static int hf_ncp_ip_packetsig = -1;
 static int hf_ncp_type = -1;
 static int hf_ncp_seq = -1;
 static int hf_ncp_connection = -1;
@@ -78,6 +72,9 @@ static int hf_ncp_control_code = -1;
 gint ett_ncp = -1;
 static gint ett_ncp_system_flags = -1;
 
+/* desegmentation of NCP over TCP */
+static gboolean ncp_desegment = TRUE;
+
 static dissector_handle_t data_handle;
 
 #define TCP_PORT_NCP		524
@@ -161,12 +158,14 @@ static value_string ncp_type_vals[] = {
 #define SYS	0x80		/* System packet */
 
 static void
-dissect_ncp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+dissect_ncp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+    gboolean is_tcp)
 {
 	proto_tree			*ncp_tree = NULL;
 	proto_item			*ti;
 	struct ncp_ip_header		ncpiph;
 	struct ncp_ip_rqhdr		ncpiphrq;
+	gboolean			is_signed = FALSE;
 	struct ncp_common_header	header;
 	guint16				nw_connection;
 	guint16				flags = 0;
@@ -186,7 +185,7 @@ dissect_ncp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (check_col(pinfo->cinfo, COL_INFO))
 		col_clear(pinfo->cinfo, COL_INFO);
 
-	if (pinfo->ptype == PT_TCP) {
+	if (is_tcp) {
 		ncpiph.signature	= tvb_get_ntohl(tvb, 0);
 		ncpiph.length		= tvb_get_ntohl(tvb, 4);
 		hdr_offset += 8;
@@ -195,8 +194,26 @@ dissect_ncp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			hdr_offset += 4;
 			ncpiphrq.rplybufsize	= tvb_get_ntohl(tvb, hdr_offset);
 			hdr_offset += 4;
-		};
-	};
+		}
+		if (ncpiph.length & 0x80000000) {
+			/*
+			 * This appears to indicate that this packet
+			 * is signed; the signature is 8 bytes long.
+			 *
+			 * XXX - that bit does *not* appear to be set
+			 * in signed replies, and we can't dissect the
+			 * reply enough to find the matching request
+			 * without knowing whether the reply is
+			 * signed.
+			 *
+			 * XXX - what about NCP-over-IPX signed
+			 * messages?
+			 */
+			is_signed = TRUE;
+			hdr_offset += 8;
+			ncpiph.length &= 0x7fffffff;
+		}
+	}
 
 	/* Record the offset where the NCP common header starts */
 	commhdr = hdr_offset;
@@ -218,13 +235,15 @@ dissect_ncp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		ti = proto_tree_add_item(tree, proto_ncp, tvb, 0, -1, FALSE);
 		ncp_tree = proto_item_add_subtree(ti, ett_ncp);
 
-		if (pinfo->ptype == PT_TCP) {
+		if (is_tcp) {
 			proto_tree_add_uint(ncp_tree, hf_ncp_ip_sig, tvb, 0, 4, ncpiph.signature);
 			proto_tree_add_uint(ncp_tree, hf_ncp_ip_length, tvb, 4, 4, ncpiph.length);
 			if (ncpiph.signature == NCPIP_RQST) {
 				proto_tree_add_uint(ncp_tree, hf_ncp_ip_ver, tvb, 8, 4, ncpiphrq.version);
 				proto_tree_add_uint(ncp_tree, hf_ncp_ip_rplybufsize, tvb, 12, 4, ncpiphrq.rplybufsize);
 			}
+			if (is_signed)
+				proto_tree_add_item(ncp_tree, hf_ncp_ip_packetsig, tvb, 16, 8, FALSE);
 		}
 		proto_tree_add_uint(ncp_tree, hf_ncp_type,	tvb, commhdr + 0, 2, header.type);
 	}
@@ -433,7 +452,46 @@ dissect_ncp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
  	}
 }
 
+static void
+dissect_ncp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+{
+	dissect_ncp_common(tvb, pinfo, tree, FALSE);
+}
 
+static guint
+get_ncp_pdu_len(tvbuff_t *tvb, int offset)
+{
+  guint32 signature;
+
+  /*
+   * Check the NCP-over-TCP header signature, to make sure it's there.
+   * If it's not there, we cannot trust the next 4 bytes to be a
+   * packet length+"has signature" flag, so we just say the length is
+   * "what remains in the packet".
+   */
+  signature = tvb_get_ntohl(tvb, offset);
+  if (signature != NCPIP_RQST && signature != NCPIP_RPLY)
+    return tvb_length_remaining(tvb, offset);
+  
+  /*
+   * Get the length of the NCP-over-TCP packet.  Strip off the "has
+   * signature" flag.
+   */
+  return tvb_get_ntohl(tvb, offset + 4) & 0x7fffffff;
+}
+
+static void
+dissect_ncp_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+{
+  dissect_ncp_common(tvb, pinfo, tree, TRUE);
+}
+
+static void
+dissect_ncp_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+{
+  tcp_dissect_pdus(tvb, pinfo, tree, ncp_desegment, 8, get_ncp_pdu_len,
+	dissect_ncp_tcp_pdu);
+}
 
 void
 proto_register_ncp(void)
@@ -441,12 +499,12 @@ proto_register_ncp(void)
 
   static hf_register_info hf[] = {
     { &hf_ncp_ip_sig,
-      { "NCP over IP signature",		"ncp.ip.signature",
+      { "NCP over IP signature",	"ncp.ip.signature",
         FT_UINT32, BASE_HEX, VALS(ncp_ip_signature), 0x0,
         "", HFILL }},
     { &hf_ncp_ip_length,
       { "NCP over IP length",		"ncp.ip.length",
-        FT_UINT32, BASE_HEX, NULL, 0x0,
+        FT_UINT32, BASE_DEC, NULL, 0x0,
         "", HFILL }},
     { &hf_ncp_ip_ver,
       { "NCP over IP Version",		"ncp.ip.version",
@@ -456,6 +514,10 @@ proto_register_ncp(void)
       { "NCP over IP Reply Buffer Size",	"ncp.ip.replybufsize",
         FT_UINT32, BASE_DEC, NULL, 0x0,
         "", HFILL }},
+    { &hf_ncp_ip_packetsig,
+      { "NCP over IP Packet Signature",	"ncp.ip.packetsig",
+        FT_BYTES, BASE_NONE, NULL, 0x0,
+        "", HFILL }},
     { &hf_ncp_type,
       { "Type",			"ncp.type",
 	FT_UINT16, BASE_HEX, VALS(ncp_type_vals), 0x0,
@@ -567,19 +629,23 @@ proto_register_ncp(void)
   proto_register_field_array(proto_ncp, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
 
-  /* Register an obsolete configuration option for what used to be the
-     initial size of the NCP hash. */
-  ncp_module = prefs_register_protocol_obsolete(proto_ncp);
+  ncp_module = prefs_register_protocol(proto_ncp, NULL);
   prefs_register_obsolete_preference(ncp_module, "initial_hash_size");
+  prefs_register_bool_preference(ncp_module, "desegment",
+    "Desegment all NCP-over-TCP messages spanning multiple segments",
+    "Whether the NCP dissector should desegment all messages spanning multiple TCP segments",
+    &ncp_desegment);
 }
 
 void
 proto_reg_handoff_ncp(void)
 {
   dissector_handle_t ncp_handle;
+  dissector_handle_t ncp_tcp_handle;
 
   ncp_handle = create_dissector_handle(dissect_ncp, proto_ncp);
-  dissector_add("tcp.port", TCP_PORT_NCP, ncp_handle);
+  ncp_tcp_handle = create_dissector_handle(dissect_ncp_tcp, proto_ncp);
+  dissector_add("tcp.port", TCP_PORT_NCP, ncp_tcp_handle);
   dissector_add("udp.port", UDP_PORT_NCP, ncp_handle);
   dissector_add("ipx.packet_type", IPX_PACKET_TYPE_NCP, ncp_handle);
   dissector_add("ipx.socket", IPX_SOCKET_NCP, ncp_handle);
