@@ -1,7 +1,7 @@
 /* packet-null.c
  * Routines for null packet disassembly
  *
- * $Id: packet-null.c,v 1.52 2002/01/21 07:36:38 guy Exp $
+ * $Id: packet-null.c,v 1.55 2002/08/03 19:49:30 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -28,16 +28,8 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <glib.h>
 
-#ifdef HAVE_SYS_SOCKET_H
-#include <sys/socket.h>
-#endif
-
 #include <string.h>
 #include <epan/packet.h>
 #include "packet-null.h"
@@ -68,13 +60,14 @@ static const value_string family_vals[] = {
     {BSD_AF_IPX,           "Netware IPX/SPX"},
     {BSD_AF_INET6_BSD,     "IPv6"           },
     {BSD_AF_INET6_FREEBSD, "IPv6"           },
+    {BSD_AF_INET6_DARWIN,  "IPv6"           }, 
     {0,                    NULL             }
 };
 
 static dissector_handle_t ppp_hdlc_handle;
 static dissector_handle_t data_handle;
 void
-capture_null( const u_char *pd, int len, packet_counts *ld )
+capture_null( const guchar *pd, int len, packet_counts *ld )
 {
   guint32 null_header;
 
