@@ -2,7 +2,7 @@
  * Routines for OSPF packet disassembly
  * (c) Copyright Hannes R. Boehm <hannes@boehm.org>
  *
- * $Id: packet-ospf.c,v 1.67 2002/05/14 09:46:38 guy Exp $
+ * $Id: packet-ospf.c,v 1.69 2002/08/02 23:35:55 jmayer Exp $
  *
  * At this time, this module is able to analyze OSPF
  * packets as specified in RFC2328. MOSPF (RFC1584) and other
@@ -36,14 +36,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 
@@ -523,8 +515,8 @@ dissect_ospf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		cksum_vec[1].ptr = pinfo->dst.data;
 		cksum_vec[1].len = pinfo->dst.len;
 		cksum_vec[2].ptr = (const guint8 *)&phdr;
-	        phdr[0] = htonl(ospflen);
-	        phdr[1] = htonl(IP_PROTO_OSPF);
+	        phdr[0] = g_htonl(ospflen);
+	        phdr[1] = g_htonl(IP_PROTO_OSPF);
 	        cksum_vec[2].len = 8;
 
 		cksum_vec[3].ptr = tvb_get_ptr(tvb, 0, reported_length);
@@ -634,7 +626,8 @@ dissect_ospf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    break;
 
 	default:
-	    call_dissector(data_handle,tvb_new_subset(tvb, ospf_header_length,-1,tvb_reported_length_remaining(tvb,ospf_header_length)), pinfo, tree);
+	    call_dissector(data_handle,
+	        tvb_new_subset(tvb, ospf_header_length, -1, -1), pinfo, tree);
 	    break;
 	}
     }
