@@ -2,7 +2,7 @@
  * Routines for PIM disassembly
  * (c) Copyright Jun-ichiro itojun Hagino <itojun@itojun.org>
  *
- * $Id: packet-pim.c,v 1.40 2002/04/22 07:41:32 guy Exp $
+ * $Id: packet-pim.c,v 1.41 2002/08/02 23:35:56 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -27,14 +27,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-#include <netinet/in.h>
-#endif
-
 #include <stddef.h>  /* For offsetof */
 #include <string.h>
 #include <glib.h>
@@ -702,8 +694,8 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 		cksum_vec[1].ptr = pinfo->dst.data;
 		cksum_vec[1].len = pinfo->dst.len;
 		cksum_vec[2].ptr = (const guint8 *)&phdr;
-		phdr[0] = htonl(pim_length);
-		phdr[1] = htonl(IP_PROTO_PIM);
+		phdr[0] = g_htonl(pim_length);
+		phdr[1] = g_htonl(IP_PROTO_PIM);
 		cksum_vec[2].len = 8;
 		cksum_vec[3].ptr = tvb_get_ptr(tvb, 0, pim_length);
 		cksum_vec[3].len = pim_length;
