@@ -2,7 +2,7 @@
  * Routines for Q.2931 frame disassembly
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-q2931.c,v 1.24 2002/05/01 08:40:22 guy Exp $
+ * $Id: packet-q2931.c,v 1.28 2002/08/02 23:35:56 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -27,10 +27,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <stdio.h>
 #include <glib.h>
 #include <string.h>
@@ -291,6 +287,7 @@ static const value_string q9231_aal1_subtype_vals[] = {
 	{ 0x00, "Null" },
 	{ 0x01, "64 kbit/s voice-band signal transport (G.711/G.722)" },
 	{ 0x02, "Circuit transport (I.363)" },
+	{ 0x03, "Circuit emulation (asynchronous)" },
 	{ 0x04, "High-quality audio signal transport (I.363)" },
 	{ 0x05, "Video signal transport (I.363)" },
 	{ 0x00, NULL }
@@ -325,7 +322,13 @@ static const value_string q2931_aal1_src_clk_rec_meth_vals[] = {
 static const value_string q2931_aal1_err_correction_method_vals[] = {
 	{ 0x00, "Null" },
 	{ 0x01, "FEC method for less sensitive signal transport" },
-	{ 0x02, "FEC method for delay-sensigive signal transport" },
+	{ 0x02, "FEC method for delay-sensitive signal transport" },
+	{ 0x00, NULL }
+};
+
+static const value_string q2931_aal_mode_vals[] = {
+	{ 0x01, "Message" },
+	{ 0x02, "Streaming" },
 	{ 0x00, NULL }
 };
 
@@ -482,6 +485,18 @@ dissect_q2931_aal_parameters_ie(tvbuff_t *tvb, int offset, int len,
 			len -= 5;
 			break;
 
+		case 0x83:	/* Mode identifier for AAL3/4 and AAL5 */
+			if (len < 2)
+				return;
+			value = tvb_get_guint8(tvb, offset + 1);
+			proto_tree_add_text(tree, tvb, offset, 2,
+			    "Mode: %s",
+			    val_to_str(value, q2931_aal_mode_vals,
+			    "Unknown (0x%02X)"));
+			offset += 2;
+			len -= 2;
+			break;
+
 		case 0x84:	/* SSCS type identifier for AAL3/4 and AAL5 */
 			if (len < 2)
 				return;
