@@ -2,7 +2,7 @@
  * Routines for rpc dissection
  * Copyright 1999, Uwe Girlich <Uwe.Girlich@philosys.de>
  * 
- * $Id: packet-rpc.c,v 1.93 2002/05/15 23:01:51 guy Exp $
+ * $Id: packet-rpc.c,v 1.98 2002/08/02 23:35:57 jmayer Exp $
  * 
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -29,10 +29,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <glib.h>
 #include <stdio.h>
 #include <string.h>
@@ -45,6 +41,7 @@
 #include "prefs.h"
 #include "reassemble.h"
 #include "rpc_defrag.h"
+#include "packet-nfs.h"
 
 /*
  * See:
@@ -190,9 +187,17 @@ static int hf_rpc_reply_dup = -1;
 static int hf_rpc_value_follows = -1;
 static int hf_rpc_array_len = -1;
 static int hf_rpc_time = -1;
+static int hf_rpc_fragments = -1;
+static int hf_rpc_fragment = -1;
+static int hf_rpc_fragment_overlap = -1;
+static int hf_rpc_fragment_overlap_conflict = -1;
+static int hf_rpc_fragment_multiple_tails = -1;
+static int hf_rpc_fragment_too_long_fragment = -1;
+static int hf_rpc_fragment_error = -1;
 
 static gint ett_rpc = -1;
 static gint ett_rpc_fragments = -1;
+static gint ett_rpc_fragment = -1;
 static gint ett_rpc_fraghdr = -1;
 static gint ett_rpc_string = -1;
 static gint ett_rpc_cred = -1;
@@ -205,6 +210,19 @@ static dissector_handle_t rpc_tcp_handle;
 static dissector_handle_t rpc_handle;
 static dissector_handle_t data_handle;
 
+fragment_items rpc_frag_items = {
+	&ett_rpc_fragment,
+	&ett_rpc_fragments,
+	&hf_rpc_fragments,
+	&hf_rpc_fragment,
+	&hf_rpc_fragment_overlap,
+	&hf_rpc_fragment_overlap_conflict,
+	&hf_rpc_fragment_multiple_tails,
+	&hf_rpc_fragment_too_long_fragment,
+	&hf_rpc_fragment_error,
+	"fragments"
+};
+
 /* Hash table with info on RPC program numbers */
 static GHashTable *rpc_progs;
 
@@ -1559,7 +1577,7 @@ dissect_rpc_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		if (is_tcp) {
 			show_rpc_fraginfo(tvb, frag_tvb, rpc_tree, rpc_rm,
-			    ipfd_head);
+			    ipfd_head, pinfo);
 		}
 	}
 
@@ -2134,6 +2152,36 @@ dissect_rpc_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	call_dissector(data_handle,
 	    tvb_new_subset(tvb, offset, -1, -1), pinfo, ptree);
 
+
+	/* XXX this should really loop over all fhandles registred for the frame */
+	if(nfs_fhandle_reqrep_matching){
+		nfs_fhandle_data_t *fhd;
+		switch (msg_type) {
+		case RPC_CALL:
+			if(rpc_call && rpc_call->rep_num){
+				fhd=(nfs_fhandle_data_t *)g_hash_table_lookup(
+					nfs_fhandle_frame_table, 
+					(gconstpointer)rpc_call->rep_num);
+				if(fhd){
+					dissect_fhandle_hidden(pinfo,
+						ptree, fhd);
+				}
+			}
+			break;
+		case RPC_REPLY:
+			if(rpc_call && rpc_call->req_num){
+				fhd=(nfs_fhandle_data_t *)g_hash_table_lookup(
+					nfs_fhandle_frame_table, 
+					(gconstpointer)rpc_call->req_num);
+				if(fhd){
+					dissect_fhandle_hidden(pinfo,
+						ptree, fhd);
+				}
+			}
+			break;
+		}
+	}
+
 	return TRUE;
 }
 
@@ -2237,12 +2285,8 @@ make_frag_tree(tvbuff_t *tvb, proto_tree *tree, int proto, gint ett,
 
 void
 show_rpc_fraginfo(tvbuff_t *tvb, tvbuff_t *frag_tvb, proto_tree *tree,
-    guint32 rpc_rm, fragment_data *ipfd_head)
+    guint32 rpc_rm, fragment_data *ipfd_head, packet_info *pinfo)
 {
-	proto_tree *st = NULL;
-	proto_item *si = NULL;
-	fragment_data *ipfd;
-
 	if (tree == NULL)
 		return;		/* don't do any work */
 
@@ -2258,15 +2302,7 @@ show_rpc_fraginfo(tvbuff_t *tvb, tvbuff_t *frag_tvb, proto_tree *tree,
 		/*
 		 * Show a tree with information about all fragments.
 		 */
-		si = proto_tree_add_text(tree, tvb, 0, -1, "Fragments");
-		st = proto_item_add_subtree(si, ett_rpc_fragments);
-		for (ipfd = ipfd_head->next; ipfd != NULL; ipfd = ipfd->next) {
-			proto_tree_add_text(st, tvb, ipfd->offset, ipfd->len,
-			    "Frame:%u [%u-%u]",
-			    ipfd->frame,
-			    ipfd->offset,
-			    ipfd->offset + ipfd->len - 1);
-		}
+		show_fragment_tree(ipfd_head, &rpc_frag_items, tree, pinfo, tvb);
 	} else {
 		/*
 		 * This message was all in one fragment, so just show
@@ -2644,7 +2680,7 @@ dissect_rpc_fragment(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		/*
 		 * Add defragmented data to the data source list.
 		 */
-		add_new_data_source(pinfo->fd, rec_tvb, "Defragmented");
+		add_new_data_source(pinfo, rec_tvb, "Defragmented");
 	}
 
 	/*
@@ -2933,10 +2969,38 @@ proto_register_rpc(void)
 			"Time from request", "rpc.time", FT_RELATIVE_TIME, BASE_NONE,
 			NULL, 0, "Time between Request and Reply for ONC-RPC calls", HFILL }},
 
+		{ &hf_rpc_fragment_overlap,
+		{ "Fragment overlap",	"rpc.fragment.overlap", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
+			"Fragment overlaps with other fragments", HFILL }},
+
+		{ &hf_rpc_fragment_overlap_conflict,
+		{ "Conflicting data in fragment overlap",	"rpc.fragment.overlap.conflict", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
+			"Overlapping fragments contained conflicting data", HFILL }},
+
+		{ &hf_rpc_fragment_multiple_tails,
+		{ "Multiple tail fragments found",	"rpc.fragment.multipletails", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
+			"Several tails were found when defragmenting the packet", HFILL }},
+
+		{ &hf_rpc_fragment_too_long_fragment,
+		{ "Fragment too long",	"rpc.fragment.toolongfragment", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
+			"Fragment contained data past end of packet", HFILL }},
+
+		{ &hf_rpc_fragment_error,
+		{ "Defragmentation error", "rpc.fragment.error", FT_NONE, BASE_NONE, NULL, 0x0,
+			"Defragmentation error due to illegal fragments", HFILL }},
+
+		{ &hf_rpc_fragment,
+		{ "RPC Fragment", "rpc.fragment", FT_NONE, BASE_NONE, NULL, 0x0,
+			"RPC Fragment", HFILL }},
+
+		{ &hf_rpc_fragments,
+		{ "RPC Fragments", "rpc.fragments", FT_NONE, BASE_NONE, NULL, 0x0,
+			"RPC Fragments", HFILL }},
 	};
 	static gint *ett[] = {
 		&ett_rpc,
 		&ett_rpc_fragments,
+		&ett_rpc_fragment,
 		&ett_rpc_fraghdr,
 		&ett_rpc_string,
 		&ett_rpc_cred,
