@@ -1,6 +1,6 @@
 /* packet-rpc.h
  *
- * $Id: packet-rpc.h,v 1.32 2002/01/21 07:36:41 guy Exp $
+ * $Id: packet-rpc.h,v 1.36 2002/05/09 12:10:05 sahlberg Exp $
  *
  * (c) 1999 Uwe Girlich
  *
@@ -31,8 +31,6 @@
 #include <epan/packet.h>
 #include <epan/conversation.h>
 
-#define EXTRACT_UINT(p,o)    pntohl(&p[o])
-
 #define RPC_CALL 0
 #define RPC_REPLY 1
 
@@ -95,19 +93,12 @@ typedef struct _rpc_call_info_value {
 	struct _rpc_proc_info_value*	proc_info;
 	gboolean request;	/* Is this a request or not ?*/
 	nstime_t req_time;
+	void *private_data;
 } rpc_call_info_value;
 
 
-typedef int (old_dissect_function_t)(const u_char* pd, int offset, frame_data* fd, proto_tree* tree);
 typedef int (dissect_function_t)(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree* tree);
 
-typedef struct _old_vsff {
-	guint32	value;
-	gchar   *strptr;
-	old_dissect_function_t *dissect_call;
-	old_dissect_function_t *dissect_reply;
-} old_vsff;
-
 typedef struct _vsff {
 	guint32	value;
 	gchar   *strptr;
@@ -117,27 +108,26 @@ typedef struct _vsff {
 
 extern const value_string rpc_auth_flavor[];
 
-extern void old_rpc_init_proc_table(guint prog, guint vers, const old_vsff *proc_table);
 extern void rpc_init_proc_table(guint prog, guint vers, const vsff *proc_table);
 extern void rpc_init_prog(int proto, guint32 prog, int ett);
 extern char *rpc_prog_name(guint32 prog);
 extern char *rpc_proc_name(guint32 prog, guint32 vers, guint32 proc);
 
 extern unsigned int rpc_roundup(unsigned int a);
-extern int dissect_rpc_bool(tvbuff_t *tvb, packet_info *pinfo,
+extern int dissect_rpc_bool(tvbuff_t *tvb,
 	proto_tree *tree, int hfindex, int offset);
-extern int dissect_rpc_string(tvbuff_t *tvb, packet_info *pinfo,
+extern int dissect_rpc_string(tvbuff_t *tvb,
 	proto_tree *tree, int hfindex, int offset, char **string_buffer_ret);
-extern int dissect_rpc_data(tvbuff_t *tvb, packet_info *pinfo,
+extern int dissect_rpc_data(tvbuff_t *tvb,
 	proto_tree *tree, int hfindex, int offset);
 extern int dissect_rpc_list(tvbuff_t *tvb, packet_info *pinfo,
 	proto_tree *tree, int offset, dissect_function_t *rpc_list_dissector);
 extern int dissect_rpc_array(tvbuff_t *tvb, packet_info *pinfo,
 	proto_tree *tree, int offset, dissect_function_t *rpc_array_dissector,
 	int hfindex);
-extern int dissect_rpc_uint32(tvbuff_t *tvb, packet_info *pinfo,
+extern int dissect_rpc_uint32(tvbuff_t *tvb,
 	proto_tree *tree, int hfindex, int offset);
-extern int dissect_rpc_uint64(tvbuff_t *tvb, packet_info *pinfo,
+extern int dissect_rpc_uint64(tvbuff_t *tvb,
 	proto_tree *tree, int hfindex, int offset);
 
 extern int dissect_rpc_indir_call(tvbuff_t *tvb, packet_info *pinfo,
