@@ -1,6 +1,6 @@
 /* packet-rtcp.c
  *
- * $Id: packet-rtcp.c,v 1.32 2002/04/15 21:25:05 guy Exp $
+ * $Id: packet-rtcp.c,v 1.34 2002/08/02 23:35:59 jmayer Exp $
  *
  * Routines for RTCP dissection
  * RTCP = Real-time Transport Control Protocol
@@ -46,14 +46,6 @@
 #include <glib.h>
 #include <epan/packet.h>
 
-#ifdef HAVE_SYS_TYPES_H
-#  include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-#  include <netinet/in.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 
@@ -382,8 +374,9 @@ dissect_rtcp_bye( tvbuff_t *tvb, int offset, proto_tree *tree,
 
 	while ( chunk <= count ) {
 		/* source identifier, 32 bits */
-		proto_tree_add_uint( tree, hf_rtcp_ssrc_source, tvb, offset, 4, tvb_get_ntohl( tvb, offset ) );
+		proto_tree_add_item( tree, hf_rtcp_ssrc_source, tvb, offset, 4, FALSE);
 		offset += 4;
+		chunk++;
 	}
 
 	if ( tvb_reported_length_remaining( tvb, offset ) > 0 ) {
