@@ -3,7 +3,7 @@
  * Routines for RTP dissection
  * RTP = Real time Transport Protocol
  *
- * $Id: packet-rtp.h,v 1.4 2001/06/12 06:31:14 guy Exp $
+ * $Id: packet-rtp.h,v 1.6 2001/11/27 07:13:26 guy Exp $
  * 
  * Copyright 2000, Philips Electronics N.V.
  * Written by Andreas Sikkema <andreas.sikkema@philips.com>
@@ -27,7 +27,5 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-void     rtp_add_address   ( const unsigned char* ip_addr, int prt );
-gboolean dissect_rtp_heur  ( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree );
-void     dissect_rtp       ( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree );
+void     rtp_add_address   ( packet_info *pinfo, const unsigned char* ip_addr, int prt );
 void     proto_register_rtp( void );
