@@ -2,7 +2,7 @@
  * Routines for SMB packet dissection
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  *
- * $Id: packet-smb-common.h,v 1.11 2002/04/30 23:48:15 guy Exp $
+ * $Id: packet-smb-common.h,v 1.14 2002/08/10 21:15:37 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -34,14 +34,6 @@
 
 #include <stdio.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <time.h>
 #include <string.h>
 #include <glib.h>
@@ -57,6 +49,10 @@ int display_unicode_string(tvbuff_t *tvb, proto_tree *tree, int offset, int hf_i
 
 int display_ms_string(tvbuff_t *tvb, proto_tree *tree, int offset, int hf_index);
 
+const gchar *get_unicode_or_ascii_string(tvbuff_t *tvb, int *offsetp,
+    gboolean useunicode, int *len, gboolean nopad, gboolean exactlen,
+    guint16 *bcp);
+
 int dissect_smb_64bit_time(tvbuff_t *tvb, proto_tree *tree, int offset, int hf_date);
 
 int dissect_nt_sid(tvbuff_t *tvb, int offset, proto_tree *parent_tree, char *name);
@@ -64,4 +60,6 @@ int dissect_nt_sid(tvbuff_t *tvb, int offset, proto_tree *parent_tree, char *nam
 int
 dissect_nt_sec_desc(tvbuff_t *tvb, int offset, proto_tree *parent_tree, int len);
 
+extern const value_string share_type_vals[];
+
 #endif
