@@ -1,7 +1,7 @@
 /* packet-smtp.c
  * Routines for SMTP packet disassembly
  *
- * $Id: packet-smtp.c,v 1.26 2002/04/14 23:04:04 guy Exp $
+ * $Id: packet-smtp.c,v 1.31 2002/08/02 23:36:02 jmayer Exp $
  *
  * Copyright (c) 2000 by Richard Sharpe <rsharpe@ns.aus.com>
  *
@@ -28,14 +28,6 @@
 #include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-#include <netinet/in.h>
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -56,11 +48,18 @@ static int proto_smtp = -1;
 
 static int hf_smtp_req = -1;
 static int hf_smtp_rsp = -1;
+static int hf_smtp_req_command = -1;
+static int hf_smtp_req_parameter = -1;
+static int hf_smtp_rsp_code = -1;
+static int hf_smtp_rsp_parameter = -1;
 
 static int ett_smtp = -1;
 
 static int global_smtp_tcp_port = TCP_PORT_SMTP;
 
+/* desegmentation of SMTP command and response lines */
+static gboolean smtp_desegment = TRUE;
+
 /*
  * A CMD is an SMTP command, MESSAGE is the message portion, and EOM is the
  * last part of a message
@@ -114,7 +113,8 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     int                     request = 0;
     conversation_t          *conversation;
     struct smtp_request_val *request_val;
-    const char              *line;
+    const guchar            *line;
+    guint32                 code;
     int                     linelen;
     gboolean                eom_seen = FALSE;
     gint                    next_offset;
@@ -152,11 +152,26 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     /*
      * Get the first line from the buffer.
      *
-     * Note that "tvb_find_line_end()" will return a value that
-     * is not longer than what's in the buffer, so the
-     * "tvb_get_ptr()" call won't throw an exception.
+     * Note that "tvb_find_line_end()" will, if it doesn't return
+     * -1, return a value that is not longer than what's in the buffer,
+     * and "tvb_find_line_end()" will always return a value that is not
+     * longer than what's in the buffer, so the "tvb_get_ptr()" call
+     * won't throw an exception.
      */
-    linelen = tvb_find_line_end(tvb, offset, -1, &next_offset);
+    linelen = tvb_find_line_end(tvb, offset, -1, &next_offset,
+      smtp_desegment && pinfo->can_desegment);
+    if (linelen == -1) {
+      /*
+       * We didn't find a line ending, and we're doing desegmentation;
+       * tell the TCP dissector where the data for this message starts
+       * in the data it handed us, and tell it we need one more byte
+       * (we may need more, but we'll try again if what we get next
+       * isn't enough), and return.
+       */
+      pinfo->desegment_offset = offset;
+      pinfo->desegment_len = 1;
+      return;
+    }
     line = tvb_get_ptr(tvb, offset, linelen);
 
     frame_data = p_get_proto_data(pinfo->fd, proto_smtp);
@@ -354,8 +369,6 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
       ti = proto_tree_add_item(tree, proto_smtp, tvb, offset, -1, FALSE);
       smtp_tree = proto_item_add_subtree(ti, ett_smtp);
-      proto_tree_add_boolean_hidden(smtp_tree, (request ? hf_smtp_req : hf_smtp_rsp),
-				    tvb, offset, 4, TRUE);
       if (request) {
 
 	/* 
@@ -384,7 +397,7 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    /*
 	     * Find the end of the line.
 	     */
-	    tvb_find_line_end(tvb, offset, -1, &next_offset);
+	    tvb_find_line_end(tvb, offset, -1, &next_offset, FALSE);
 
 	    /*
 	     * Put this line.
@@ -431,11 +444,13 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    cmdlen = 4;
 	  else
 	    cmdlen = linelen;
-	  proto_tree_add_text(smtp_tree, tvb, offset, cmdlen,
-	      "Command: %s", format_text(line, cmdlen));
+	  proto_tree_add_boolean_hidden(smtp_tree, hf_smtp_req, tvb,
+					0, 0, TRUE);
+	  proto_tree_add_item(smtp_tree, hf_smtp_req_command, tvb,
+			      offset, cmdlen, FALSE);
 	  if (linelen > 5) {
-	    proto_tree_add_text(smtp_tree, tvb, offset + 5, linelen - 5,
-	        "Parameter: %s", format_text(line + 5, linelen - 5));
+	    proto_tree_add_item(smtp_tree, hf_smtp_req_parameter, tvb,
+				offset + 5, linelen - 5, FALSE);
 	  }
 
 	}
@@ -447,13 +462,15 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	 * Process the response, a line at a time, until we hit a line
 	 * that doesn't have a continuation indication on it.
 	 */
+	proto_tree_add_boolean_hidden(smtp_tree, hf_smtp_rsp, tvb,
+					0, 0, TRUE);
 
 	while (tvb_offset_exists(tvb, offset)) {
 
 	  /*
 	   * Find the end of the line.
 	   */
-	  linelen = tvb_find_line_end(tvb, offset, -1, &next_offset);
+	  linelen = tvb_find_line_end(tvb, offset, -1, &next_offset, FALSE);
 
 	  /*
 	   * Is it a continuation line?
@@ -464,11 +481,27 @@ dissect_smtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	  /*
 	   * Put it into the protocol tree.
 	   */
-	  proto_tree_add_text(smtp_tree, tvb, offset, 3,
-	      "Response: %s", tvb_format_text(tvb, offset, 3));
-	  if (linelen >= 4) {
-	    proto_tree_add_text(smtp_tree, tvb, offset + 4, linelen - 4,
-	        "Parameter: %s", tvb_format_text(tvb, offset + 4, linelen - 4));
+	  line = tvb_get_ptr(tvb, offset, linelen);
+	  if (linelen >= 3 && isdigit(line[0]) && isdigit(line[1])
+	 		   && isdigit(line[2])) {
+	    /*
+	     * We have a 3-digit response code.
+	     */
+	    code = (line[0] - '0')*100 + (line[1] - '0')*10 + (line[2] - '0');
+	    proto_tree_add_uint(smtp_tree, hf_smtp_rsp_code, tvb, offset, 3,
+				code);
+
+	    if (linelen >= 4) {
+	      proto_tree_add_item(smtp_tree, hf_smtp_rsp_parameter, tvb,
+				  offset + 4, linelen - 4, FALSE);
+	    }
+	  } else {
+	    /*
+	     * No 3-digit response code.
+	     */
+	    proto_tree_add_text(smtp_tree, tvb, offset, linelen,
+				"Bogus reply line (no response code): %s",
+				tvb_format_text(tvb, offset, linelen));
 	  }
 
 	  /*
@@ -499,11 +532,27 @@ proto_register_smtp(void)
 
     { &hf_smtp_rsp,
       { "Response", "smtp.rsp", FT_BOOLEAN, BASE_NONE, NULL, 0x0, "", HFILL }},
+
+    { &hf_smtp_req_command,
+      { "Command", "smtp.req.command", FT_STRING,  BASE_NONE, NULL, 0x0,
+      	"", HFILL }},
+
+    { &hf_smtp_req_parameter,
+      { "Request parameter", "smtp.req.parameter", FT_STRING, BASE_NONE, NULL, 0x0,
+      	"", HFILL }},
+
+    { &hf_smtp_rsp_code,
+      { "Response code", "smtp.response.code", FT_UINT32, BASE_DEC, NULL, 0x0,
+      	"", HFILL }},
+
+    { &hf_smtp_rsp_parameter,
+      { "Response parameter", "smtp.rsp.parameter", FT_STRING, BASE_NONE, NULL, 0x0,
+      	"", HFILL }}
   };
   static gint *ett[] = {
     &ett_smtp
   };
-  /*module_t *smtp_module = NULL; */  /* Not yet used */
+  module_t *smtp_module;
 
   /* No Configuration options to register? */
 
@@ -514,6 +563,11 @@ proto_register_smtp(void)
   proto_register_subtree_array(ett, array_length(ett));
   register_init_routine(&smtp_init_protocol);
 
+  smtp_module = prefs_register_protocol(proto_smtp, NULL);
+  prefs_register_bool_preference(smtp_module, "desegment_lines",
+    "Desegment all SMTP command and response lines spanning multiple TCP segments",
+    "Whether the SMTP dissector should desegment all command and response lines spanning multiple TCP segments",
+    &smtp_desegment);
 }
 
 /* The registration hand-off routine */
