@@ -2,7 +2,7 @@
  * Routines for socks versions 4 &5  packet dissection
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet-socks.c,v 1.38 2002/04/14 23:04:04 guy Exp $
+ * $Id: packet-socks.c,v 1.42 2002/08/02 23:36:03 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -55,22 +55,10 @@
 #endif
 
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <glib.h>
 
-#ifdef NEED_SNPRINTF_H
-# include "snprintf.h"
-#endif
-
 #include <epan/packet.h>
 #include <epan/resolv.h>
 #include "alignment.h"
@@ -263,11 +251,10 @@ static int display_string(tvbuff_t *tvb, int offset,
 	proto_tree      *name_tree;
 	proto_item      *ti;
 
-
 	char temp[ 256];
 	int length = tvb_get_guint8(tvb, offset);
 
-	strncpy( temp, tvb_get_ptr(tvb, offset+1, -1), length);
+	tvb_memcpy(tvb, (guint8 *)temp, offset+1, length);
 	temp[ length ] = 0;
   
    	ti = proto_tree_add_text(tree, tvb, offset, length + 1,
@@ -276,7 +263,7 @@ static int display_string(tvbuff_t *tvb, int offset,
 
 	name_tree = proto_item_add_subtree(ti, ett_socks_name);
 
-	proto_tree_add_text( name_tree, tvb, offset, 1, "Length: %d", length);
+	proto_tree_add_text( name_tree, tvb, offset, 1, "Length: %u", length);
 
 	++offset;
 
@@ -510,7 +497,7 @@ display_socks_v4(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		if ( tvb_offset_exists(tvb, offset)) {
 						/* display user name 	*/
 			proto_tree_add_string( tree, hf_user_name, tvb, offset, 
-				strlen( tvb_get_ptr(tvb, offset, -1)) + 1,
+				tvb_strsize(tvb, offset),
 				tvb_get_ptr(tvb, offset, -1));
 		}
 
@@ -543,7 +530,7 @@ display_socks_v4(tvbuff_t *tvb, int offset, packet_info *pinfo,
 /* Should perhaps do TCP reassembly as well */
 		if ( tvb_offset_exists(tvb, offset)) {
 			proto_tree_add_text( tree, tvb, offset,
-				strlen( tvb_get_ptr(tvb, offset, -1)),
+				tvb_strsize(tvb, offset),
 				"User Name: %s", tvb_get_ptr(tvb, offset, -1));
 		}
 	}
@@ -692,12 +679,22 @@ state_machine_v4( socks_hash_entry_t *hash_info, tvbuff_t *tvb,
 
 		offset += 8;
 		
-		if ( !tvb_offset_exists(tvb, offset)) 	/* if no user name */
+		if ( !tvb_offset_exists(tvb, offset)) {	/* if no user name */
 							/* change state */
 			hash_info->state = V4UserNameWait;
-		
-			
-		hash_info->connect_offset += strlen( tvb_get_ptr(tvb, offset, -1)) + 1;
+			/*
+			 * XXX - add 1, or leave it alone?
+			 * We were adding "strlen(...) + 1".
+			 */
+			hash_info->connect_offset += 1;
+		} else {
+			/*
+			 * Add in the length of the user name.
+			 * XXX - what if the user name is split between
+			 * TCP segments?
+			 */
+			hash_info->connect_offset += tvb_strsize(tvb, offset);
+		}
 		
 		if ( !hash_info->dst_addr){ 		/* if no dest address */
 							/* if more data */
@@ -877,8 +874,8 @@ display_ping_and_tracert(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tr
 /* Display the ping/trace_route conversation */
 
 
-       	const u_char    *data, *dataend;
-       	const u_char   *lineend, *eol;
+       	const guchar    *data, *dataend;
+       	const guchar   *lineend, *eol;
        	int             linelen;
 
 					/* handle the end command */
@@ -1181,4 +1178,3 @@ proto_reg_handoff_socks(void) {
  
  	dissector_add("tcp.port", TCP_PORT_SOCKS, socks_handle);
 }
-
