@@ -6,7 +6,7 @@
  *       In particular I have not had an opportunity to see how it 
  *       responds to SRVLOC over TCP.
  *
- * $Id: packet-srvloc.c,v 1.29 2002/01/24 09:20:51 guy Exp $
+ * $Id: packet-srvloc.c,v 1.32 2002/08/02 23:36:03 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -36,22 +36,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <string.h>
 #include <time.h>
 #include <glib.h>
 
-#ifdef NEED_SNPRINTF_H
-# include "snprintf.h"
-#endif
-
 #include <epan/packet.h>
 #include <epan/strutil.h>
 
@@ -88,7 +76,7 @@ struct srvloc_hdr {
     guint16	length;
     guint8	flags;
     guint8	dialect;
-    u_char	language[2];
+    guchar	language[2];
     guint16	encoding;
     guint16	xid;
 };
@@ -530,7 +518,7 @@ proto_register_srvloc(void)
 					   "SRVLOC", "srvloc");
     proto_register_field_array(proto_srvloc, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
-};
+}
 
 void
 proto_reg_handoff_srvloc(void)
