@@ -1,7 +1,7 @@
 /* packet-tns.c
  * Routines for Oracle TNS packet dissection
  *
- * $Id: packet-tns.c,v 1.29 2002/02/01 04:34:15 gram Exp $
+ * $Id: packet-tns.c,v 1.35 2002/08/02 23:36:03 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -30,19 +30,17 @@
 
 #include <stdio.h>
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 #include <string.h>
 #include <glib.h>
 #include <epan/packet.h>
+#include "packet-tcp.h"
 #include "packet-tns.h"
 
+#include "prefs.h"
+
+/* desegmentation of TNS over TCP */
+static gboolean tns_desegment = TRUE;
+
 static int proto_tns = -1;
 static int hf_tns_request = -1;
 static int hf_tns_response = -1;
@@ -54,17 +52,55 @@ static int hf_tns_reserved_byte = -1;
 static int hf_tns_connect = -1;
 static int hf_tns_version = -1;
 static int hf_tns_compat_version = -1;
+
 static int hf_tns_service_options = -1;
+static int hf_tns_sopt_flag_bconn = -1;
+static int hf_tns_sopt_flag_pc = -1;
+static int hf_tns_sopt_flag_hc = -1;
+static int hf_tns_sopt_flag_fd = -1;
+static int hf_tns_sopt_flag_hd = -1;
+static int hf_tns_sopt_flag_dc1 = -1;
+static int hf_tns_sopt_flag_dc2 = -1;
+static int hf_tns_sopt_flag_dio = -1;
+static int hf_tns_sopt_flag_ap = -1;
+static int hf_tns_sopt_flag_ra = -1;
+static int hf_tns_sopt_flag_sa = -1;
+
 static int hf_tns_sdu_size = -1;
 static int hf_tns_max_tdu_size = -1;
+
 static int hf_tns_nt_proto_characteristics = -1;
+static int hf_tns_ntp_flag_hangon = -1;
+static int hf_tns_ntp_flag_crel = -1;
+static int hf_tns_ntp_flag_tduio = -1;
+static int hf_tns_ntp_flag_srun = -1;
+static int hf_tns_ntp_flag_dtest = -1;
+static int hf_tns_ntp_flag_cbio = -1;
+static int hf_tns_ntp_flag_asio = -1;
+static int hf_tns_ntp_flag_pio = -1;
+static int hf_tns_ntp_flag_grant = -1;
+static int hf_tns_ntp_flag_handoff = -1;
+static int hf_tns_ntp_flag_sigio = -1;
+static int hf_tns_ntp_flag_sigpipe = -1;
+static int hf_tns_ntp_flag_sigurg = -1;
+static int hf_tns_ntp_flag_urgentio = -1;
+static int hf_tns_ntp_flag_fdio = -1;
+static int hf_tns_ntp_flag_testop = -1;
+
 static int hf_tns_line_turnaround = -1;
 static int hf_tns_value_of_one = -1;
 static int hf_tns_connect_data_length = -1;
 static int hf_tns_connect_data_offset = -1;
 static int hf_tns_connect_data_max = -1;
+
 static int hf_tns_connect_flags0 = -1;
 static int hf_tns_connect_flags1 = -1;
+static int hf_tns_conn_flag_nareq = -1;
+static int hf_tns_conn_flag_nalink = -1;
+static int hf_tns_conn_flag_enablena = -1;
+static int hf_tns_conn_flag_ichg = -1;
+static int hf_tns_conn_flag_wantna = -1;
+
 static int hf_tns_connect_data = -1;
 static int hf_tns_trace_cf1 = -1;
 static int hf_tns_trace_cf2 = -1;
@@ -122,6 +158,9 @@ static gint ett_tns_attention = -1;
 static gint ett_tns_control = -1;
 static gint ett_tns_data = -1;
 static gint ett_tns_data_flag = -1;
+static gint ett_tns_sopt_flag = -1;
+static gint ett_tns_ntp_flag = -1;
+static gint ett_tns_conn_flag = -1;
 static gint ett_sql = -1;
 
 static dissector_handle_t data_handle;
@@ -156,6 +195,50 @@ static const value_string tns_control_cmds[] = {
 	{0, NULL}
 };
 
+void proto_reg_handoff_tns(void);
+static guint get_tns_pdu_len(tvbuff_t *tvb, int offset);
+static void dissect_tns_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
+
+static void dissect_tns_service_options(tvbuff_t *tvb, int offset,
+	proto_tree *sopt_tree)
+{
+
+	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_bconn, tvb,
+			offset, 2, FALSE);
+	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_pc, tvb,
+			offset, 2, FALSE);
+	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_hc, tvb,
+			offset, 2, FALSE);
+	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_fd, tvb,
+			offset, 2, FALSE);
+	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_hd, tvb,
+			offset, 2, FALSE);
+	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_dc1, tvb,
+			offset, 2, FALSE);
+	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_dc2, tvb,
+			offset, 2, FALSE);
+	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_dio, tvb,
+			offset, 2, FALSE);
+	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_ap, tvb,
+			offset, 2, FALSE);
+	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_ra, tvb,
+			offset, 2, FALSE);
+	proto_tree_add_item(sopt_tree, hf_tns_sopt_flag_sa, tvb,
+			offset, 2, FALSE);
+	
+}
+
+static void dissect_tns_connect_flag(tvbuff_t *tvb, int offset,
+	proto_tree *cflag_tree)
+{
+
+	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_nareq, tvb, offset, 1, FALSE);
+	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_nalink, tvb, offset, 1, FALSE);
+	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_enablena, tvb, offset, 1, FALSE);
+	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_ichg, tvb, offset, 1, FALSE);
+	proto_tree_add_item(cflag_tree, hf_tns_conn_flag_wantna, tvb, offset, 1, FALSE);
+}
+
 static void dissect_tns_data(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree, proto_tree *tns_tree)
 {
@@ -224,7 +307,8 @@ static void dissect_tns_data(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	
 	if ( data_tree )
 	{
-		call_dissector(data_handle,tvb_new_subset(tvb,offset,-1,tvb_reported_length_remaining(tvb,offset)),pinfo,data_tree);
+		call_dissector(data_handle,
+		    tvb_new_subset(tvb, offset, -1, -1), pinfo, data_tree);
 	}
 
 	return;
@@ -269,9 +353,16 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
 	if ( connect_tree )
 	{
-		/* need to break down w/ bitfield */
-		proto_tree_add_item(connect_tree, hf_tns_service_options, tvb,
+		proto_tree *sopt_tree = NULL;
+		
+		ti = proto_tree_add_item(connect_tree, hf_tns_service_options, tvb,
 			offset, 2, FALSE);
+
+		sopt_tree = proto_item_add_subtree(ti, ett_tns_sopt_flag);
+
+		dissect_tns_service_options(tvb, offset, sopt_tree);
+		
+
 	}
 	offset += 2;
 
@@ -291,8 +382,29 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
 	if ( connect_tree )
 	{
-		proto_tree_add_item(connect_tree, hf_tns_nt_proto_characteristics, tvb,
+		proto_tree *ntp_tree = NULL;
+		
+		ti = proto_tree_add_item(connect_tree, hf_tns_nt_proto_characteristics, tvb,
 			offset, 2, FALSE);
+		
+		ntp_tree = proto_item_add_subtree(ti, ett_tns_ntp_flag);
+
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_hangon, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_crel, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_tduio, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_srun, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_dtest, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_cbio, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_asio, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_pio, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_grant, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_handoff, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_sigio, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_sigpipe, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_sigurg, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_urgentio, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_fdio, tvb, offset, 2, FALSE);
+		proto_tree_add_item(ntp_tree, hf_tns_ntp_flag_testop, tvb, offset, 2, FALSE);
 	}
 	offset += 2;
 
@@ -335,38 +447,50 @@ static void dissect_tns_connect(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
 	if ( connect_tree )
 	{
-		proto_tree_add_item(connect_tree, hf_tns_connect_flags0, tvb,
+		proto_tree *cflag_tree = NULL;
+		
+		ti = proto_tree_add_item(connect_tree, hf_tns_connect_flags0, tvb,
 			offset, 1, FALSE);
+
+		cflag_tree = proto_item_add_subtree(ti, ett_tns_conn_flag);
+
+		dissect_tns_connect_flag(tvb, offset, cflag_tree);
 	}
 	offset += 1;
 
 	if ( connect_tree )
 	{
-		proto_tree_add_item(connect_tree, hf_tns_connect_flags1, tvb,
+		proto_tree *cflag_tree = NULL;
+		
+		ti = proto_tree_add_item(connect_tree, hf_tns_connect_flags1, tvb,
 			offset, 1, FALSE);
+
+		cflag_tree = proto_item_add_subtree(ti, ett_tns_conn_flag);
+
+		dissect_tns_connect_flag(tvb, offset, cflag_tree);
 	}
 	offset += 1;
 
 	if ( connect_tree )
 	{
 		proto_tree_add_item(connect_tree, hf_tns_trace_cf1, tvb,
-			offset, 2, FALSE);
+			offset, 4, FALSE);
 	}
-	offset += 2;
+	offset += 4;
 
 	if ( connect_tree )
 	{
 		proto_tree_add_item(connect_tree, hf_tns_trace_cf2, tvb,
-			offset, 2, FALSE);
+			offset, 4, FALSE);
 	}
-	offset += 2;
+	offset += 4;
 
 	if ( connect_tree )
 	{
 		proto_tree_add_item(connect_tree, hf_tns_trace_cid, tvb,
-			offset, 2, FALSE);
+			offset, 8, FALSE);
 	}
-	offset += 2;
+	offset += 8;
 
 	if ( connect_tree && cd_len > 0)
 	{
@@ -408,8 +532,15 @@ static void dissect_tns_accept(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	
 	if ( accept_tree )
 	{
-		proto_tree_add_item(accept_tree, hf_tns_service_options, tvb,
-			offset, 2, FALSE);
+		proto_tree *sopt_tree = NULL;
+		
+		ti = proto_tree_add_item(accept_tree, hf_tns_service_options, 
+			tvb, offset, 2, FALSE);
+
+		sopt_tree = proto_item_add_subtree(ti, ett_tns_sopt_flag);
+
+		dissect_tns_service_options(tvb, offset, sopt_tree);
+	
 	}
 	offset += 2;
 
@@ -452,15 +583,29 @@ static void dissect_tns_accept(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
 	if ( accept_tree )
 	{
-		proto_tree_add_item(accept_tree, hf_tns_connect_flags0, tvb,
+		proto_tree *cflag_tree = NULL;
+		
+		ti = proto_tree_add_item(accept_tree, hf_tns_connect_flags0, tvb,
 			offset, 1, FALSE);
+
+		cflag_tree = proto_item_add_subtree(ti, ett_tns_conn_flag);
+
+		dissect_tns_connect_flag(tvb, offset, cflag_tree);
+		
 	}
 	offset += 1;
 
 	if ( accept_tree )
 	{
-		proto_tree_add_item(accept_tree, hf_tns_connect_flags1, tvb,
+		proto_tree *cflag_tree = NULL;
+		
+		ti = proto_tree_add_item(accept_tree, hf_tns_connect_flags1, tvb,
 			offset, 1, FALSE);
+
+		cflag_tree = proto_item_add_subtree(ti, ett_tns_conn_flag);
+
+		dissect_tns_connect_flag(tvb, offset, cflag_tree);
+		
 	}
 	offset += 1;
 
@@ -695,10 +840,24 @@ static void dissect_tns_control(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	return;
 }
 
-
+static guint
+get_tns_pdu_len(tvbuff_t *tvb, int offset)
+{
+        /*
+         * Get the length of the TNS message, including header
+         */
+        return tvb_get_ntohs(tvb, offset);
+}
 
 static void
 dissect_tns(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+{
+	tcp_dissect_pdus(tvb, pinfo, tree, tns_desegment, 2,
+	    get_tns_pdu_len, dissect_tns_pdu);
+}
+
+static void
+dissect_tns_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	proto_tree      *tns_tree = NULL, *ti;
 	int offset = 0;
@@ -804,7 +963,10 @@ dissect_tns(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			dissect_tns_data(tvb,offset,pinfo,tree,tns_tree);
 			break;
 		default:
-			call_dissector(data_handle,tvb_new_subset(tvb,offset,-1,tvb_reported_length_remaining(tvb,offset)),pinfo,tns_tree);
+			call_dissector(data_handle,
+			    tvb_new_subset(tvb, offset, -1, -1), pinfo,
+			    tns_tree);
+			break;
 	}
 }
 
@@ -833,18 +995,108 @@ void proto_register_tns(void)
 		{ &hf_tns_compat_version, { 	
 			"Version (Compatible)", "tns.compat_version", FT_UINT16, BASE_DEC, 
 			NULL, 0x0, "Version (Compatible)", HFILL }},
+
 		{ &hf_tns_service_options, { 	
 			"Service Options", "tns.service_options", FT_UINT16, BASE_HEX, 
 			NULL, 0x0, "Service Options", HFILL }},
+
+		{ &hf_tns_sopt_flag_bconn, { 	
+			"Broken Connect Notify", "tns.so_flag.bconn", FT_UINT16, BASE_BIN, 
+			NULL, 0x2000, "Broken Connect Notify", HFILL }},
+		{ &hf_tns_sopt_flag_pc, { 	
+			"Packet Checksum", "tns.so_flag.pc", FT_UINT16, BASE_BIN, 
+			NULL, 0x1000, "Packet Checksum", HFILL }},
+		{ &hf_tns_sopt_flag_hc, { 	
+			"Header Checksum", "tns.so_flag.hc", FT_UINT16, BASE_BIN, 
+			NULL, 0x0800, "Header Checksum", HFILL }},
+		{ &hf_tns_sopt_flag_fd, { 	
+			"Full Duplex", "tns.so_flag.fd", FT_UINT16, BASE_BIN, 
+			NULL, 0x0400, "Full Duplex", HFILL }},
+		{ &hf_tns_sopt_flag_hd, { 	
+			"Half Duplex", "tns.so_flag.hd", FT_UINT16, BASE_BIN, 
+			NULL, 0x0200, "Half Duplex", HFILL }},
+		{ &hf_tns_sopt_flag_dc1, { 	
+			"Don't Care", "tns.so_flag.dc1", FT_UINT16, BASE_BIN, 
+			NULL, 0x0100, "Don't Care", HFILL }},
+		{ &hf_tns_sopt_flag_dc2, { 	
+			"Don't Care", "tns.so_flag.dc2", FT_UINT16, BASE_BIN, 
+			NULL, 0x0080, "Don't Care", HFILL }},		
+		{ &hf_tns_sopt_flag_dio, { 	
+			"Direct IO to Transport", "tns.so_flag.dio", FT_UINT16, BASE_BIN, 
+			NULL, 0x0010, "Direct IO to Transport", HFILL }},
+		{ &hf_tns_sopt_flag_ap, { 	
+			"Attention Processing", "tns.so_flag.ap", FT_UINT16, BASE_BIN, 
+			NULL, 0x0008, "Attention Processing", HFILL }},
+		{ &hf_tns_sopt_flag_ra, { 	
+			"Can Receive Attention", "tns.so_flag.ra", FT_UINT16, BASE_BIN, 
+			NULL, 0x0004, "Can Receive Attention", HFILL }},
+		{ &hf_tns_sopt_flag_sa, { 	
+			"Can Send Attention", "tns.so_flag.sa", FT_UINT16, BASE_BIN, 
+			NULL, 0x0002, "Can Send Attention", HFILL }},
+
+
 		{ &hf_tns_sdu_size, { 	
 			"Session Data Unit Size", "tns.sdu_size", FT_UINT16, BASE_DEC, 
 			NULL, 0x0, "Session Data Unit Size", HFILL }},
 		{ &hf_tns_max_tdu_size, { 	
 			"Maximum Transmission Data Unit Size", "tns.max_tdu_size", FT_UINT16, BASE_DEC, 
 			NULL, 0x0, "Maximum Transmission Data Unit Size", HFILL }},
+
 		{ &hf_tns_nt_proto_characteristics, { 	
 			"NT Protocol Characteristics", "tns.nt_proto_characteristics", FT_UINT16, BASE_HEX, 
 			NULL, 0x0, "NT Protocol Characteristics", HFILL }},
+		{ &hf_tns_ntp_flag_hangon, { 	
+			"Hangon to listener connect", "tns.ntp_flag.hangon", FT_UINT16, BASE_BIN, 
+			NULL, 0x8000, "Hangon to listener connect", HFILL }},
+		{ &hf_tns_ntp_flag_crel, { 	
+			"Confirmed release", "tns.ntp_flag.crel", FT_UINT16, BASE_BIN, 
+			NULL, 0x4000, "Confirmed release", HFILL }},
+		{ &hf_tns_ntp_flag_tduio, { 	
+			"TDU based IO", "tns.ntp_flag.tduio", FT_UINT16, BASE_BIN, 
+			NULL, 0x2000, "TDU based IO", HFILL }},
+		{ &hf_tns_ntp_flag_srun, { 	
+			"Spawner running", "tns.ntp_flag.srun", FT_UINT16, BASE_BIN, 
+			NULL, 0x1000, "Spawner running", HFILL }},
+		{ &hf_tns_ntp_flag_dtest, { 	
+			"Data test", "tns.ntp_flag.dtest", FT_UINT16, BASE_BIN, 
+			NULL, 0x0800, "Data Test", HFILL }},
+		{ &hf_tns_ntp_flag_cbio, { 	
+			"Callback IO supported", "tns.ntp_flag.cbio", FT_UINT16, BASE_BIN, 
+			NULL, 0x0400, "Callback IO supported", HFILL }},
+		{ &hf_tns_ntp_flag_asio, { 	
+			"ASync IO Supported", "tns.ntp_flag.asio", FT_UINT16, BASE_BIN, 
+			NULL, 0x0200, "ASync IO Supported", HFILL }},
+		{ &hf_tns_ntp_flag_pio, { 	
+			"Packet oriented IO", "tns.ntp_flag.pio", FT_UINT16, BASE_BIN, 
+			NULL, 0x0100, "Packet oriented IO", HFILL }},
+		{ &hf_tns_ntp_flag_grant, { 	
+			"Can grant connection to another", "tns.ntp_flag.grant", FT_UINT16, BASE_BIN, 
+			NULL, 0x0080, "Can grant connection to another", HFILL }},
+		{ &hf_tns_ntp_flag_handoff, { 	
+			"Can handoff connection to another", "tns.ntp_flag.handoff", FT_UINT16, BASE_BIN, 
+			NULL, 0x0040, "Can handoff connection to another", HFILL }},
+		{ &hf_tns_ntp_flag_sigio, { 	
+			"Generate SIGIO signal", "tns.ntp_flag.sigio", FT_UINT16, BASE_BIN, 
+			NULL, 0x0020, "Generate SIGIO signal", HFILL }},
+		{ &hf_tns_ntp_flag_sigpipe, { 	
+			"Generate SIGPIPE signal", "tns.ntp_flag.sigpipe", FT_UINT16, BASE_BIN, 
+			NULL, 0x0010, "Generate SIGPIPE signal", HFILL }},
+		{ &hf_tns_ntp_flag_sigurg, { 	
+			"Generate SIGURG signal", "tns.ntp_flag.sigurg", FT_UINT16, BASE_BIN, 
+			NULL, 0x0008, "Generate SIGURG signal", HFILL }},
+		{ &hf_tns_ntp_flag_urgentio, { 	
+			"Urgent IO supported", "tns.ntp_flag.urgentio", FT_UINT16, BASE_BIN, 
+			NULL, 0x0004, "Urgent IO supported", HFILL }},
+		{ &hf_tns_ntp_flag_fdio, { 	
+			"Full duplex IO supported", "tns.ntp_flag.dfio", FT_UINT16, BASE_BIN, 
+			NULL, 0x0002, "Full duplex IO supported", HFILL }},
+		{ &hf_tns_ntp_flag_testop, { 	
+			"Test operation", "tns.ntp_flag.testop", FT_UINT16, BASE_BIN, 
+			NULL, 0x0001, "Test operation", HFILL }},
+
+
+
+
 		{ &hf_tns_line_turnaround, { 	
 			"Line Turnaround Value", "tns.line_turnaround", FT_UINT16, BASE_DEC, 
 			NULL, 0x0, "Line Turnaround Value", HFILL }},
@@ -864,20 +1116,39 @@ void proto_register_tns(void)
 		{ &hf_tns_connect_data_max, { 	
 			"Maximum Receivable Connect Data", "tns.connect_data_max", FT_UINT32, BASE_DEC, 
 			NULL, 0x0, "Maximum Receivable Connect Data", HFILL }},
+
 		{ &hf_tns_connect_flags0, { 	
 			"Connect Flags 0", "tns.connect_flags0", FT_UINT8, BASE_HEX, 
 			NULL, 0x0, "Connect Flags 0", HFILL }},
 		{ &hf_tns_connect_flags1, { 	
 			"Connect Flags 1", "tns.connect_flags1", FT_UINT8, BASE_HEX, 
 			NULL, 0x0, "Connect Flags 1", HFILL }},
+
+		{ &hf_tns_conn_flag_nareq, { 	
+			"NA services required", "tns.connect_flags.nareq", FT_UINT8, BASE_BIN, 
+			NULL, 0x10, "NA services required", HFILL }},
+		{ &hf_tns_conn_flag_nalink, { 	
+			"NA services linked in", "tns.connect_flags.nalink", FT_UINT8, BASE_BIN, 
+			NULL, 0x08, "NA services linked in", HFILL }},
+		{ &hf_tns_conn_flag_enablena, { 	
+			"NA services enabled", "tns.connect_flags.enablena", FT_UINT8, BASE_BIN, 
+			NULL, 0x04, "NA services enabled", HFILL }},
+		{ &hf_tns_conn_flag_ichg, { 	
+			"Interchange is involved", "tns.connect_flags.ichg", FT_UINT8, BASE_BIN, 
+			NULL, 0x02, "Interchange is involved", HFILL }},
+		{ &hf_tns_conn_flag_wantna, { 	
+			"NA services wanted", "tns.connect_flags.wantna", FT_UINT8, BASE_BIN, 
+			NULL, 0x01, "NA services wanted", HFILL }},
+
+
 		{ &hf_tns_trace_cf1, { 	
-			"Trace Cross Facility Item 1", "tns.trace_cf1", FT_UINT16, BASE_HEX, 
+			"Trace Cross Facility Item 1", "tns.trace_cf1", FT_UINT32, BASE_HEX, 
 			NULL, 0x0, "Trace Cross Facility Item 1", HFILL }},
 		{ &hf_tns_trace_cf2, { 	
-			"Trace Cross Facility Item 2", "tns.trace_cf2", FT_UINT16, BASE_HEX, 
+			"Trace Cross Facility Item 2", "tns.trace_cf2", FT_UINT32, BASE_HEX, 
 			NULL, 0x0, "Trace Cross Facility Item 2", HFILL }},
 		{ &hf_tns_trace_cid, { 	
-			"Trace Unique Connection ID", "tns.trace_cid", FT_UINT16, BASE_HEX, 
+			"Trace Unique Connection ID", "tns.trace_cid", FT_UINT64, BASE_HEX, 
 			NULL, 0x0, "Trace Unique Connection ID", HFILL }},
 		{ &hf_tns_connect_data, { 	
 			"Connect Data", "tns.connect_data", FT_STRING, BASE_NONE, 
@@ -887,7 +1158,7 @@ void proto_register_tns(void)
 			"Accept", "tns.accept", FT_BOOLEAN, BASE_NONE, 
 			NULL, 0x0, "Accept", HFILL }},		
 		{ &hf_tns_accept_data_length, { 	
-			"Accept Data Length", "tns.accept_data_length", FT_UINT16, BASE_HEX, 
+			"Accept Data Length", "tns.accept_data_length", FT_UINT16, BASE_DEC, 
 			NULL, 0x0, "Length of Accept Data", HFILL }},
 		{ &hf_tns_accept_data, { 	
 			"Accept Data", "tns.accept_data", FT_STRING, BASE_NONE, 
@@ -904,10 +1175,10 @@ void proto_register_tns(void)
 			"Refuse Reason (User)", "tns.refuse_reason_user", FT_UINT8, BASE_HEX, 
 			NULL, 0x0, "Refuse Reason from Application", HFILL }},
 		{ &hf_tns_refuse_reason_system, { 	
-			"Refuse Reason (User)", "tns.refuse_reason_system", FT_UINT8, BASE_HEX, 
+			"Refuse Reason (System)", "tns.refuse_reason_system", FT_UINT8, BASE_HEX, 
 			NULL, 0x0, "Refuse Reason from System", HFILL }},
 		{ &hf_tns_refuse_data_length, { 	
-			"Refuse Data Length", "tns.refuse_data_length", FT_UINT16, BASE_HEX, 
+			"Refuse Data Length", "tns.refuse_data_length", FT_UINT16, BASE_DEC, 
 			NULL, 0x0, "Length of Refuse Data", HFILL }},
 		{ &hf_tns_refuse_data, { 	
 			"Refuse Data", "tns.refuse_data", FT_STRING, BASE_NONE, 
@@ -953,7 +1224,7 @@ void proto_register_tns(void)
 			"Redirect", "tns.redirect", FT_BOOLEAN, BASE_NONE, 
 			NULL, 0x0, "Redirect", HFILL }},		
 		{ &hf_tns_redirect_data_length, { 	
-			"Redirect Data Length", "tns.redirect_data_length", FT_UINT16, BASE_HEX, 
+			"Redirect Data Length", "tns.redirect_data_length", FT_UINT16, BASE_DEC, 
 			NULL, 0x0, "Length of Redirect Data", HFILL }},
 		{ &hf_tns_redirect_data, { 	
 			"Redirect Data", "tns.redirect_data", FT_STRING, BASE_NONE, 
@@ -961,7 +1232,8 @@ void proto_register_tns(void)
 
 		{ &hf_tns_data, { 
 			"Data", "tns.data", FT_BOOLEAN, BASE_NONE, 
-			NULL, 0x0, "Data", HFILL }},		
+			NULL, 0x0, "Data", HFILL }},	
+	
 		{ &hf_tns_data_flag, { 	
 			"Data Flag", "tns.data_flag", FT_UINT16, BASE_HEX, 
 			NULL, 0x0, "Data Flag", HFILL }},
@@ -1015,12 +1287,23 @@ void proto_register_tns(void)
 		&ett_tns_control,
 		&ett_tns_data,
 		&ett_tns_data_flag,
+		&ett_tns_sopt_flag,
+		&ett_tns_ntp_flag,
+		&ett_tns_conn_flag,
 		&ett_sql
 	};
+	module_t *tns_module;
+
 	proto_tns = proto_register_protocol(
 		"Transparent Network Substrate Protocol", "TNS", "tns");
 	proto_register_field_array(proto_tns, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+
+	tns_module = prefs_register_protocol(proto_tns, NULL);
+	prefs_register_bool_preference(tns_module, "desegment_tns_messages",
+	  "Desegment all TNS messages spanning multiple TCP segments",
+	  "Whether the TNS dissector should desegment all messages spanning multiple TCP segments",
+	  &tns_desegment);
 }
 
 void
