@@ -2,7 +2,7 @@
  * Routines for Token-Ring packet disassembly
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-tr.c,v 1.70 2002/04/14 23:04:04 guy Exp $
+ * $Id: packet-tr.c,v 1.72 2002/08/02 23:36:03 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -27,10 +27,6 @@
 # include "config.h"
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
 #include <string.h>
 #include <stdio.h>
 #include <glib.h>
@@ -164,7 +160,7 @@ int check_for_old_linux_tvb(tvbuff_t *tvb)
 }
 
 static
-int check_for_old_linux(const u_char * pd)
+int check_for_old_linux(const guchar * pd)
 {
 	int x;
 	for(x=1;x<=18;x++)
@@ -182,7 +178,7 @@ static void
 add_ring_bridge_pairs(int rcf_len, tvbuff_t*, proto_tree *tree);
 
 void
-capture_tr(const u_char *pd, int offset, int len, packet_counts *ld) {
+capture_tr(const guchar *pd, int offset, int len, packet_counts *ld) {
 
 	int			source_routed = 0;
 	int			frame_type;
@@ -226,6 +222,11 @@ capture_tr(const u_char *pd, int offset, int len, packet_counts *ld) {
 	 * which packets should have been SR here. I'll check to
 	 * see if there's a SNAP or IPX field right after
 	 * my RIF fields.
+	 *
+	 * The Linux 2.4.18 code, at least appears to do the
+	 * same thing, from a capture I got from somebody running
+	 * 2.4.18 (RH 7.1, so perhaps this is a Red Hat
+	 * "improvement").
 	 */
 	if (!source_routed && trn_rif_bytes > 0) {
 		if (pd[offset + 0x0e] != pd[offset + 0x0f]) {
@@ -365,6 +366,11 @@ dissect_tr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	 * which packets should have been SR here. I'll check to
 	 * see if there's a SNAP or IPX field right after
 	 * my RIF fields.
+	 *
+	 * The Linux 2.4.18 code, at least appears to do the
+	 * same thing, from a capture I got from somebody running
+	 * 2.4.18 (RH 7.1, so perhaps this is a Red Hat
+	 * "improvement").
 	 */
 	if (frame_type == 1 && !source_routed && trn_rif_bytes > 0) {
 		TRY {
