@@ -1,6 +1,6 @@
 /* packet-tr.h
  *
- * $Id: packet-tr.h,v 1.5 2001/11/20 21:59:13 guy Exp $
+ * $Id: packet-tr.h,v 1.6 2002/08/02 23:36:03 jmayer Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -24,6 +24,6 @@
 #ifndef __PACKET_TR_H__
 #define __PACKET_TR_H__
 
-void capture_tr(const u_char *, int, int, packet_counts *);
+void capture_tr(const guchar *, int, int, packet_counts *);
 
 #endif
